@@ -42,6 +42,7 @@
 #include "components/variations/pref_names.h"
 #include "components/variations/proto/variations_seed.pb.h"
 #include "components/variations/seed_response.h"
+#include "components/variations/sticky_activation_manager.h"
 #include "components/variations/variations_safe_seed_store_local_state.h"
 #include "components/variations/variations_seed_simulator.h"
 #include "components/variations/variations_switches.h"
@@ -554,6 +555,7 @@ void VariationsService::RegisterPrefs(PrefRegistrySimple* registry) {
   SafeSeedManager::RegisterPrefs(registry);
   VariationsSeedStore::RegisterPrefs(registry);
   RegisterFieldTrialInternalsPrefs(*registry);
+  StickyActivationManager::RegisterPrefs(*registry);
 
   registry->RegisterIntegerPref(
       prefs::kDeviceVariationsRestrictionsByPolicy,
@@ -710,9 +712,10 @@ void VariationsService::StoreSeed(std::string seed_data,
       base::BindOnce(&VariationsService::OnSeedStoreResult,
                      weak_ptr_factory_.GetWeakPtr(), is_delta_compressed);
   field_trial_creator_.seed_store()->StoreSeedData(
-      std::move(seed_data), std::move(seed_signature), std::move(country_code),
-      date_fetched, is_delta_compressed, is_gzip_compressed,
-      std::move(done_callback));
+      std::move(done_callback), std::move(seed_data), std::move(seed_signature),
+      std::move(country_code), date_fetched, is_delta_compressed,
+      is_gzip_compressed,
+      /*require_synchronous=*/false);
 }
 
 void VariationsService::OnSeedStoreResult(bool is_delta_compressed,
@@ -793,7 +796,7 @@ void VariationsService::NotifyObservers(const SeedSimulationResult& result) {
 }
 
 void VariationsService::OnSimpleLoaderComplete(
-    std::unique_ptr<std::string> response_body) {
+    std::optional<std::string> response_body) {
   DCHECK_CALLED_ON_VALID_SEQUENCE(sequence_checker_);
   TRACE_EVENT0("browser", "VariationsService::OnSimpleLoaderComplete");
 
