@@ -130,7 +130,6 @@ constexpr int kMaxEvictionTaskIntervalMs = 10000;
 #endif  // defined(ARCH_CPU_64_BITS)
 
 BASE_FEATURE(kLightweightUafDetector,
-             "LightweightUafDetector",
 #if BUILDFLAG(IS_WIN)
              base::FEATURE_ENABLED_BY_DEFAULT
 #else
@@ -583,8 +582,7 @@ void MaybeEnableExtremeLightweightDetector(bool boost_sampling,
   // `base::FeatureList::IsEnabled` gets called so that the finch system applies
   // the experiments to the right devices equally and collects the accurate
   // statistics from the devices.
-  if (base::SysInfo::AmountOfPhysicalMemory() <
-      8ULL * 1024 * 1024 * 1024 /* 8 Gbytes */) {
+  if (base::SysInfo::AmountOfPhysicalMemory() < base::GiB(8)) {
     return;
   }
 #endif  // PA_BUILDFLAG(IS_ANDROID)
