@@ -2,6 +2,14 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+// LINT.IfChange(JSThemesAndFonts)
+
+// These classes must agree with the font classes in distilledpage.css.
+const themeClasses = ['light', 'dark', 'sepia'];
+const fontFamilyClasses = ['sans-serif', 'serif', 'monospace'];
+
+// LINT.ThenChange(//components/dom_distiller/core/viewer.cc:JSThemesAndFonts)
+
 // On iOS, |distillerOnIos| was set to true before this script.
 // eslint-disable-next-line no-var
 var distillerOnIos;
@@ -21,34 +29,226 @@ function addToPage(html) {
   const div = document.createElement('div');
   div.innerHTML = html;
   $('content').appendChild(div);
-  fillYouTubePlaceholders();
-  sanitizeLinks();
+  // Readability will leave iframes around, but they need the proper structure
+  // and classes to be styled correctly.
+  addClassesToYoutubeIFrames(div);
+  // DomDistiller will leave placeholders, which need to be replaced with
+  // actual iframes.
+  fillYouTubePlaceholders(div);
+  sanitizeLinks(div);
+  ImageClassifier.processImagesIn(div);
 }
 
 /**
- * Iterates through all links on the page. If a link does not have
- * an http or https scheme, it removes the link element from the DOM.
+ * A utility class for classifying images in distilled content.
+ *
+ * Uses a prioritized cascade of heuristics to classify an image as either
+ * inline (e.g., icon) or full-width (e.g., feature image). The checks are:
+ * 1. Rendered size vs. viewport size (for visually dominant images).
+ * 2. Intrinsic size and metadata (for small or decorative images).
+ * 3. Structural context (e.g., inside a <figure>).
+ * 4. A final fallback based on intrinsic width.
+ *
+ * All checks use density-independent units (CSS pixels).
  */
-function sanitizeLinks() {
-  const allLinks = document.querySelectorAll('a');
+class ImageClassifier {
+  static INLINE_CLASS = 'distilled-inline-img';
+  static FULL_WIDTH_CLASS = 'distilled-full-width-img';
+  static DOMINANT_IMAGE_MIN_VIEWPORT_RATIO = 0.8;
+
+  constructor() {
+    // Baseline thresholds in density-independent units (CSS pixels).
+    this.smallAreaUpperBoundDp = 64 * 64;
+    this.inlineWidthFallbackUpperBoundDp = 300;
+
+    // Matches common keywords for icons or mathematical formulas.
+    const mathyKeywords =
+        ['math', 'latex', 'equation', 'formula', 'tex', 'icon'];
+    this._mathyKeywordsRegex =
+        new RegExp('\\b(' + mathyKeywords.join('|') + ')\\b', 'i');
+
+    // Matches characters commonly found in inline formulas.
+    this._mathyAltTextRegex = /[+\-=_^{}\\]/;
+
+    // Extracts the filename from a URL path.
+    this._filenameRegex = /(?:.*\/)?([^?#]*)/;
+  }
+
+  /**
+   * Checks for strong signals that the image is INLINE based on its intrinsic
+   * properties.
+   * @param {HTMLImageElement} img The image element to check.
+   * @return {boolean} True if the image should be inline.
+   * @private
+   */
+  _isDefinitelyInline(img) {
+    // Use natural dimensions (in CSS pixels) to check for small area.
+    const area = img.naturalWidth * img.naturalHeight;
+    if (area > 0 && area < this.smallAreaUpperBoundDp) {
+      return true;
+    }
+
+    // "Mathy" or decorative clues in attributes.
+    const classAndId = (img.className + ' ' + img.id);
+    if (this._mathyKeywordsRegex.test(classAndId)) {
+      return true;
+    }
+
+    // Check the filename of the src URL, ignoring data URIs.
+    if (img.src && !img.src.startsWith('data:')) {
+      const filename = img.src.match(this._filenameRegex)?.[1] || '';
+      if (filename && this._mathyKeywordsRegex.test(filename)) {
+        return true;
+      }
+    }
+
+    // "Mathy" alt text.
+    const alt = img.getAttribute('alt') || '';
+    if (alt.length > 0 && alt.length < 80 &&
+        this._mathyAltTextRegex.test(alt)) {
+      return true;
+    }
+
+    return false;
+  }
+
+  /**
+   * Checks if the image is the primary content of its container.
+   * @param {HTMLImageElement} img The image element to check.
+   * @return {boolean} True if the image should be full-width.
+   * @private
+   */
+  _isDefinitelyFullWidth(img) {
+    // Image is in a <figure> with a <figcaption>.
+    const parent = img.parentElement;
+    if (parent && parent.tagName === 'FIGURE' &&
+        parent.querySelector('figcaption')) {
+      return true;
+    }
+
+    // Image is the only significant content in its container.
+    let container = parent;
+    while (container &&
+           !['P', 'DIV', 'FIGURE', 'BODY'].includes(container.tagName)) {
+      container = container.parentElement;
+    }
+
+    if (container) {
+      for (const child of container.childNodes) {
+        // Skip insignificant nodes.
+        if (child === img) continue;
+        if (child.tagName === 'BR') continue;
+        if (child.nodeType === Node.TEXT_NODE &&
+            child.textContent.trim() === '') {
+          continue;
+        }
+
+        // If we reach this point, the node must be significant.
+        return false;
+      }
+      // If we finish the loop, no significant siblings were found.
+      return true;
+    }
+
+    return false;
+  }
+
+  /**
+   * Classifies the image based on a simple intrinsic width fallback.
+   * @param {HTMLImageElement} img The image element to check.
+   * @return {string} The CSS class to apply.
+   * @private
+   */
+  _classifyByFallback(img) {
+    // Use naturalWidth (in CSS pixels) and compare against the dp threshold.
+    return img.naturalWidth > this.inlineWidthFallbackUpperBoundDp ?
+        ImageClassifier.FULL_WIDTH_CLASS :
+        ImageClassifier.INLINE_CLASS;
+  }
+
+  /**
+   * Determines an image's display style using a prioritized cascade of checks.
+   * @param {HTMLImageElement} img The image element to classify.
+   * @return {string} The CSS class to apply.
+   */
+  classify(img) {
+    // Check for visually dominant images first, as this is the most reliable
+    // signal and overrides all other heuristics.
+    const renderedWidth = img.getBoundingClientRect().width;
+    if (renderedWidth > 0 && window.innerWidth > 0 &&
+        (renderedWidth / window.innerWidth) >
+            ImageClassifier.DOMINANT_IMAGE_MIN_VIEWPORT_RATIO) {
+      return ImageClassifier.FULL_WIDTH_CLASS;
+    }
+
+    // Fall back to checks based on intrinsic properties and structure.
+    if (this._isDefinitelyInline(img)) {
+      return ImageClassifier.INLINE_CLASS;
+    }
+
+    if (this._isDefinitelyFullWidth(img)) {
+      return ImageClassifier.FULL_WIDTH_CLASS;
+    }
+
+    return this._classifyByFallback(img);
+  }
+
+  /**
+   * Post-processes all images in an element to apply classification classes.
+   * @param {HTMLElement} element The element to search for images in.
+   */
+  static processImagesIn(element) {
+    const classifier = new ImageClassifier();
+    const images = element.getElementsByTagName('img');
+
+    const imageLoadHandler = (event) => {
+      const img = event.currentTarget;
+      const classification = classifier.classify(img);
+      img.classList.add(classification);
+    };
+
+    for (const img of images) {
+      img.onload = imageLoadHandler;
+
+      // If the image is already loaded (e.g., from cache), manually trigger.
+      if (img.complete) {
+        // We use .call() to ensure `this` is correctly bound if the handler
+        // were a traditional function, and to pass a mock event object.
+        imageLoadHandler.call(img, {currentTarget: img});
+      }
+    }
+  }
+}
+
+/**
+ * Visits all links on the page, preserve http and https links and have them
+ * open to new tab. Remove (i.e., unwrap) otherwise.
+ * @param {HTMLElement} element The element to sanitize links in.
+ */
+function sanitizeLinks(element) {
+  const allLinks = element.querySelectorAll('a');
 
   allLinks.forEach(linkElement => {
     const href = linkElement.getAttribute('href');
 
     if (href) {
-      let isProtocolInvalid = false;
+      let keepLink = false;
       // Use a try-catch block to handle malformed URLs gracefully.
       try {
-        const url = new URL(href, window.location.href);
-        if (url.protocol !== 'http:' && url.protocol !== 'https:') {
-          isProtocolInvalid = true;
+        if (href) {
+          const url = new URL(href, window.location.href);
+          // In particular, reject javascript: and #in-page links.
+          if (url.protocol === 'http:' || url.protocol === 'https:') {
+            keepLink = true;
+            // Open to new tab.
+            linkElement.target = '_blank';
+          }
         }
       } catch (error) {
-        // A malformed URL is considered invalid.
-        isProtocolInvalid = true;
+        // URL is malformed.
       }
 
-      if (isProtocolInvalid) {
+      if (!keepLink) {
         // If the protocol is invalid or the URL is malformed, unwrap the link.
         const parent = linkElement.parentNode;
 
@@ -65,12 +265,19 @@ function sanitizeLinks() {
         }
       }
     }
+    // With href, an anchor can be a placeholder. Leave these alone.
   });
 }
 
-function fillYouTubePlaceholders() {
-  const placeholders = document.getElementsByClassName('embed-placeholder');
-  for (let i = 0; i < placeholders.length; i++) {
+/**
+ * Locates youtube embeds generated by DomDistiller, and creates an iframe for
+ * each.
+ * @param {HTMLElement} element The element to search for placeholders in.
+ */
+function fillYouTubePlaceholders(element) {
+  const placeholders = element.getElementsByClassName('embed-placeholder');
+  for (let i = 0; i < placeholders.length;
+ i++) {
     if (!placeholders[i].hasAttribute('data-type') ||
         placeholders[i].getAttribute('data-type') !== 'youtube' ||
         !placeholders[i].hasAttribute('data-id')) {
@@ -79,20 +286,66 @@ function fillYouTubePlaceholders() {
     const embed = document.createElement('iframe');
     const url = 'http://www.youtube.com/embed/' +
         placeholders[i].getAttribute('data-id');
-    embed.setAttribute('class', 'youtubeIframe');
     embed.setAttribute('src', url);
     embed.setAttribute('type', 'text/html');
     embed.setAttribute('frameborder', '0');
-
-    const parent = placeholders[i].parentElement;
-    const container = document.createElement('div');
-    container.setAttribute('class', 'youtubeContainer');
-    container.appendChild(embed);
-
-    parent.replaceChild(container, placeholders[i]);
+    embedYoutubeIFrame(embed);
   }
 }
 
+/**
+ * Locates existing youtube iframes and applies viewer stylings to them. This
+ * is only relevant to readability which leave iframes in the result.
+ * DomDistiller leaves behind placeholders, which are handled by
+ * #fillYouTubePlaceholders.
+ * @param {HTMLElement} element The element to search for iframes in.
+ */
+function addClassesToYoutubeIFrames(element) {
+  const iframes = element.getElementsByTagName('iframe');
+  for (let i = 0; i < iframes.length; i++) {
+    const iframe = iframes[i];
+    if (!isYouTubeIframe(iframe.src)) {
+      continue;
+    }
+    embedYoutubeIFrame(iframe);
+  }
+}
+
+/**
+ * Checks if an iframe element is a YouTube video embed.
+ * @param src The iframe element to check.
+ * @returns True if the iframe is a YouTube video, false otherwise.
+ */
+function isYouTubeIframe(src) {
+  try {
+    const url = new URL(src);
+    const hostname = url.hostname;
+
+    // Check for standard youtube.com or the privacy-enhanced
+    // youtube-nocookie.com
+    return (
+        hostname === 'www.youtube.com' || hostname === 'youtube.com' ||
+        hostname === 'www.youtube-nocookie.com');
+  } catch (error) {
+    // Invalid URL in src, so it's not a valid YouTube embed
+    return false;
+  }
+}
+
+/**
+ * Takes the given youtube iframe, adds a class and embeds it in a div. This is
+ * used to apply consistent styling for all youtube embeds.
+ * @param element The iframe element to embed within a container.
+ */
+function embedYoutubeIFrame(element) {
+  const parent = element.parentElement;
+  const container = document.createElement('div');
+  element.setAttribute('class', 'youtubeIframe');
+  container.setAttribute('class', 'youtubeContainer');
+  parent.replaceChild(container, element);
+  container.appendChild(element);
+}
+
 function showLoadingIndicator(isLastPage) {
   $('loading-indicator').className = isLastPage ? 'hidden' : 'visible';
 }
@@ -112,10 +365,6 @@ function setTextDirection(direction) {
   document.body.setAttribute('dir', direction);
 }
 
-// These classes must agree with the font classes in distilledpage.css.
-const themeClasses = ['light', 'dark', 'sepia'];
-const fontFamilyClasses = ['sans-serif', 'serif', 'monospace'];
-
 // Get the currently applied appearance setting.
 function getAppearanceSetting(settingClasses) {
   const cls = Array.from(document.body.classList)
@@ -187,7 +436,7 @@ class FontSizeSlider {
     this.update(this.element.value);
   }
   // TODO(meredithl): validate |scale| and snap to nearest supported font size.
-  useFontScaling(scale) {
+  useFontScaling(scale, restoreCenter = true) {
     this.element.value = this.fontSizeScale.indexOf(scale);
     document.documentElement.style.fontSize = scale * this.baseSize + 'px';
     this.update(this.element.value);
@@ -206,6 +455,11 @@ class FontSizeSlider {
       option.classList.toggle('after-thumb', !isBeforeThumb);
     }
   }
+
+  useBaseFontSize(size) {
+    this.baseSize = size;
+    this.update(this.element.value);
+  }
 }
 
 maybeSetWebFont();
@@ -233,10 +487,10 @@ class Pincher {
   // TODO(wychen): Improve scroll position when elementFromPoint is body.
 
   constructor() {
-    // This has to be in sync with 'font-size' in distilledpage.css.
+    // This has to be in sync with largest 'font-size' in distilledpage_{}.css.
     // This value is hard-coded because JS might be injected before CSS is
     // ready. See crbug.com/1004663.
-    this.baseSize = 14;
+    this.baseSize = 16;
     this.pinching = false;
     this.fontSizeAnchor = 1.0;
 
@@ -271,7 +525,7 @@ class Pincher {
   refreshTransform_() {
     const slowedScale = Math.exp(Math.log(this.scale) * FONT_SCALE_MULTIPLIER);
     this.clampedScale =
-        Math.max(0.5, Math.min(2.0, this.fontSizeAnchor * slowedScale));
+        Math.max($MIN_SCALE, Math.min(2.0, this.fontSizeAnchor * slowedScale));
 
     // Use "fake" 3D transform so that the layer is not repainted.
     // With 2D transform, the frame rate would be much lower.
@@ -462,13 +716,22 @@ class Pincher {
     };
   }
 
-  useFontScaling(scaling) {
-    this.saveCenter_({x: window.innerWidth / 2, y: window.innerHeight / 2});
+  useFontScaling(scaling, restoreCenter = true) {
+    if (restoreCenter) {
+      this.saveCenter_({x: window.innerWidth / 2, y: window.innerHeight / 2});
+    }
     this.shiftX = 0;
     this.shiftY = 0;
     document.documentElement.style.fontSize = scaling * this.baseSize + 'px';
     this.clampedScale = scaling;
-    this.restoreCenter_();
+    if (restoreCenter) {
+      this.restoreCenter_();
+    }
+  }
+
+  useBaseFontSize(size) {
+    this.baseSize = size;
+    this.reset();
   }
 }
 
@@ -482,11 +745,54 @@ if (navigator.userAgent.toLowerCase().indexOf('android') > -1) {
   fontSizeSlider = new FontSizeSlider();
 }
 
-function useFontScaling(scale) {
+/**
+ * Called to set the baseFontSize for the pinch/slider (whichever is active).
+ */
+function useBaseFontSize(size) {
   if (navigator.userAgent.toLowerCase().indexOf('android') > -1) {
-    pincher.useFontScaling(scale);
+    pincher.useBaseFontSize(size);
   } else {
-    fontSizeSlider.useFontScaling(scale);
+    fontSizeSlider.useBaseFontSize(size);
+  }
+}
+
+function useFontScaling(scale, restoreCenter = true) {
+  if (navigator.userAgent.toLowerCase().indexOf('android') > -1) {
+    pincher.useFontScaling(scale, restoreCenter);
+  } else {
+    fontSizeSlider.useFontScaling(scale, restoreCenter);
+  }
+}
+
+/**
+ * Finds a paragraph with `innerText` matching `hash` and `charCount`, then
+ * scrolls to that paragraph with the provided `progress` corresponding to the
+ * location to scroll to wrt. that paragraph, 0 being the top of that
+ * paragraph, 1 being the bottom.
+ * @param {number} hash The hash of the paragraph's innerText.
+ * @param {number} charCount The character count of the paragraph's innerText.
+ * @param {number} progress The scroll progress within the paragraph (0-1).
+ */
+function scrollToParagraphByHash(hash, charCount, progress) {
+  const targetHash = hash;
+  const targetCharCount = charCount;
+  const paragraphs = document.querySelectorAll('p');
+  for (let i = 0; i < paragraphs.length; i++) {
+    const p = paragraphs[i];
+    const pText = p.innerText;
+    if (pText.length === targetCharCount) {
+      // Only compute hash if the length already matches.
+      const hashCode = (s) =>
+          s.split('').reduce((a, b) => ((a << 5) - a + b.charCodeAt(0)) | 0, 0);
+      const pHash = hashCode(pText);
+      if (pHash === targetHash) {
+        const rect = p.getBoundingClientRect();
+        const scrollOffset = (window.scrollY + rect.top) +
+            (rect.height * progress) - (window.innerHeight / 2);
+        window.scrollTo(0, scrollOffset);
+        break;
+      }
+    }
   }
 }
 
