@@ -93,9 +93,6 @@ const char kDefaultInstallSource[] = "";
 const char kReinstallInstallSource[] = "reinstall";
 
 const char kGoogleDotCom[] = "google.com";
-const char kTokenServiceConsumerId[] = "extension_downloader";
-const char kWebstoreOAuth2Scope[] =
-    "https://www.googleapis.com/auth/chromewebstore.readonly";
 
 ExtensionDownloader::TestObserver* g_test_observer = nullptr;
 ExtensionDownloaderTestDelegate* g_test_delegate = nullptr;
@@ -254,12 +251,6 @@ ExtensionDownloader::FetchDataGroupKey::FetchDataGroupKey(
 
 ExtensionDownloader::FetchDataGroupKey::~FetchDataGroupKey() = default;
 
-bool ExtensionDownloader::FetchDataGroupKey::operator<(
-    const FetchDataGroupKey& other) const {
-  return std::tie(request_id, update_url, is_force_installed) <
-         std::tie(other.request_id, other.update_url, other.is_force_installed);
-}
-
 ExtensionDownloader::ExtensionDownloader(
     ExtensionDownloaderDelegate* delegate,
     scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory,
@@ -1194,17 +1185,15 @@ void ExtensionDownloader::CreateExtensionLoader() {
       // ExtensionLoader will be started once the token fetch is complete,
       // in either OnTokenFetchSuccess or OnTokenFetchFailure.
       DCHECK(identity_manager_);
-      signin::ScopeSet webstore_scopes;
-      webstore_scopes.insert(kWebstoreOAuth2Scope);
       // It is safe to use Unretained(this) here given that the callback
       // will not be invoked if this object is deleted.
       access_token_fetcher_ =
           std::make_unique<signin::PrimaryAccountAccessTokenFetcher>(
-              kTokenServiceConsumerId, identity_manager_, webstore_scopes,
+              signin::OAuthConsumerId::kExtensionDownloader, identity_manager_,
               base::BindOnce(&ExtensionDownloader::OnAccessTokenFetchComplete,
                              base::Unretained(this)),
               signin::PrimaryAccountAccessTokenFetcher::Mode::kImmediate,
-              signin::ConsentLevel::kSync);
+              signin::ConsentLevel::kSignin);
       return;
     }
     extension_loader_resource_request_->headers.SetHeader(
@@ -1441,12 +1430,13 @@ bool ExtensionDownloader::IterateFetchCredentialsAfterFailure(
       if (response_code == net::HTTP_UNAUTHORIZED &&
           fetch->oauth2_attempt_count <= kMaxOAuth2Attempts) {
         DCHECK(identity_manager_);
-        signin::ScopeSet webstore_scopes;
-        webstore_scopes.insert(kWebstoreOAuth2Scope);
-        identity_manager_->RemoveAccessTokenFromCache(
-            identity_manager_->GetPrimaryAccountId(signin::ConsentLevel::kSync),
-            webstore_scopes, access_token_);
-        access_token_.clear();
+        if (!access_token_.empty()) {
+          identity_manager_->RemoveAccessTokenFromCache(
+              identity_manager_->GetPrimaryAccountId(
+                  signin::ConsentLevel::kSignin),
+              signin::OAuthConsumerId::kExtensionDownloader, access_token_);
+          access_token_.clear();
+        }
         return true;
       }
       // Either there is no Gaia identity available, the active identity
