@@ -11,14 +11,12 @@
 #include <utility>
 #include <vector>
 
-#include "base/base64.h"
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
 #include "base/location.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/task/single_thread_task_runner.h"
-#include "chrome/browser/extensions/account_extension_tracker.h"
 #include "chrome/browser/extensions/api/developer_private/developer_private_api.h"
 #include "chrome/browser/extensions/api/developer_private/inspectable_views_finder.h"
 #include "chrome/browser/extensions/commands/command_service.h"
@@ -31,6 +29,7 @@
 #include "chrome/browser/extensions/mv2_experiment_stage.h"
 #include "chrome/browser/extensions/permissions/site_permissions_helper.h"
 #include "chrome/browser/extensions/shared_module_service.h"
+#include "chrome/browser/extensions/sync/account_extension_tracker.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/toolbar/toolbar_actions_model.h"
 #include "chrome/browser/ui/webui/extensions/extension_icon_source.h"
@@ -44,16 +43,17 @@
 #include "extensions/browser/blocklist_extension_prefs.h"
 #include "extensions/browser/blocklist_state.h"
 #include "extensions/browser/extension_error.h"
-#include "extensions/browser/extension_icon_placeholder.h"
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/extension_registry.h"
 #include "extensions/browser/extension_system.h"
 #include "extensions/browser/extension_util.h"
+#include "extensions/browser/icon_util.h"
 #include "extensions/browser/image_loader.h"
 #include "extensions/browser/path_util.h"
 #include "extensions/browser/ui_util.h"
 #include "extensions/browser/user_script_manager.h"
 #include "extensions/browser/warning_service.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/command.h"
 #include "extensions/common/extension_features.h"
 #include "extensions/common/extension_set.h"
@@ -82,6 +82,8 @@
 #include "ui/base/accelerators/global_accelerator_listener/global_accelerator_listener.h"  // nogncheck
 #endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 namespace extensions {
 
 namespace developer = api::developer_private;
@@ -172,9 +174,12 @@ developer::RuntimeError ConstructRuntimeError(const RuntimeError& error) {
   // reasons, but it's not a high priority to change.
   result.render_view_id = error.render_frame_id();
   result.render_process_id = error.render_process_id();
-  result.can_inspect =
+  result.is_service_worker = error.is_from_service_worker();
+  bool can_inspect_frame =
       content::RenderFrameHost::FromID(error.render_process_id(),
                                        error.render_frame_id()) != nullptr;
+  result.can_inspect = can_inspect_frame || result.is_service_worker;
+
   for (const StackFrame& f : error.stack_trace()) {
     developer::StackFrame frame;
     frame.line_number = f.line_number;
@@ -892,7 +897,9 @@ void ExtensionInfoGenerator::FillExtensionInfo(const Extension& extension,
       &extension, extension_misc::EXTENSION_ICON_MEDIUM,
       ExtensionIconSet::Match::kBigger);
   if (icon.empty()) {
-    info.icon_url = GetDefaultIconUrl(extension.name());
+    info.icon_url = GetPlaceholderIconUrl(extension_misc::EXTENSION_ICON_MEDIUM,
+                                          extension.name())
+                        .spec();
     list_.push_back(std::move(info));
   } else {
     ++pending_image_loads_;
@@ -907,25 +914,13 @@ void ExtensionInfoGenerator::FillExtensionInfo(const Extension& extension,
   }
 }
 
-std::string ExtensionInfoGenerator::GetDefaultIconUrl(const std::string& name) {
-  return GetIconUrlFromImage(ExtensionIconPlaceholder::CreateImage(
-      extension_misc::EXTENSION_ICON_MEDIUM, name));
-}
-
-std::string ExtensionInfoGenerator::GetIconUrlFromImage(
-    const gfx::Image& image) {
-  std::string base_64 = base::Base64Encode(*image.As1xPNGBytes());
-  const char kDataUrlPrefix[] = "data:image/png;base64,";
-  return GURL(kDataUrlPrefix + base_64).spec();
-}
-
 void ExtensionInfoGenerator::OnImageLoaded(developer::ExtensionInfo info,
                                            const gfx::Image& icon) {
-  if (!icon.IsEmpty()) {
-    info.icon_url = GetIconUrlFromImage(icon);
-  } else {
-    info.icon_url = GetDefaultIconUrl(info.name);
-  }
+  GURL icon_url = icon.IsEmpty()
+                      ? GetPlaceholderIconUrl(
+                            extension_misc::EXTENSION_ICON_MEDIUM, info.name)
+                      : GetIconUrlFromImage(icon);
+  info.icon_url = icon_url.spec();
 
   list_.push_back(std::move(info));
 
