@@ -22,7 +22,7 @@ class ChromePDFDocumentHelperClient : public pdf::PDFDocumentHelperClient {
   // pdf::PDFDocumentHelperClient:
   void UpdateContentRestrictions(content::RenderFrameHost* render_frame_host,
                                  int content_restrictions) override;
-  void OnSaveURL(content::WebContents* contents) override;
+  void OnSaveURL() override;
   void SetPluginCanSave(content::RenderFrameHost* render_frame_host,
                         bool can_save) override;
   void OnSearchifyStarted(content::RenderFrameHost* render_frame_host) override;
