@@ -110,8 +110,6 @@
 #if BUILDFLAG(IS_CHROMEOS)
 static_assert(BUILDFLAG(ENABLE_PDF), "ChromeOS Ash must enable PDF");
 static_assert(BUILDFLAG(ENABLE_PRINTING), "ChromeOS Ash must enable Printing");
-#include "chrome/services/ipp_parser/ipp_parser.h"  // nogncheck
-#include "chrome/services/ipp_parser/public/mojom/ipp_parser.mojom.h"  // nogncheck
 #include "chrome/services/pdf/pdf_service.h"
 #include "chrome/services/pdf/public/mojom/pdf_service.mojom.h"
 #include "chrome/services/sharing/sharing_impl.h"
@@ -275,13 +273,6 @@ auto RunScreenAIServiceFactory(
 }
 #endif
 
-#if BUILDFLAG(IS_CHROMEOS)
-auto RunCupsIppParser(
-    mojo::PendingReceiver<ipp_parser::mojom::IppParser> receiver) {
-  return std::make_unique<ipp_parser::IppParser>(std::move(receiver));
-}
-#endif
-
 #if (BUILDFLAG(SAFE_BROWSING_DOWNLOAD_PROTECTION) && \
      !BUILDFLAG(IS_ANDROID)) ||                      \
     BUILDFLAG(IS_CHROMEOS)
@@ -494,10 +485,6 @@ void RegisterMainThreadServices(mojo::ServiceFactory& services) {
   services.Add(RunSystemSignalsService);
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
 
-#if BUILDFLAG(IS_CHROMEOS)
-  services.Add(RunCupsIppParser);
-#endif
-
 #if BUILDFLAG(IS_MAC)
   services.Add(RunMacNotificationService);
 #endif  // BUILDFLAG(IS_MAC)
