@@ -21,16 +21,46 @@ namespace enterprise_connectors {
 AnalysisServiceSettings::AnalysisServiceSettings(
     const base::Value& settings_value,
     const ServiceProviderConfig& service_provider_config) {
-  if (!settings_value.is_dict())
+  if (!settings_value.is_dict()) {
     return;
-  const base::Value::Dict& settings_dict = settings_value.GetDict();
+  }
 
+  const auto& settings_dict = settings_value.GetDict();
+  if (!TryParseServiceProviderData(settings_dict, service_provider_config)) {
+    return;
+  }
+
+  // Add the patterns to the settings, which configures settings.matcher and
+  // settings.*_pattern_settings. No enable patterns implies the settings are
+  // invalid.
+  const auto* enabled_pattern_settings_list =
+      settings_dict.FindList(kKeyEnable);
+  if (!enabled_pattern_settings_list ||
+      enabled_pattern_settings_list->empty()) {
+    return;
+  }
+  base::MatcherStringPattern::ID id(0);
+  ParsePatternSettings(enabled_pattern_settings_list, true, id);
+  ParsePatternSettings(settings_dict.FindList(kKeyDisable), false, id);
+
+  ParseBlockSettings(settings_dict);
+  ParseMinimumDataSize(settings_dict);
+  ParseCustomMessages(settings_dict);
+  ParseJustificationTags(settings_dict);
+#if BUILDFLAG(ENTERPRISE_LOCAL_CONTENT_ANALYSIS)
+  ParseVerificationSignatures(settings_dict);
+#endif
+}
+
+bool AnalysisServiceSettings::TryParseServiceProviderData(
+    const base::Value::Dict& settings_dict,
+    const ServiceProviderConfig& service_provider_config) {
   // The service provider identifier should always be there, and it should match
   // an existing provider.
   const std::string* service_provider_name =
       settings_dict.FindString(kKeyServiceProvider);
   if (!service_provider_name) {
-    return;
+    return false;
   }
 
   service_provider_name_ = *service_provider_name;
@@ -40,53 +70,45 @@ AnalysisServiceSettings::AnalysisServiceSettings(
   }
   if (!analysis_config_) {
     DLOG(ERROR) << "No analysis config for corresponding service provider";
+    return false;
+  }
+
+  return true;
+}
+
+void AnalysisServiceSettings::ParsePatternSettings(
+    const base::Value::List* pattern_settings_list,
+    bool is_enabled_pattern,
+    base::MatcherStringPattern::ID& id) {
+  if (!pattern_settings_list || pattern_settings_list->empty()) {
     return;
   }
 
-  // Add the patterns to the settings, which configures settings.matcher and
-  // settings.*_pattern_settings. No enable patterns implies the settings are
-  // invalid.
-  matcher_ = std::make_unique<url_matcher::URLMatcher>();
+  for (const base::Value& pattern_setting : *pattern_settings_list) {
+    const base::Value::Dict* pattern_dict = pattern_setting.GetIfDict();
+    if (!pattern_dict) {
+      continue;
+    }
+
+    auto* url_list = pattern_dict->FindList(kKeyUrlList);
+    auto* source_destination_list =
+        pattern_dict->FindList(kKeySourceDestinationList);
+
+    if (url_list && source_destination_list) {
+      DLOG(ERROR) << kKeyUrlList << " and " << kKeySourceDestinationList
+                  << " specified together. Ignoring it.";
+    } else if (url_list) {
+      AddUrlPatternSettings(*pattern_dict, is_enabled_pattern, &id);
+    } else if (source_destination_list) {
 #if BUILDFLAG(IS_CHROMEOS)
-  source_destination_matcher_ = std::make_unique<SourceDestinationMatcherAsh>();
+      AddSourceDestinationSettings(*pattern_dict, is_enabled_pattern, &id);
 #endif
-  base::MatcherStringPattern::ID id(0);
-  for (auto [key, is_enable] :
-       {std::pair{kKeyEnable, true}, {kKeyDisable, false}}) {
-    const base::Value::List* list = settings_dict.FindList(key);
-    if (list && !list->empty()) {
-      for (const base::Value& value : *list) {
-        const base::Value::Dict* dict = value.GetIfDict();
-        if (!dict) {
-          continue;
-        }
-        auto* url_list = dict->FindList(kKeyUrlList);
-        auto* source_destination_list =
-            dict->FindList(kKeySourceDestinationList);
-        if (url_list && source_destination_list) {
-          DLOG(ERROR) << kKeyUrlList << " and " << kKeySourceDestinationList
-                      << " specified together. Ignoring it.";
-        } else if (url_list) {
-          AddUrlPatternSettings(*dict, is_enable, &id);
-        } else if (source_destination_list) {
-#if BUILDFLAG(IS_CHROMEOS)
-          AddSourceDestinationSettings(*dict, is_enable, &id);
-#else
-          DLOG(ERROR) << kKeySourceDestinationList
-                      << " specified on unsupported platform. Ignoring it.";
-#endif
-        } else {
-          DLOG(ERROR) << "Neither " << kKeyUrlList << " nor "
-                      << kKeySourceDestinationList
-                      << " found in analysis settings. Ignoring it.";
-        }
-      }
-    } else if (is_enable) {
-      // If nothing is enabled, just return and don't parse anything else.
-      return;
     }
   }
+}
 
+void AnalysisServiceSettings::ParseBlockSettings(
+    const base::Value::Dict& settings_dict) {
   // The block settings are optional, so a default is used if they can't be
   // found.
   block_until_verdict_ =
@@ -105,48 +127,67 @@ AnalysisServiceSettings::AnalysisServiceSettings(
       settings_dict.FindBool(kKeyBlockPasswordProtected).value_or(false);
   block_large_files_ =
       settings_dict.FindBool(kKeyBlockLargeFiles).value_or(false);
-  minimum_data_size_ = settings_dict.FindInt(kKeyMinimumDataSize).value_or(100);
+}
 
+void AnalysisServiceSettings::ParseMinimumDataSize(
+    const base::Value::Dict& settings_dict) {
+  minimum_data_size_ = settings_dict.FindInt(kKeyMinimumDataSize)
+                           .value_or(kDefaultMinimumDataSize);
+}
+
+void AnalysisServiceSettings::ParseCustomMessages(
+    const base::Value::Dict& settings_dict) {
   const base::Value::List* custom_messages =
       settings_dict.FindList(kKeyCustomMessages);
-  if (custom_messages) {
-    for (const base::Value& value : *custom_messages) {
-      const base::Value::Dict& dict = value.GetDict();
-
-      // As of now, this list will contain one message per tag. At some point,
-      // the server may start sending one message per language/tag pair. If this
-      // is the case, this code should be changed to match the language to
-      // Chrome's UI language.
-      const std::string* tag = dict.FindString(kKeyCustomMessagesTag);
-      if (!tag)
-        continue;
-
-      CustomMessageData data;
-
-      const std::string* message = dict.FindString(kKeyCustomMessagesMessage);
-      // This string originates as a protobuf string on the server, which are
-      // utf8 and it's used in the UI where it needs to be encoded as utf16. Do
-      // the conversion now, otherwise code down the line may not be able to
-      // determine if the std::string is ASCII or UTF8 before passing it to the
-      // UI.
-      data.message = base::UTF8ToUTF16(message ? *message : "");
-
-      const std::string* url = dict.FindString(kKeyCustomMessagesLearnMoreUrl);
-      data.learn_more_url = url ? GURL(*url) : GURL();
-
-      tags_[*tag].custom_message = std::move(data);
-    }
+  if (!custom_messages) {
+    return;
   }
 
+  for (const base::Value& value : *custom_messages) {
+    const base::Value::Dict& dict = value.GetDict();
+
+    // As of now, this list will contain one message per tag. At some point,
+    // the server may start sending one message per language/tag pair. If this
+    // is the case, this code should be changed to match the language to
+    // Chrome's UI language.
+    const std::string* tag = dict.FindString(kKeyCustomMessagesTag);
+    if (!tag) {
+      continue;
+    }
+
+    CustomMessageData data;
+
+    const std::string* message = dict.FindString(kKeyCustomMessagesMessage);
+    // This string originates as a protobuf string on the server, which are
+    // utf8 and it's used in the UI where it needs to be encoded as utf16. Do
+    // the conversion now, otherwise code down the line may not be able to
+    // determine if the std::string is ASCII or UTF8 before passing it to the
+    // UI.
+    data.message = base::UTF8ToUTF16(message ? *message : "");
+
+    const std::string* url = dict.FindString(kKeyCustomMessagesLearnMoreUrl);
+    data.learn_more_url = url ? GURL(*url) : GURL();
+
+    tags_[*tag].custom_message = std::move(data);
+  }
+}
+
+void AnalysisServiceSettings::ParseJustificationTags(
+    const base::Value::Dict& settings_dict) {
   const base::Value::List* require_justification_tags =
       settings_dict.FindList(kKeyRequireJustificationTags);
-  if (require_justification_tags) {
-    for (const base::Value& tag : *require_justification_tags) {
-      tags_[tag.GetString()].requires_justification = true;
-    }
+  if (!require_justification_tags) {
+    return;
   }
 
+  for (const base::Value& tag : *require_justification_tags) {
+    tags_[tag.GetString()].requires_justification = true;
+  }
+}
+
 #if BUILDFLAG(ENTERPRISE_LOCAL_CONTENT_ANALYSIS)
+void AnalysisServiceSettings::ParseVerificationSignatures(
+    const base::Value::Dict& settings_dict) {
 #if BUILDFLAG(IS_WIN)
   const char* verification_key = kKeyWindowsVerification;
 #elif BUILDFLAG(IS_MAC)
@@ -155,17 +196,19 @@ AnalysisServiceSettings::AnalysisServiceSettings(
   const char* verification_key = kKeyLinuxVerification;
 #endif
 
-  const base::Value::Dict& dict = settings_value.GetDict();
   const base::Value::List* signatures =
-      dict.FindListByDottedPath(verification_key);
-  if (signatures) {
-    for (auto& v : *signatures) {
-      if (v.is_string())
-        verification_signatures_.push_back(v.GetString());
+      settings_dict.FindListByDottedPath(verification_key);
+  if (!signatures) {
+    return;
+  }
+
+  for (auto& v : *signatures) {
+    if (v.is_string()) {
+      verification_signatures_.push_back(v.GetString());
     }
   }
-#endif
 }
+#endif
 
 // static
 std::optional<AnalysisServiceSettings::URLPatternSettings>
@@ -173,17 +216,19 @@ AnalysisServiceSettings::GetPatternSettings(
     const PatternSettings& patterns,
     base::MatcherStringPattern::ID match) {
   // If the pattern exists directly in the map, return its settings.
-  if (patterns.count(match) == 1)
+  if (patterns.count(match) == 1) {
     return patterns.at(match);
+  }
 
   // If the pattern doesn't exist in the map, it might mean that it wasn't the
   // only pattern to correspond to its settings and that the ID added to
   // the map was the one of the last pattern corresponding to those settings.
-  // This means the next match ID greater than |match| has the correct settings
-  // if it exists.
+  // This means the next match ID greater than |match| has the correct
+  // settings if it exists.
   auto next = patterns.upper_bound(match);
-  if (next != patterns.end())
+  if (next != patterns.end()) {
     return next->second;
+  }
 
   return std::nullopt;
 }
@@ -231,17 +276,20 @@ AnalysisSettings AnalysisServiceSettings::GetAnalysisSettingsWithTags(
 std::optional<AnalysisSettings> AnalysisServiceSettings::GetAnalysisSettings(
     const GURL& url,
     DataRegion data_region) const {
-  if (!IsValid())
+  if (!IsValid()) {
     return std::nullopt;
+  }
 
   DCHECK(matcher_);
   auto matches = matcher_->MatchURL(url);
-  if (matches.empty())
+  if (matches.empty()) {
     return std::nullopt;
+  }
 
   auto tags = GetTags(matches);
-  if (tags.empty())
+  if (tags.empty()) {
     return std::nullopt;
+  }
 
   return GetAnalysisSettingsWithTags(std::move(tags), data_region);
 }
@@ -252,26 +300,32 @@ std::optional<AnalysisSettings> AnalysisServiceSettings::GetAnalysisSettings(
     const storage::FileSystemURL& source_url,
     const storage::FileSystemURL& destination_url,
     DataRegion data_region) const {
-  if (!IsValid())
+  if (!IsValid()) {
     return std::nullopt;
+  }
+
   DCHECK(source_destination_matcher_);
 
   auto matches =
       source_destination_matcher_->Match(context, source_url, destination_url);
-  if (matches.empty())
+  if (matches.empty()) {
     return std::nullopt;
+  }
 
   auto tags = GetTags(matches);
-  if (tags.empty())
+  if (tags.empty()) {
     return std::nullopt;
+  }
 
   return GetAnalysisSettingsWithTags(std::move(tags), data_region);
 }
 #endif  // BUILDFLAG(IS_CHROMEOS)
 
 bool AnalysisServiceSettings::ShouldBlockUntilVerdict() const {
-  if (!IsValid())
+  if (!IsValid()) {
     return false;
+  }
+
   return block_until_verdict_ == BlockUntilVerdict::kBlock;
 }
 
@@ -279,6 +333,7 @@ bool AnalysisServiceSettings::ShouldBlockByDefault() const {
   if (!IsValid()) {
     return false;
   }
+
   return default_action_ == DefaultAction::kBlock;
 }
 
@@ -325,22 +380,25 @@ void AnalysisServiceSettings::AddUrlPatternSettings(
     base::MatcherStringPattern::ID* id) {
   DCHECK(id);
   DCHECK(analysis_config_);
-  if (enabled)
+  if (enabled) {
     DCHECK(disabled_patterns_settings_.empty());
-  else
+  } else {
     DCHECK(!enabled_patterns_settings_.empty());
+  }
 
   URLPatternSettings setting;
 
   const base::Value::List* tags = url_settings_dict.FindList(kKeyTags);
-  if (!tags)
+  if (!tags) {
     return;
+  }
 
   for (const base::Value& tag : *tags) {
     if (tag.is_string()) {
       for (const auto& supported_tag : analysis_config_->supported_tags) {
-        if (tag.GetString() == supported_tag.name)
+        if (tag.GetString() == supported_tag.name) {
           setting.tags.insert(tag.GetString());
+        }
       }
     }
   }
@@ -350,6 +408,7 @@ void AnalysisServiceSettings::AddUrlPatternSettings(
   if (!url_list) {
     return;
   }
+
   base::MatcherStringPattern::ID previous_id = *id;
   url_matcher::util::AddFiltersWithLimit(matcher_.get(), enabled, id,
                                          *url_list);
@@ -360,10 +419,11 @@ void AnalysisServiceSettings::AddUrlPatternSettings(
     return;
   }
 
-  if (enabled)
+  if (enabled) {
     enabled_patterns_settings_[*id] = std::move(setting);
-  else
+  } else {
     disabled_patterns_settings_[*id] = std::move(setting);
+  }
 }
 
 #if BUILDFLAG(IS_CHROMEOS)
@@ -374,23 +434,26 @@ void AnalysisServiceSettings::AddSourceDestinationSettings(
   DCHECK(id);
   DCHECK(analysis_config_);
   DCHECK(source_destination_matcher_);
-  if (enabled)
+  if (enabled) {
     DCHECK(disabled_patterns_settings_.empty());
-  else
+  } else {
     DCHECK(!enabled_patterns_settings_.empty());
+  }
 
   URLPatternSettings setting;
 
   const base::Value::List* tags =
       source_destination_settings_value.FindList(kKeyTags);
-  if (!tags)
+  if (!tags) {
     return;
+  }
 
   for (const base::Value& tag : *tags) {
     if (tag.is_string()) {
       for (const auto& supported_tag : analysis_config_->supported_tags) {
-        if (tag.GetString() == supported_tag.name)
+        if (tag.GetString() == supported_tag.name) {
           setting.tags.insert(tag.GetString());
+        }
       }
     }
   }
@@ -411,10 +474,11 @@ void AnalysisServiceSettings::AddSourceDestinationSettings(
     return;
   }
 
-  if (enabled)
+  if (enabled) {
     enabled_patterns_settings_[*id] = std::move(setting);
-  else
+  } else {
     disabled_patterns_settings_[*id] = std::move(setting);
+  }
 }
 #endif  // BUILDFLAG(IS_CHROMEOS)
 
@@ -436,21 +500,24 @@ std::map<std::string, TagSettings> AnalysisServiceSettings::GetTags(
 
     DCHECK(maybe_pattern_setting.has_value());
     auto tags = std::move(maybe_pattern_setting.value().tags);
-    if (enable)
+    if (enable) {
       enable_tags.insert(tags.begin(), tags.end());
-    else
+    } else {
       disable_tags.insert(tags.begin(), tags.end());
+    }
   }
 
-  for (const std::string& tag_to_disable : disable_tags)
+  for (const std::string& tag_to_disable : disable_tags) {
     enable_tags.erase(tag_to_disable);
+  }
 
   std::map<std::string, TagSettings> output;
   for (const std::string& tag : enable_tags) {
-    if (tags_.count(tag))
+    if (tags_.count(tag)) {
       output[tag] = tags_.at(tag);
-    else
+    } else {
       output[tag] = TagSettings();
+    }
   }
 
   return output;
@@ -458,15 +525,13 @@ std::map<std::string, TagSettings> AnalysisServiceSettings::GetTags(
 
 bool AnalysisServiceSettings::IsValid() const {
   // The settings are invalid if no provider was given.
-  if (!analysis_config_)
+  if (!analysis_config_) {
     return false;
+  }
 
   // The settings are invalid if no enabled pattern(s) exist since that would
   // imply no URL can ever have an analysis.
-  if (enabled_patterns_settings_.empty())
-    return false;
-
-  return true;
+  return !enabled_patterns_settings_.empty();
 }
 
 AnalysisServiceSettings::AnalysisServiceSettings(AnalysisServiceSettings&&) =
