@@ -33,8 +33,7 @@
 #include "chrome/browser/enterprise/connectors/analysis/page_print_request_handler.h"
 #include "chrome/browser/enterprise/connectors/common.h"
 #include "chrome/browser/enterprise/connectors/connectors_service.h"
-#include "chrome/browser/enterprise/data_controls/reporting_service.h"
-#include "chrome/browser/extensions/api/safe_browsing_private/safe_browsing_private_event_router.h"
+#include "chrome/browser/enterprise/connectors/referrer_cache_utils.h"
 #include "chrome/browser/file_util_service.h"
 #include "chrome/browser/policy/dm_token_utils.h"
 #include "chrome/browser/profiles/profile.h"
@@ -51,7 +50,6 @@
 #include "components/enterprise/common/proto/connectors.pb.h"
 #include "components/enterprise/connectors/core/analysis_settings.h"
 #include "components/enterprise/connectors/core/common.h"
-#include "components/enterprise/connectors/core/features.h"
 #include "components/enterprise/connectors/core/reporting_constants.h"
 #include "components/enterprise/connectors/core/reporting_utils.h"
 #include "components/guest_view/browser/guest_view_base.h"
@@ -500,16 +498,13 @@ ContentAnalysisDelegate::ContentAnalysisDelegate(
     CompletionCallback callback,
     DeepScanAccessPoint access_point)
     : data_(std::move(data)),
-      tab_id_(sessions::SessionTabHelper::IdForTab(web_contents)),
       callback_(std::move(callback)),
       access_point_(access_point),
       web_contents_(web_contents->GetWeakPtr()) {
   CHECK(web_contents);
   profile_ = Profile::FromBrowserContext(web_contents->GetBrowserContext());
   url_ = web_contents->GetLastCommittedURL();
-  if (base::FeatureList::IsEnabled(kEnterpriseIframeDlpRulesSupport)) {
-    frame_url_chain_ = CollectFrameUrls(web_contents, access_point_);
-  }
+  frame_url_chain_ = CollectFrameUrls(web_contents, access_point_);
   title_ = base::UTF16ToUTF8(web_contents->GetTitle());
   user_action_id_ = base::HexEncode(base::RandBytesAsVector(128));
   page_content_type_ = web_contents->GetContentsMimeType();
@@ -964,10 +959,15 @@ bool ContentAnalysisDelegate::text_request_required() const {
 }
 
 bool ContentAnalysisDelegate::image_request_required() const {
-  return !data_.image.empty() &&
-         data_.image.size() <=
-             data_.settings.cloud_or_local_settings.max_file_size() &&
-         data_.settings.cloud_or_local_settings.is_local_analysis();
+  if (data_.settings.cloud_or_local_settings.is_local_analysis() ||
+      base::FeatureList::IsEnabled(
+          enterprise_connectors::kDlpScanPastedImages)) {
+    return !data_.image.empty() &&
+           data_.image.size() <=
+               data_.settings.cloud_or_local_settings.max_file_size();
+  }
+
+  return false;
 }
 
 const AnalysisSettings& ContentAnalysisDelegate::settings() const {
@@ -1018,11 +1018,10 @@ ContentAnalysisRequest::Reason ContentAnalysisDelegate::reason() const {
 
 google::protobuf::RepeatedPtrField<safe_browsing::ReferrerChainEntry>
 ContentAnalysisDelegate::referrer_chain() const {
-  ReferrerChain referrers;
-  GetNavigationObserverManager()->IdentifyReferrerChainByEventURL(
-      url_, tab_id_, enterprise_connectors::kReferrerUserGestureLimit,
-      &referrers);
-  return referrers;
+  if (!web_contents_) {
+    return {};
+  }
+  return GetReferrerChain(url_, *web_contents_);
 }
 
 google::protobuf::RepeatedPtrField<std::string>
