@@ -102,6 +102,7 @@
 #include "extensions/browser/updater/extension_cache.h"
 #include "extensions/browser/updater/extension_downloader.h"
 #include "extensions/browser/updater/manifest_fetch_data.h"
+#include "extensions/buildflags/buildflags.h"
 #include "extensions/common/constants.h"
 #include "extensions/common/extension.h"
 #include "extensions/common/extension_features.h"
@@ -124,6 +125,8 @@
 #include "chrome/browser/upgrade_detector/upgrade_detector.h"
 #endif
 
+static_assert(BUILDFLAG(ENABLE_EXTENSIONS_CORE));
+
 using content::BrowserContext;
 using content::BrowserThread;
 using extensions::mojom::ManifestLocation;
@@ -144,11 +147,12 @@ const char* const kObsoleteComponentExtensionIds[] = {
     "jcgeabjmjgoblfofpppfkcoakmfobdko",  // Video Player
 };
 
-const char kBlockLoadCommandline[] = "command_line";
-
 // ExtensionUnpublishedAvailability policy default value.
 constexpr int kAllowUnpublishedExtensions = 0;
 
+#if !BUILDFLAG(GOOGLE_CHROME_BRANDING) || BUILDFLAG(IS_CHROMEOS)
+const char kBlockLoadCommandline[] = "command_line";
+
 bool ShouldBlockCommandLineExtension(Profile& profile) {
   const base::Value::List& list =
       profile.GetPrefs()->GetList(pref_names::kExtensionInstallTypeBlocklist);
@@ -160,6 +164,8 @@ bool ShouldBlockCommandLineExtension(Profile& profile) {
 
   return false;
 }
+#endif
+
 }  // namespace
 
 // ExtensionService.
@@ -392,12 +398,11 @@ void ExtensionService::LoadExtensionsFromCommandLineFlag(
 
   // Check that --load-extension is allowed.
   if (switch_name == switches::kLoadExtension) {
-    if (base::FeatureList::IsEnabled(
-            extensions_features::kDisableLoadExtensionCommandLineSwitch)) {
-      LOG(WARNING)
-          << "--load-extension is not allowed in Google Chrome, ignoring.";
-      return;
-    }
+#if BUILDFLAG(GOOGLE_CHROME_BRANDING) && !BUILDFLAG(IS_CHROMEOS)
+    LOG(WARNING)
+        << "--load-extension is not allowed in Google Chrome, ignoring.";
+    return;
+#else   // BUILDFLAG(GOOGLE_CHROME_BRANDING) && !BUILDFLAG(IS_CHROMEOS)
     if (ShouldBlockCommandLineExtension(*profile_)) {
       // TODO(crbug.com/401529219): Deprecate this restriction once
       // --load-extension removal on Chrome builds is fully launched.
@@ -406,6 +411,7 @@ void ExtensionService::LoadExtensionsFromCommandLineFlag(
           << "ExtensionInstallTypeBlocklist::command_line, ignoring.";
       return;
     }
+#endif  // BUILDFLAG(GOOGLE_CHROME_BRANDING) && !BUILDFLAG(IS_CHROMEOS)
   } else if (base::FeatureList::IsEnabled(
                  extensions_features::
                      kDisableDisableExtensionsExceptCommandLineSwitch)) {
