@@ -23,6 +23,7 @@
 #include "base/metrics/field_trial_params.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/notreached.h"
+#include "base/strings/strcat.h"
 #include "base/strings/string_split.h"
 #include "base/strings/string_util.h"
 #include "base/strings/string_view_util.h"
@@ -77,6 +78,7 @@
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/first_party_sets_handler.h"
 #include "content/public/browser/network_service_instance.h"
+#include "content/public/browser/reduce_accept_language_utils.h"
 #include "content/public/browser/shared_cors_origin_access_list.h"
 #include "content/public/browser/storage_partition.h"
 #include "content/public/common/url_constants.h"
@@ -85,6 +87,7 @@
 #include "net/base/features.h"
 #include "net/cert/asn1_util.h"
 #include "net/disk_cache/backend_experiment.h"
+#include "net/disk_cache/buildflags.h"
 #include "net/http/http_auth_preferences.h"
 #include "net/http/http_util.h"
 #include "net/net_buildflags.h"
@@ -103,7 +106,6 @@
 #include "ash/constants/ash_features.h"
 #include "ash/constants/ash_switches.h"
 #include "chrome/browser/ash/kcer/kcer_factory_ash.h"
-#include "chrome/browser/ash/net/client_cert_store_ash.h"
 #include "chrome/browser/ash/net/client_cert_store_kcer.h"
 #include "chrome/browser/ash/profiles/profile_helper.h"
 #include "chrome/browser/certificate_provider/certificate_provider.h"
@@ -132,11 +134,16 @@
 #include "net/ssl/client_cert_store_mac.h"
 #endif  // BUILDFLAG(IS_MAC)
 
+#if BUILDFLAG(IS_ANDROID)
+#include "net/ssl/client_cert_store_empty.h"
+#endif  // BUILDFLAG(IS_ANDROID)
+
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "extensions/common/constants.h"
 #endif
 
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || \
+    BUILDFLAG(IS_ANDROID)
 #include "chrome/browser/enterprise/client_certificates/certificate_provisioning_service_factory.h"
 #include "chrome/browser/policy/chrome_browser_policy_connector.h"
 #include "components/enterprise/browser/controller/chrome_browser_cloud_management_controller.h"
@@ -269,6 +276,14 @@ void UpdateCookieSettings(Profile* profile, ContentSettingsType type) {
   } else {
     settings = HostContentSettingsMapFactory::GetForProfile(profile)
                    ->GetSettingsForOneType(type);
+    if (type == ContentSettingsType::STORAGE_ACCESS ||
+        type == ContentSettingsType::TOP_LEVEL_STORAGE_ACCESS) {
+      // The network service only cares about "granted" settings, so we don't
+      // bother to send any others.
+      std::erase_if(settings, [](const auto& setting) {
+        return setting.GetContentSetting() != CONTENT_SETTING_ALLOW;
+      });
+    }
   }
   profile->ForEachLoadedStoragePartition(
       [&](content::StoragePartition* storage_partition) {
@@ -277,14 +292,14 @@ void UpdateCookieSettings(Profile* profile, ContentSettingsType type) {
       });
 }
 
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
+#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || \
+    BUILDFLAG(IS_ANDROID)
 std::unique_ptr<net::ClientCertStore> GetWrappedCertStore(
     Profile* profile,
     std::unique_ptr<net::ClientCertStore> platform_store) {
   client_certificates::CertificateProvisioningService*
       profile_provisioning_service = nullptr;
-  if (profile && client_certificates::features::
-                     IsManagedClientCertificateForUserEnabled()) {
+  if (profile) {
     profile_provisioning_service = client_certificates::
         CertificateProvisioningServiceFactory::GetForProfile(profile);
   }
@@ -307,7 +322,8 @@ std::unique_ptr<net::ClientCertStore> GetWrappedCertStore(
       profile_provisioning_service, browser_provisioning_service,
       std::move(platform_store));
 }
-#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
+#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) ||
+        // BUILDFLAG(IS_ANDROID)
 
 bool IsValidDNSConstraint(std::string_view possible_dns_constraint) {
   return base::IsStringASCII(possible_dns_constraint) &&
@@ -401,6 +417,55 @@ bool NeedsIpProtection(const IpProtectionCoreHost* ipp_core_host,
                            !net::features::kIpPrivacyOnlyInIncognito.Get());
 }
 
+constexpr std::string_view kDiskCacheExperimentNameSeparator = " ";
+constexpr std::string_view kDiskCacheExperimentNameNone = "None";
+
+bool GetHttpCacheBackendResetParam(PrefService* local_state) {
+  // Get the field trial groups.  If the server cannot be reached, then
+  // this corresponds to "None" for each experiment.
+  base::FieldTrial* isolation_key_field_trial =
+      base::FeatureList::GetFieldTrial(
+          net::features::kSplitCacheByNetworkIsolationKey);
+  base::FieldTrial* credentials_field_trial = base::FeatureList::GetFieldTrial(
+      net::features::kSplitCacheByIncludeCredentials);
+  base::FieldTrial* backend_field_trial = base::FeatureList::GetFieldTrial(
+      net::features::kDiskCacheBackendExperiment);
+
+  std::vector<std::string_view> experiment_parts;
+  // SplitCacheByNetworkIsolationKey experiment:
+  experiment_parts.push_back(isolation_key_field_trial
+                                 ? isolation_key_field_trial->group_name()
+                                 : kDiskCacheExperimentNameNone);
+  // This used to be used for keying on main frame only vs main frame +
+  // innermost frame, but the feature was removed, and now it's always
+  // keyed on both.
+  experiment_parts.push_back(kDiskCacheExperimentNameNone);
+  // This used to be for keying on scheme + eTLD+1 vs origin, but the trial
+  // was removed, and now it's always keyed on eTLD+1. Still keeping a
+  // third "None" to avoid resetting the disk cache.
+  experiment_parts.push_back(kDiskCacheExperimentNameNone);
+  // SplitCacheByIncludeCredentials experiment:
+  experiment_parts.push_back(credentials_field_trial
+                                 ? credentials_field_trial->group_name()
+                                 : kDiskCacheExperimentNameNone);
+
+  // Add the disk cache backend experiment group if active.
+  if (backend_field_trial) {
+    experiment_parts.push_back(backend_field_trial->group_name());
+  }
+
+  const std::string current_field_trial_status =
+      base::JoinString(experiment_parts, kDiskCacheExperimentNameSeparator);
+
+  const std::string previous_field_trial_status =
+      local_state->GetString(kHttpCacheFinchExperimentGroups);
+  local_state->SetString(kHttpCacheFinchExperimentGroups,
+                         current_field_trial_status);
+
+  return !previous_field_trial_status.empty() &&
+         current_field_trial_status != previous_field_trial_status;
+}
+
 }  // namespace
 
 ProfileNetworkContextService::ProfileNetworkContextService(Profile* profile)
@@ -459,22 +524,20 @@ ProfileNetworkContextService::ProfileNetworkContextService(Profile* profile)
 #endif
 
 #if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
-  if (base::FeatureList::IsEnabled(features::kEnableCertManagementUIV2Write)) {
-    // Register observer to update certificates when changes are made to the
-    // server cert database. Unretained is safe as the
-    // `server_cert_database_observer_` is a CallbackListSubscription which
-    // will unregister the observer once the ProfileNetworkContextService is
-    // destroyed.
-    net::ServerCertificateDatabaseService* server_cert_db_service =
-        net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
-            profile_);
-    // The service can be null for AshInternals profiles.
-    if (server_cert_db_service) {
-      server_cert_database_observer_ =
-          server_cert_db_service->AddObserver(base::BindRepeating(
-              &ProfileNetworkContextService::UpdateAdditionalCertificates,
-              base::Unretained(this)));
-    }
+  // Register observer to update certificates when changes are made to the
+  // server cert database. Unretained is safe as the
+  // `server_cert_database_observer_` is a CallbackListSubscription which
+  // will unregister the observer once the ProfileNetworkContextService is
+  // destroyed.
+  net::ServerCertificateDatabaseService* server_cert_db_service =
+      net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
+          profile_);
+  // The service can be null for AshInternals profiles.
+  if (server_cert_db_service) {
+    server_cert_database_observer_ =
+        server_cert_db_service->AddObserver(base::BindRepeating(
+            &ProfileNetworkContextService::UpdateAdditionalCertificates,
+            base::Unretained(this)));
   }
 #endif
 
@@ -625,7 +688,9 @@ std::string ProfileNetworkContextService::ComputeAcceptLanguage() const {
     return ComputeAcceptLanguageFromPref(
         language::GetFirstLanguage(pref_accept_language_.GetValue()));
   }
-  return ComputeAcceptLanguageFromPref(pref_accept_language_.GetValue());
+  return ComputeAcceptLanguageFromPref(
+      content::ReduceAcceptLanguageUtils::GetLanguagesWithMaxCount(
+          pref_accept_language_.GetValue()));
 }
 
 void ProfileNetworkContextService::UpdateReferrersEnabled() {
@@ -836,19 +901,17 @@ void ProfileNetworkContextService::UpdateAdditionalCertificates() {
   CHECK(!is_shutting_down_);
 
 #if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
-  if (base::FeatureList::IsEnabled(features::kEnableCertManagementUIV2Write)) {
-    net::ServerCertificateDatabaseService* cert_db_service =
-        net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
-            profile_);
-    // The service can be null for AshInternals profiles. If it's null, fall
-    // through to updating the additional certs without it.
-    if (cert_db_service) {
-      cert_db_service->GetAllCertificates(
-          base::BindOnce(&ProfileNetworkContextService::
-                             UpdateAdditionalCertificatesWithUserAddedCerts,
-                         weak_factory_.GetWeakPtr()));
-      return;
-    }
+  net::ServerCertificateDatabaseService* cert_db_service =
+      net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
+          profile_);
+  // The service can be null for AshInternals profiles. If it's null, fall
+  // through to updating the additional certs without it.
+  if (cert_db_service) {
+    cert_db_service->GetAllCertificates(
+        base::BindOnce(&ProfileNetworkContextService::
+                           UpdateAdditionalCertificatesWithUserAddedCerts,
+                       weak_factory_.GetWeakPtr()));
+    return;
   }
 #endif
   profile_->ForEachLoadedStoragePartition(
@@ -1134,21 +1197,17 @@ void ProfileNetworkContextService::CreateClientCertIssuerSourcesWithDBCerts(
         std::move(certs)));
   }
 
-  // Intermediates from NSS are used unconditionally. There are 2 reasons why
-  // the NSS source is used:
-  // 1) If the ServerCertificateDatabase feature is not enabled
-  // (kEnableCertManagementUIV2Write is false), user-added intermediates
-  // still come from NSS, so checking NSS is required.
-  // 2) Device-wide ONC intermediate certificates may be needed as well. It's
-  // unclear if the use of device-wide policy in non-signin-profile client cert
-  // verification was intended or just an accidental side effect of NSS state
-  // being global, but enterprises might be depending on it (at least one
-  // browser_test depends on it:
+  // Intermediates from NSS are used unconditionally as device-wide ONC
+  // intermediate certificates may be needed. It's unclear if the use of
+  // device-wide policy in non-signin-profile client cert verification was
+  // intended or just an accidental side effect of NSS state being global, but
+  // enterprises might be depending on it (at least one browser_test depends on
+  // it:
   // SuccessViaCaAndIntermediate/SigninFrameWebviewClientCertsLoginTest.LockscreenTest/0).
-  // TODO(https://crbug.com/40554868): once kEnableCertManagementUIV2Write has
-  // fully launched, consider removing the NSS source and making this read from
-  // the device ONC policy directly (or decide if using the device ONC policy
-  // here is not intended and change the test to not do that).
+  // TODO(https://crbug.com/40554868): consider removing the NSS source and
+  // making this read from the device ONC policy directly, or decide if using
+  // the device ONC policy here is not intended and remove and change the test
+  // to not do that.
   sources.push_back(
       std::make_unique<net::ClientCertStoreNSS::IssuerSourceNSS>());
 
@@ -1157,19 +1216,16 @@ void ProfileNetworkContextService::CreateClientCertIssuerSourcesWithDBCerts(
 
 void ProfileNetworkContextService::CreateClientCertIssuerSources(
     net::ClientCertIssuerSourceGetterCallback callback) {
-  if (base::FeatureList::IsEnabled(features::kEnableCertManagementUIV2Write)) {
-    net::ServerCertificateDatabaseService* cert_db_service =
-        net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
-            profile_);
-    // The service can be null for AshInternals profiles. If it's null fall
-    // through to creating the ClientCertIssuerSource without it.
-    if (cert_db_service) {
-      cert_db_service->GetAllCertificates(
-          base::BindOnce(&ProfileNetworkContextService::
-                             CreateClientCertIssuerSourcesWithDBCerts,
-                         weak_factory_.GetWeakPtr(), std::move(callback)));
-      return;
-    }
+  net::ServerCertificateDatabaseService* cert_db_service =
+      net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
+          profile_);
+  // The service can be null for AshInternals profiles. If it's null fall
+  // through to creating the ClientCertIssuerSource without it.
+  if (cert_db_service) {
+    cert_db_service->GetAllCertificates(base::BindOnce(
+        &ProfileNetworkContextService::CreateClientCertIssuerSourcesWithDBCerts,
+        weak_factory_.GetWeakPtr(), std::move(callback)));
+    return;
   }
 
   CreateClientCertIssuerSourcesWithDBCerts(std::move(callback),
@@ -1204,41 +1260,9 @@ ProfileNetworkContextService::CreateClientCertStore() {
 #endif
 
 #if BUILDFLAG(IS_CHROMEOS)
-  bool use_system_key_slot = false;
-  // Enable client certificates for the Chrome OS sign-in frame, if this feature
-  // is not disabled by a flag.
-  // Note that while this applies to the whole sign-in profile / lock screen
-  // profile, client certificates will only be selected for the StoragePartition
-  // currently used in the sign-in frame (see SigninPartitionManager).
-  if (ash::ProfileHelper::IsSigninProfile(profile_) ||
-      ash::ProfileHelper::IsLockScreenProfile(profile_)) {
-    use_system_key_slot = true;
-  }
-
-  if (ash::features::ShouldUseKcerClientCertStore()) {
-    return std::make_unique<ash::ClientCertStoreKcer>(
-        std::move(certificate_provider),
-        kcer::KcerFactoryAsh::GetKcer(profile_),
-        GetClientCertIssuerSourceFactory());
-  } else {
-    std::string username_hash;
-    const user_manager::User* user =
-        ash::ProfileHelper::Get()->GetUserByProfile(profile_);
-    if (user && !user->username_hash().empty()) {
-      username_hash = user->username_hash();
-
-      // Use the device-wide system key slot only if the user is affiliated on
-      // the device.
-      if (user->IsAffiliated()) {
-        use_system_key_slot = true;
-      }
-    }
-
-    return std::make_unique<ash::ClientCertStoreAsh>(
-        std::move(certificate_provider), use_system_key_slot, username_hash,
-        base::BindRepeating(&CreateCryptoModuleBlockingPasswordDelegate,
-                            kCryptoModulePasswordClientAuth));
-  }
+  return std::make_unique<ash::ClientCertStoreKcer>(
+      std::move(certificate_provider), kcer::KcerFactoryAsh::GetKcer(profile_),
+      GetClientCertIssuerSourceFactory());
 
 #elif BUILDFLAG(USE_NSS_CERTS)
   std::unique_ptr<net::ClientCertStore> store =
@@ -1257,53 +1281,19 @@ ProfileNetworkContextService::CreateClientCertStore() {
   return GetWrappedCertStore(profile_,
                              std::make_unique<net::ClientCertStoreMac>());
 #elif BUILDFLAG(IS_ANDROID)
-  // Android does not use the ClientCertStore infrastructure. On Android client
-  // cert matching is done by the OS as part of the call to show the cert
-  // selection dialog.
-  return nullptr;
+  // On Android client we don't use a platform client cert store, but we still
+  // need to use Chrome profile and browser level stores, so we wrap the empty
+  // store to use it as a platform cert store.
+  // The certificate matching for android will first try to find a matching cert
+  // in the profile/browser stores, and if none is found, it will proceed with
+  // the OS as part of the call to show the cert selection dialog.
+  return GetWrappedCertStore(profile_,
+                             std::make_unique<net::ClientCertStoreEmpty>());
 #else
 #error Unknown platform.
 #endif
 }
 
-bool GetHttpCacheBackendResetParam(PrefService* local_state) {
-  // Get the field trial groups.  If the server cannot be reached, then
-  // this corresponds to "None" for each experiment.
-  base::FieldTrial* field_trial = base::FeatureList::GetFieldTrial(
-      net::features::kSplitCacheByNetworkIsolationKey);
-  std::string current_field_trial_status =
-      (field_trial ? field_trial->group_name() : "None");
-  // This used to be used for keying on main frame only vs main frame +
-  // innermost frame, but the feature was removed, and now it's always keyed on
-  // both.
-  current_field_trial_status += " None";
-  // This used to be for keying on scheme + eTLD+1 vs origin, but the trial was
-  // removed, and now it's always keyed on eTLD+1. Still keeping a third "None"
-  // to avoid resetting the disk cache.
-  current_field_trial_status += " None ";
-
-  field_trial = base::FeatureList::GetFieldTrial(
-      net::features::kSplitCacheByIncludeCredentials);
-  current_field_trial_status +=
-      (field_trial ? field_trial->group_name() : "None");
-
-  if (disk_cache::InBackendExperiment()) {
-    if (disk_cache::InSimpleBackendExperimentGroup()) {
-      current_field_trial_status += " 20241007-DiskCache-Simple";
-    } else {
-      current_field_trial_status += " 20241007-DiskCache-Blockfile";
-    }
-  }
-
-  std::string previous_field_trial_status =
-      local_state->GetString(kHttpCacheFinchExperimentGroups);
-  local_state->SetString(kHttpCacheFinchExperimentGroups,
-                         current_field_trial_status);
-
-  return !previous_field_trial_status.empty() &&
-         current_field_trial_status != previous_field_trial_status;
-}
-
 void ProfileNetworkContextService::ConfigureNetworkContextParamsInternal(
     bool in_memory,
     const base::FilePath& relative_partition_path,
@@ -1321,7 +1311,6 @@ void ProfileNetworkContextService::ConfigureNetworkContextParamsInternal(
   g_browser_process->system_network_context_manager()
       ->ConfigureDefaultNetworkContextParams(network_context_params);
 
-  network_context_params->enable_zstd = true;
   network_context_params->accept_language = ComputeAcceptLanguage();
   network_context_params->enable_referrers = enable_referrers_.GetValue();
 
@@ -1494,8 +1483,7 @@ void ProfileNetworkContextService::ConfigureNetworkContextParamsInternal(
   // add an isManaged() check here.
 
 #if BUILDFLAG(CHROME_ROOT_STORE_CERT_MANAGEMENT_UI)
-  if (base::FeatureList::IsEnabled(features::kEnableCertManagementUIV2Write) &&
-      net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
+  if (net::ServerCertificateDatabaseServiceFactory::GetForBrowserContext(
           profile_)) {
     cert_verifier_creation_params->wait_for_update = true;
     UpdateAdditionalCertificates();
@@ -1568,11 +1556,22 @@ void ProfileNetworkContextService::ConfigureNetworkContextParamsInternal(
         ipp_core_host->IsIpProtectionEnabled();
     network_context_params->ip_protection_incognito =
         profile_->IsIncognitoProfile();
+    if (profile_->IsIncognitoProfile()) {
+      network_context_params->initial_ip_protection_tokens =
+          ipp_core_host->TakeRecycledTokens();
+    }
     if (base::CommandLine::ForCurrentProcess()->HasSwitch(
             network::switches::kStoreProbabilisticRevealTokens)) {
       network_context_params->ip_protection_data_directory =
           profile_->GetPath();
     }
+
+    ContentSettingsForOneType tracking_protection_content_settings =
+        HostContentSettingsMapFactory::GetForProfile(profile_)
+            ->GetSettingsForOneType(ContentSettingsType::TRACKING_PROTECTION);
+
+    network_context_params->tracking_protection_content_settings =
+        std::move(tracking_protection_content_settings);
   }
 
   network_context_params->device_bound_sessions_enabled =
