@@ -54,8 +54,8 @@
 
 #if BUILDFLAG(ENABLE_GLIC)
 #include "chrome/browser/background/startup_launch_manager.h"
-#include "chrome/browser/glic/glic_enabling.h"
 #include "chrome/browser/glic/glic_pref_names.h"
+#include "chrome/browser/glic/public/glic_enabling.h"
 #endif
 
 using signin::constants::kNoHostedDomainFound;
