@@ -34,7 +34,9 @@
 #include "chrome/browser/signin/signin_util.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_dialogs.h"
+#include "chrome/browser/ui/startup/startup_tab_provider.h"
 #include "chrome/browser/ui/startup/startup_types.h"
+#include "chrome/common/chrome_switches.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/common/url_constants.h"
 #include "components/prefs/pref_service.h"
@@ -82,7 +84,8 @@ void FindOrCreateNewWindowForProfile(
     Profile* profile,
     chrome::startup::IsProcessStartup process_startup,
     chrome::startup::IsFirstRun is_first_run,
-    bool always_create) {
+    bool always_create,
+    bool open_command_line_urls) {
   DCHECK(profile);
   TRACE_EVENT1("browser", "FindOrCreateNewWindowForProfile", "profile_path",
                profile->GetPath());
@@ -98,6 +101,21 @@ void FindOrCreateNewWindowForProfile(
   base::RecordAction(UserMetricsAction("NewWindow"));
   base::CommandLine command_line(base::CommandLine::NO_PROGRAM);
   StartupBrowserCreator browser_creator;
+
+#if !BUILDFLAG(IS_CHROMEOS)
+  if (open_command_line_urls) {
+    auto* current_command_line = base::CommandLine::ForCurrentProcess();
+    StartupTabProviderImpl startup_tab_provider;
+    StartupTabs tabs = startup_tab_provider.GetCommandLineTabs(
+        *current_command_line, base::FilePath(), profile);
+    for (const auto& tab : tabs) {
+      if (tab.url.is_valid()) {
+        command_line.AppendArg(tab.url.spec());
+      }
+    }
+  }
+#endif  // !BUILDFLAG(IS_CHROMEOS)
+
   // This is not a browser launch from the user; don't record the launch mode.
   browser_creator.LaunchBrowser(command_line, profile, base::FilePath(),
                                 process_startup, is_first_run,
@@ -107,6 +125,7 @@ void FindOrCreateNewWindowForProfile(
 void OpenBrowserWindowForProfile(base::OnceCallback<void(Browser*)> callback,
                                  bool always_create,
                                  bool is_new_profile,
+                                 bool open_command_line_urls,
                                  Profile* profile) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   TRACE_EVENT1("browser", "OpenBrowserWindowForProfile", "profile_path",
@@ -175,8 +194,8 @@ void OpenBrowserWindowForProfile(base::OnceCallback<void(Browser*)> callback,
   // existed, which means that here a browser definitely needs to be created.
   // Passing true for |always_create| means we won't duplicate the code that
   // tries to find a browser.
-  profiles::FindOrCreateNewWindowForProfile(profile, process_startup,
-                                            is_first_run, true);
+  profiles::FindOrCreateNewWindowForProfile(
+      profile, process_startup, is_first_run, true, open_command_line_urls);
 }
 
 #if !BUILDFLAG(IS_ANDROID)
@@ -189,11 +208,12 @@ void LoadProfileAsync(const base::FilePath& path,
 
 void SwitchToProfile(const base::FilePath& path,
                      bool always_create,
-                     base::OnceCallback<void(Browser*)> callback) {
+                     base::OnceCallback<void(Browser*)> callback,
+                     bool open_command_line_urls) {
   base::OnceCallback<void(Profile*)> open_browser_callback =
       base::BindOnce(&profiles::OpenBrowserWindowForProfile,
                      std::move(callback), always_create,
-                     /*is_new_profile=*/false);
+                     /*is_new_profile=*/false, open_command_line_urls);
   g_browser_process->profile_manager()->CreateProfileAsync(
       path,
       base::BindOnce(&ProfileLoadedCallback, std::move(open_browser_callback)));
