@@ -59,6 +59,7 @@
 #include "components/version_info/channel.h"
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/storage_partition.h"
+#include "google_apis/gaia/gaia_auth_fetcher.h"
 #include "google_apis/gaia/gaia_constants.h"
 #include "google_apis/gaia/gaia_urls.h"
 #include "ui/base/models/tree_node_iterator.h"
@@ -311,23 +312,21 @@ void ChromeSigninClient::RemoveContentSettingsObserver(
       observer);
 }
 
-bool ChromeSigninClient::IsClearPrimaryAccountAllowed(
-    bool has_sync_account) const {
-  return GetSignoutDecision(has_sync_account,
-                            /*signout_source=*/std::nullopt) ==
+bool ChromeSigninClient::IsClearPrimaryAccountAllowed() const {
+  return GetSignoutDecision(
+             /*signout_source=*/std::nullopt) ==
          SigninClient::SignoutDecision::ALLOW;
 }
 
 bool ChromeSigninClient::IsRevokeSyncConsentAllowed() const {
-  return GetSignoutDecision(/*has_sync_account=*/true,
-                            /*signout_source=*/std::nullopt) !=
+  return GetSignoutDecision(
+             /*signout_source=*/std::nullopt) !=
          SigninClient::SignoutDecision::REVOKE_SYNC_DISALLOWED;
 }
 
 void ChromeSigninClient::PreSignOut(
     base::OnceCallback<void(SignoutDecision)> on_signout_decision_reached,
-    signin_metrics::ProfileSignout signout_source_metric,
-    bool has_sync_account) {
+    signin_metrics::ProfileSignout signout_source_metric) {
   DCHECK(on_signout_decision_reached);
   DCHECK(!on_signout_decision_reached_) << "SignOut already in-progress!";
   on_signout_decision_reached_ = std::move(on_signout_decision_reached);
@@ -364,7 +363,7 @@ void ChromeSigninClient::PreSignOut(
         profile_,
         base::BindRepeating(&ChromeSigninClient::OnCloseBrowsersSuccess,
                             base::Unretained(this), signout_source_metric,
-                            /*should_sign_out=*/true, has_sync_account),
+                            /*should_sign_out=*/true),
         base::BindRepeating(&ChromeSigninClient::OnCloseBrowsersAborted,
                             base::Unretained(this)),
         signout_source_metric == signin_metrics::ProfileSignout::kAbortSignin ||
@@ -378,7 +377,7 @@ void ChromeSigninClient::PreSignOut(
   {
 #endif
     std::move(on_signout_decision_reached_)
-        .Run(GetSignoutDecision(has_sync_account, signout_source_metric));
+        .Run(GetSignoutDecision(signout_source_metric));
   }
 }
 
@@ -448,18 +447,22 @@ void ChromeSigninClient::OnPrimaryAccountChanged(
 std::unique_ptr<signin::BoundSessionOAuthMultiLoginDelegate>
 ChromeSigninClient::CreateBoundSessionOAuthMultiloginDelegate() const {
 #if BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
-  if (BoundSessionCookieRefreshService* bound_session_cookie_refresh_service =
-          BoundSessionCookieRefreshServiceFactory::GetForProfile(profile_);
-      bound_session_cookie_refresh_service) {
+  if (!base::FeatureList::IsEnabled(
+          switches::kEnableOAuthMultiloginCookiesBinding)) {
+    return nullptr;
+  }
+  BoundSessionCookieRefreshService* bound_session_cookie_refresh_service =
+      BoundSessionCookieRefreshServiceFactory::GetForProfile(profile_);
+  if (bound_session_cookie_refresh_service) {
     return std::make_unique<BoundSessionOAuthMultiLoginDelegateImpl>(
-        bound_session_cookie_refresh_service->GetWeakPtr());
+        bound_session_cookie_refresh_service->GetWeakPtr(),
+        IdentityManagerFactory::GetForProfile(profile_));
   }
 #endif  // BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
   return nullptr;
 }
 
 SigninClient::SignoutDecision ChromeSigninClient::GetSignoutDecision(
-    bool has_sync_account,
     const std::optional<signin_metrics::ProfileSignout> signout_source) const {
   // TODO(crbug.com/40239707): Revisit |kAlwaysAllowedSignoutSources|.
   for (const auto& always_allowed_source : kAlwaysAllowedSignoutSources) {
@@ -527,9 +530,7 @@ void ChromeSigninClient::OnTokenFetchComplete(bool token_is_valid) {
           signin_metrics::ProfileSignout::kAuthenticationFailedWithForceSignin,
           // Do not sign the user out to allow them to reauthenticate from the
           // profile picker.
-          /*should_sign_out=*/false,
-          // Sync value is not used since we are not signing out.
-          /*has_sync_account=*/false),
+          /*should_sign_out=*/false),
       /*on_close_aborted=*/base::DoNothing(),
       /*skip_beforeunload=*/true);
 }
@@ -582,7 +583,6 @@ void ChromeSigninClient::SetURLLoaderFactoryForTest(
 void ChromeSigninClient::OnCloseBrowsersSuccess(
     const signin_metrics::ProfileSignout signout_source_metric,
     bool should_sign_out,
-    bool has_sync_account,
     const base::FilePath& profile_path) {
 #if !BUILDFLAG(IS_ANDROID) && !BUILDFLAG(IS_CHROMEOS)
   if (signin_util::IsForceSigninEnabled() && force_signin_verifier_.get()) {
@@ -592,7 +592,7 @@ void ChromeSigninClient::OnCloseBrowsersSuccess(
 
   if (should_sign_out) {
     std::move(on_signout_decision_reached_)
-        .Run(GetSignoutDecision(has_sync_account, signout_source_metric));
+        .Run(GetSignoutDecision(signout_source_metric));
   }
 
   LockForceSigninProfile(profile_path);
