@@ -4,25 +4,32 @@
 
 #include "chrome/browser/signin/signin_promo_util.h"
 
+#include "base/check_deref.h"
+#include "base/notreached.h"
 #include "chrome/browser/browser_process.h"
+#include "chrome/browser/profiles/batch_upload/batch_upload_service.h"
+#include "chrome/browser/profiles/batch_upload/batch_upload_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
 #include "chrome/browser/signin/signin_promo.h"
+#include "chrome/browser/ui/webui/signin/signin_ui_error.h"
 #include "chrome/common/pref_names.h"
 #include "components/prefs/pref_service.h"
 #include "components/signin/public/base/consent_level.h"
 #include "components/signin/public/base/signin_metrics.h"
 #include "components/signin/public/base/signin_pref_names.h"
-#include "components/signin/public/base/signin_prefs.h"
 #include "components/signin/public/base/signin_switches.h"
 #include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/signin/public/identity_manager/primary_account_mutator.h"
 #include "components/sync/base/features.h"
 #include "components/sync_bookmarks/switches.h"
+#include "google_apis/gaia/core_account_id.h"
+#include "google_apis/gaia/gaia_id.h"
 #include "net/base/network_change_notifier.h"
 
 #if !BUILDFLAG(IS_ANDROID)
 #include "chrome/browser/sync/sync_service_factory.h"
+#include "chrome/browser/ui/webui/signin/signin_utils_desktop.h"
 #include "components/sync/service/sync_prefs.h"
 #endif  // !BUILDFLAG(IS_ANDROID)
 
@@ -42,15 +49,162 @@
 #include "components/sync/service/sync_service.h"
 #include "components/sync/service/sync_user_settings.h"
 #include "components/user_education/common/user_education_features.h"
+#endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
+
+namespace signin {
 
 namespace {
 
+#if BUILDFLAG(ENABLE_DICE_SUPPORT)
+
 using signin::SignInPromoType;
 using signin_util::SignedInState;
 
 constexpr int kSigninPromoShownThreshold = 5;
 constexpr int kSigninPromoDismissedThreshold = 2;
 
+// Prefs that are part of the dictionary from
+// `SigninPrefs::GetOrCreateAvatarButtonPromoCountDictionary()` that maps the
+// used and shown counts for the promos listed in
+// `ProfileMenuAvatarButtonPromoInfo::Type` (Except for
+// `ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo`).
+constexpr char kAvatarButtonHistorySyncPromoShownCount[] =
+    "AvatarButtonHistorySyncPromoShownCount";
+constexpr char kAvatarButtonHistorySyncPromoUsedCount[] =
+    "AvatarButtonHistorySyncPromoUsedCount";
+constexpr char kAvatarButtonBatchUploadPromoShownCount[] =
+    "AvatarButtonBatchUploadPromoShownCount";
+constexpr char kAvatarButtonBatchUploadPromoUsedCount[] =
+    "AvatarButtonBatchUploadPromoUsedCount";
+constexpr char kAvatarButtonBatchUploadBookmarkPromoShownCount[] =
+    "AvatarButtonBatchUploadBookmarkPromoShownCount";
+constexpr char kAvatarButtonBatchUploadBookmarkPromoUsedCount[] =
+    "AvatarButtonBatchUploadBookmarkPromoUsedCount";
+constexpr char kAvatarButtonBatchUploadWindows10DepreciationPromoShownCount[] =
+    "AvatarButtonBatchUploadWindows10DepreciationPromoShownCount";
+constexpr char kAvatarButtonBatchUploadWindows10DepreciationPromoUsedCount[] =
+    "AvatarButtonBatchUploadWindows10DepreciationPromoUsedCount";
+
+const char* GetAvatarButtonPromoShownKey(
+    ProfileMenuAvatarButtonPromoInfo::Type promo_type) {
+  switch (promo_type) {
+    case ProfileMenuAvatarButtonPromoInfo::Type::kHistorySyncPromo:
+      return kAvatarButtonHistorySyncPromoShownCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kBatchUploadPromo:
+      return kAvatarButtonBatchUploadPromoShownCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kBatchUploadBookmarksPromo:
+      return kAvatarButtonBatchUploadBookmarkPromoShownCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::
+        kBatchUploadWindows10DepreciationPromo:
+      CHECK(switches::IsSigninWindows10DepreciationState());
+      return kAvatarButtonBatchUploadWindows10DepreciationPromoShownCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo:
+      NOTREACHED() << "SyncPromo uses the SigninPrefs values directly";
+  }
+}
+
+const char* GetAvatarButtonPromoUsedKey(
+    ProfileMenuAvatarButtonPromoInfo::Type promo_type) {
+  switch (promo_type) {
+    case ProfileMenuAvatarButtonPromoInfo::Type::kHistorySyncPromo:
+      return kAvatarButtonHistorySyncPromoUsedCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kBatchUploadPromo:
+      return kAvatarButtonBatchUploadPromoUsedCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kBatchUploadBookmarksPromo:
+      return kAvatarButtonBatchUploadBookmarkPromoUsedCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::
+        kBatchUploadWindows10DepreciationPromo:
+      CHECK(switches::IsSigninWindows10DepreciationState());
+      return kAvatarButtonBatchUploadWindows10DepreciationPromoUsedCount;
+    case ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo:
+      NOTREACHED() << "SyncPromo uses the SigninPrefs values directly";
+  }
+}
+
+bool WasPreviouslySyncingWithPrimaryAccount(Profile* profile) {
+  const GaiaId last_syncing_gaia_id(
+      profile->GetPrefs()->GetString(prefs::kGoogleServicesLastSyncingGaiaId));
+  if (last_syncing_gaia_id.empty()) {
+    return false;
+  }
+
+  const GaiaId primary_account_gaia_id =
+      IdentityManagerFactory::GetForProfile(profile)
+          ->GetPrimaryAccountInfo(ConsentLevel::kSignin)
+          .gaia;
+  if (primary_account_gaia_id.empty()) {
+    return false;
+  }
+
+  return last_syncing_gaia_id == primary_account_gaia_id;
+}
+
+void ComputeProfileMenuAvatarButtonPromoInfoWithBatchUploadResult(
+    Profile* profile,
+    base::OnceCallback<void(ProfileMenuAvatarButtonPromoInfo)> result_callback,
+    std::map<syncer::DataType, syncer::LocalDataDescription> local_map_result) {
+  CHECK(
+      base::FeatureList::IsEnabled(syncer::kReplaceSyncPromosWithSignInPromos));
+
+  size_t local_data_count = std::accumulate(
+      local_map_result.begin(), local_map_result.end(), 0u,
+      [](size_t current_count,
+         std::pair<syncer::DataType, syncer::LocalDataDescription> local_data) {
+        return current_count + local_data.second.local_data_models.size();
+      });
+
+  // Batch Upload promo: Windows 10 depreciation promo.
+  // TODO(crbug.com/447048341): Confirm whether additional requirements are
+  // needed for this promo (e.g. minimum cookie age, cross account error).
+  if (local_data_count > 0 && switches::IsSigninWindows10DepreciationState()) {
+    std::move(result_callback)
+        .Run(ProfileMenuAvatarButtonPromoInfo{
+            .type = ProfileMenuAvatarButtonPromoInfo::Type::
+                kBatchUploadWindows10DepreciationPromo,
+            .local_data_count = local_data_count});
+    return;
+  }
+
+  // Batch Upload Bookmarks promo: for users that have local bookmarks and were
+  // previously syncing with the current primary account.
+  if (WasPreviouslySyncingWithPrimaryAccount(profile) &&
+      local_map_result.contains(syncer::BOOKMARKS) &&
+      !local_map_result[syncer::BOOKMARKS].local_data_models.empty()) {
+    std::move(result_callback)
+        .Run(ProfileMenuAvatarButtonPromoInfo{
+            .type = ProfileMenuAvatarButtonPromoInfo::Type::
+                kBatchUploadBookmarksPromo,
+            .local_data_count = local_data_count});
+    return;
+  }
+
+  // History sync promo.
+  if (signin_util::ShouldShowHistorySyncOptinScreen(*profile) ==
+          signin_util::ShouldShowHistorySyncOptinResult::kShow &&
+      !signin_util::HasExplicitlyDisabledHistorySync(*profile)) {
+    std::move(result_callback)
+        .Run(ProfileMenuAvatarButtonPromoInfo{
+            .type = ProfileMenuAvatarButtonPromoInfo::Type::kHistorySyncPromo,
+            .local_data_count = local_data_count});
+    return;
+  }
+
+  // Regular Batch Upload promo: for users that have any local data type.
+  if (local_data_count > 0) {
+    std::move(result_callback)
+        .Run(ProfileMenuAvatarButtonPromoInfo{
+            .type = ProfileMenuAvatarButtonPromoInfo::Type::kBatchUploadPromo,
+            .local_data_count = local_data_count});
+    return;
+  }
+
+  // No promo.
+  std::move(result_callback)
+      .Run(ProfileMenuAvatarButtonPromoInfo{
+          .type = std::nullopt, .local_data_count = local_data_count});
+  return;
+}
+
 syncer::DataType GetDataTypeFromSignInPromoType(SignInPromoType type) {
   switch (type) {
     case SignInPromoType::kPassword:
@@ -119,6 +273,10 @@ bool ShouldShowPromoBasedOnImpressionOrDismissalCount(Profile& profile,
 // `ShouldShowAddressSignInPromo` and `ShouldShowPasswordSignInPromo`).
 // `profile` is the profile of the tab the promo would be shown on.
 bool ShouldShowSignInPromoCommon(Profile& profile, SignInPromoType type) {
+  if (profile.IsOffTheRecord()) {
+    return false;
+  }
+
   // Don't show the promo if it does not pass the sync base checks.
   if (!signin::ShouldShowSyncPromo(profile)) {
     return false;
@@ -132,7 +290,6 @@ bool ShouldShowSignInPromoCommon(Profile& profile, SignInPromoType type) {
   if (!sync_service) {
     return false;
   }
-  CHECK(!profile.IsOffTheRecord());
 
   syncer::DataType data_type = GetDataTypeFromSignInPromoType(type);
 
@@ -163,10 +320,9 @@ bool ShouldShowSignInPromoCommon(Profile& profile, SignInPromoType type) {
   return ShouldShowPromoBasedOnImpressionOrDismissalCount(profile, type);
 }
 
-}  // namespace
 #endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
 
-namespace signin {
+}  // namespace
 
 #if !BUILDFLAG(IS_ANDROID)
 bool ShouldShowSyncPromo(Profile& profile) {
@@ -191,13 +347,19 @@ bool ShouldShowSyncPromo(Profile& profile) {
     return false;
   }
 
-  // Don't show if sign in is not allowed.
-  if (!original_profile->GetPrefs()->GetBoolean(prefs::kSigninAllowed)) {
-    return false;
-  }
-
   signin::IdentityManager* identity_manager =
       IdentityManagerFactory::GetForProfile(original_profile);
+  AccountInfo promo_account =
+      profile.IsOffTheRecord()
+          ? AccountInfo()  // Incognito profiles do not personalize promos.
+          : signin_ui_util::GetSingleAccountForPromos(identity_manager);
+
+  // Don't show if sign in can't be offered (ex: signin disallowed).
+  if (!CanOfferSignin(original_profile, promo_account.gaia, promo_account.email,
+                      /*allow_account_from_other_profile=*/true)
+           .IsOk()) {
+    return false;
+  }
 
   // No promo if the user is already syncing.
   if (identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync)) {
@@ -419,22 +581,63 @@ void RecordSignInPromoShown(signin_metrics::AccessPoint access_point,
   }
 }
 
-SyncPromoIdentityPillManager::SyncPromoIdentityPillManager(Profile& profile)
+void ComputeProfileMenuAvatarButtonPromoInfo(
+    Profile& profile,
+    base::OnceCallback<void(ProfileMenuAvatarButtonPromoInfo)>
+        result_callback) {
+  if (base::FeatureList::IsEnabled(
+          syncer::kReplaceSyncPromosWithSignInPromos)) {
+    // Note: `GetLocalDataDescriptionsForAvailableTypes()` will return no data
+    // if the SyncService is not initialized.
+    BatchUploadServiceFactory::GetForProfile(&profile)
+        ->GetLocalDataDescriptionsForAvailableTypes(base::BindOnce(
+            &ComputeProfileMenuAvatarButtonPromoInfoWithBatchUploadResult,
+            &profile, std::move(result_callback)));
+    return;
+  }
+
+  // This promo is only possible if `syncer::kReplaceSyncPromosWithSignInPromos`
+  // is disabled, as it promotes Sync.
+  if (switches::IsAvatarSyncPromoFeatureEnabled() &&
+      signin_util::ShouldShowAvatarSyncPromo(&profile)) {
+    std::move(result_callback)
+        .Run(ProfileMenuAvatarButtonPromoInfo{
+            .type = ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo,
+            .local_data_count = 0});
+    return;
+  }
+
+  // `profile` is not eligible to any promo.
+  std::move(result_callback).Run(ProfileMenuAvatarButtonPromoInfo());
+}
+
+SyncPromoIdentityPillManager::SyncPromoIdentityPillManager(
+    signin::IdentityManager* identity_manager,
+    PrefService* pref_service)
     : SyncPromoIdentityPillManager(
-          profile,
+          identity_manager,
+          pref_service,
           user_education::features::GetNewBadgeShowCount(),
           user_education::features::GetNewBadgeFeatureUsedCount()) {}
 
-SyncPromoIdentityPillManager::SyncPromoIdentityPillManager(Profile& profile,
-                                                           int max_shown_count,
-                                                           int max_used_count)
-    : profile_(profile),
+SyncPromoIdentityPillManager::SyncPromoIdentityPillManager(
+    signin::IdentityManager* identity_manager,
+    PrefService* pref_service,
+    int max_shown_count,
+    int max_used_count)
+    : identity_manager_(identity_manager),
+      signin_prefs_(CHECK_DEREF(pref_service)),
       max_shown_count_(max_shown_count),
-      max_used_count_(max_used_count) {}
+      max_used_count_(max_used_count) {
+  CHECK(identity_manager_);
+  identity_manager_scoped_observation_.Observe(identity_manager_);
+}
 
-bool SyncPromoIdentityPillManager::ShouldShowPromo() const {
-  const AccountInfo account = signin_ui_util::GetSingleAccountForPromos(
-      IdentityManagerFactory::GetForProfile(&profile_.get()));
+SyncPromoIdentityPillManager::~SyncPromoIdentityPillManager() = default;
+
+bool SyncPromoIdentityPillManager::ShouldShowPromo(
+    ProfileMenuAvatarButtonPromoInfo::Type promo_type) {
+  const AccountInfo account = GetSignedInAccountInfo();
   if (account.gaia.empty()) {
     // If there is no account available, the promo should not be shown (the sync
     // promo should be shown only for signed in users).
@@ -444,48 +647,72 @@ bool SyncPromoIdentityPillManager::ShouldShowPromo() const {
     return false;
   }
 
-  SigninPrefs signin_prefs(*profile_->GetPrefs());
-  const int show_count =
-      switches::IsAvatarSyncPromoFeatureEnabled()
-          ? signin_prefs.GetSyncPromoIdentityPillShownCount(account.gaia)
-          : signin_prefs.GetHistorySyncPromoIdentityPillShownCount(
-                account.gaia);
-  const int used_count =
-      switches::IsAvatarSyncPromoFeatureEnabled()
-          ? signin_prefs.GetSyncPromoIdentityPillUsedCount(account.gaia)
-          : signin_prefs.GetHistorySyncPromoIdentityPillUsedCount(account.gaia);
-  return show_count < max_shown_count_ && used_count < max_used_count_;
+  int promo_shown_count = 0;
+  int promo_used_count = 0;
+  if (promo_type == ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo) {
+    CHECK(switches::IsAvatarSyncPromoFeatureEnabled());
+    promo_shown_count =
+        signin_prefs_.GetSyncPromoIdentityPillShownCount(account.gaia);
+    promo_used_count =
+        signin_prefs_.GetSyncPromoIdentityPillUsedCount(account.gaia);
+  } else {
+    base::DictValue& promo_counts =
+        signin_prefs_.GetOrCreateAvatarButtonPromoCountDictionary(account.gaia);
+
+    promo_shown_count =
+        promo_counts.FindInt(GetAvatarButtonPromoShownKey(promo_type))
+            .value_or(0);
+    promo_used_count =
+        promo_counts.FindInt(GetAvatarButtonPromoUsedKey(promo_type))
+            .value_or(0);
+  }
+
+  return promo_shown_count < max_shown_count_ &&
+         promo_used_count < max_used_count_;
 }
 
-void SyncPromoIdentityPillManager::RecordPromoShown() {
-  const AccountInfo account = signin_ui_util::GetSingleAccountForPromos(
-      IdentityManagerFactory::GetForProfile(&profile_.get()));
+void SyncPromoIdentityPillManager::RecordPromoShown(
+    ProfileMenuAvatarButtonPromoInfo::Type promo_type) {
+  const AccountInfo account = GetSignedInAccountInfo();
   if (account.gaia.empty()) {
     // If there is no account available, there is nothing to record (the sync
     // promo should be shown only for signed in users).
     return;
   }
 
-  SigninPrefs signin_prefs(*profile_->GetPrefs());
-  switches::IsAvatarSyncPromoFeatureEnabled()
-      ? signin_prefs.IncrementSyncPromoIdentityPillShownCount(account.gaia)
-      : signin_prefs.IncrementHistorySyncPromoIdentityPillShownCount(
-            account.gaia);
+  if (promo_type == ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo) {
+    CHECK(switches::IsAvatarSyncPromoFeatureEnabled());
+    signin_prefs_.IncrementSyncPromoIdentityPillShownCount(account.gaia);
+    return;
+  }
+
+  base::DictValue& promo_counts =
+      signin_prefs_.GetOrCreateAvatarButtonPromoCountDictionary(account.gaia);
+  const char* shown_key = GetAvatarButtonPromoShownKey(promo_type);
+  int new_conut = promo_counts.FindInt(shown_key).value_or(0) + 1;
+  promo_counts.Set(shown_key, new_conut);
 }
 
-void SyncPromoIdentityPillManager::RecordPromoUsed() {
-  const AccountInfo account = signin_ui_util::GetSingleAccountForPromos(
-      IdentityManagerFactory::GetForProfile(&profile_.get()));
+void SyncPromoIdentityPillManager::RecordPromoUsed(
+    ProfileMenuAvatarButtonPromoInfo::Type promo_type) {
+  const AccountInfo account = GetSignedInAccountInfo();
   if (account.gaia.empty()) {
     // If there is no account available, there is nothing to record (the sync
     // promo should be shown only for signed in users).
     return;
   }
-  SigninPrefs signin_prefs(*profile_->GetPrefs());
-  switches::IsAvatarSyncPromoFeatureEnabled()
-      ? signin_prefs.IncrementSyncPromoIdentityPillUsedCount(account.gaia)
-      : signin_prefs.IncrementHistorySyncPromoIdentityPillUsedCount(
-            account.gaia);
+
+  if (promo_type == ProfileMenuAvatarButtonPromoInfo::Type::kSyncPromo) {
+    CHECK(switches::IsAvatarSyncPromoFeatureEnabled());
+    signin_prefs_.IncrementSyncPromoIdentityPillUsedCount(account.gaia);
+    return;
+  }
+
+  base::DictValue& promo_counts =
+      signin_prefs_.GetOrCreateAvatarButtonPromoCountDictionary(account.gaia);
+  const char* used_key = GetAvatarButtonPromoUsedKey(promo_type);
+  int new_conut = promo_counts.FindInt(used_key).value_or(0) + 1;
+  promo_counts.Set(used_key, new_conut);
 }
 
 bool SyncPromoIdentityPillManager::ArePromotionsEnabled() const {
@@ -493,6 +720,24 @@ bool SyncPromoIdentityPillManager::ArePromotionsEnabled() const {
   return local_state && local_state->GetBoolean(prefs::kPromotionsEnabled);
 }
 
+void SyncPromoIdentityPillManager::OnIdentityManagerShutdown(
+    IdentityManager* identity_manager) {
+  CHECK_EQ(identity_manager, identity_manager_.get());
+  identity_manager_ = nullptr;
+  identity_manager_scoped_observation_.Reset();
+}
+
+AccountInfo SyncPromoIdentityPillManager::GetSignedInAccountInfo() const {
+  CHECK(identity_manager_->AreRefreshTokensLoaded());
+  // Checks for accounts in error as well.
+  if (signin_util::GetSignedInState(identity_manager_.get()) !=
+      signin_util::SignedInState::kSignedIn) {
+    return AccountInfo();
+  }
+  return identity_manager_->FindExtendedAccountInfo(
+      identity_manager_->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin));
+}
+
 #endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
 
 }  // namespace signin
