@@ -29,11 +29,14 @@
 #include "chrome/browser/signin/account_consistency_mode_manager.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
 #include "chrome/browser/signin/signin_ui_delegate.h"
+#include "chrome/browser/signin/signin_util.h"
+#include "chrome/browser/sync/sync_service_factory.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_navigator.h"
 #include "chrome/browser/ui/browser_navigator_params.h"
 #include "chrome/browser/ui/browser_window/public/browser_window_features.h"
 #include "chrome/browser/ui/chrome_pages.h"
+#include "chrome/browser/ui/signin/promos/signin_promo_tab_helper.h"
 #include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/ui/webui/signin/turn_sync_on_helper.h"
 #include "chrome/common/pref_names.h"
@@ -49,6 +52,7 @@
 #include "components/signin/public/identity_manager/identity_utils.h"
 #include "components/signin/public/identity_manager/primary_account_mutator.h"
 #include "components/sync/base/features.h"
+#include "components/sync/service/sync_service.h"
 #include "third_party/re2/src/re2/re2.h"
 #include "ui/gfx/font_list.h"
 #include "ui/gfx/text_elider.h"
@@ -56,7 +60,7 @@
 #if BUILDFLAG(IS_CHROMEOS)
 #include "chrome/browser/ash/profiles/profile_helper.h"
 #include "chrome/browser/signin/signin_ui_chromeos_util.h"
-#include "chromeos/ash/components/account_manager/account_manager_facade_factory.h"
+#include "chromeos/ash/components/account_manager/account_manager_factory.h"
 #include "components/account_manager_core/account_manager_facade.h"
 #include "components/user_manager/user.h"
 #endif  // BUILDFLAG(IS_CHROMEOS)
@@ -192,7 +196,8 @@ void ShowReauthForAccount(Profile* profile,
                           const std::string& email,
                           signin_metrics::AccessPoint access_point) {
 #if BUILDFLAG(IS_CHROMEOS)
-  ash::GetAccountManagerFacade(profile->GetPath().value())
+  ash::AccountManagerFactory::Get()
+      ->GetAccountManagerFacade(profile->GetPath().value())
       ->ShowReauthAccountDialog(
           GetAccountReauthSourceFromAccessPoint(access_point), email,
           base::DoNothing());
@@ -305,7 +310,6 @@ void SignInFromSingleAccountPromo(Profile* profile,
       identity_manager->GetPrimaryAccountId(signin::ConsentLevel::kSignin) ==
           account.account_id &&
       !needs_reauth_before_signin) {
-    DVLOG(1) << "There is already a primary account.";
     return;
   }
 
@@ -331,11 +335,6 @@ void EnableSyncFromSingleAccountPromo(
     Profile* profile,
     const CoreAccountInfo& account,
     signin_metrics::AccessPoint access_point) {
-  // TODO(crbug.com/417950948): Delete this function when removing the Sync
-  // feature.
-  CHECK(!base::FeatureList::IsEnabled(
-      syncer::kReplaceSyncPromosWithSignInPromos));
-
   EnableSyncFromMultiAccountPromo(profile, account, access_point,
                                   /*is_default_promo_account=*/true);
 }
@@ -344,11 +343,6 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
                                      const CoreAccountInfo& account,
                                      signin_metrics::AccessPoint access_point,
                                      bool is_default_promo_account) {
-  // TODO(crbug.com/417950948): Delete this function when removing the Sync
-  // feature.
-  CHECK(!base::FeatureList::IsEnabled(
-      syncer::kReplaceSyncPromosWithSignInPromos));
-
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
   DCHECK_NE(signin_metrics::AccessPoint::kUnknown, access_point);
   DCHECK(!profile->IsOffTheRecord());
@@ -393,6 +387,22 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
     return;
   }
 
+  signin_metrics::LogSigninAccessPointStarted(access_point,
+                                              existing_account_promo_action);
+  signin_metrics::RecordSigninUserActionForAccessPoint(access_point);
+
+  if (base::FeatureList::IsEnabled(
+          syncer::kReplaceSyncPromosWithSignInPromos)) {
+    if (!identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin)) {
+      identity_manager->GetPrimaryAccountMutator()->SetPrimaryAccount(
+          account.account_id, signin::ConsentLevel::kSignin, access_point);
+    }
+
+    GetSigninUiDelegate()->ShowHistorySyncOptinUI(profile, account.account_id,
+                                                  access_point);
+    return;
+  }
+
   // In the UNO model, if the account was in the web-only signed in state,
   // turning on sync will sign the account in the profile and show the sync
   // confirmation dialog.
@@ -414,10 +424,6 @@ void EnableSyncFromMultiAccountPromo(Profile* profile,
               !is_sync_promo
           ? TurnSyncOnHelper::SigninAbortedMode::KEEP_ACCOUNT_ON_WEB_ONLY
           : TurnSyncOnHelper::SigninAbortedMode::KEEP_ACCOUNT;
-  signin_metrics::LogSigninAccessPointStarted(access_point,
-                                              existing_account_promo_action);
-  signin_metrics::RecordSigninUserActionForAccessPoint(access_point);
-
   bool user_already_signed_in =
       identity_manager->GetPrimaryAccountId(signin::ConsentLevel::kSignin) ==
       account.account_id;
@@ -641,4 +647,63 @@ void RecordProfileMenuClick(const Profile& profile) {
   }
 }
 
+void TriggerSignInForHistorySyncOptIn(Browser* browser,
+                                     Profile* profile,
+                                     signin_metrics::AccessPoint access_point) {
+#if !BUILDFLAG(IS_CHROMEOS)
+  // Try to sign in or open a sign in tab if user input is needed. If the user
+  // is already signed in, this is a no-op.
+  signin_ui_util::SignInFromSingleAccountPromo(
+      profile,
+      signin_ui_util::GetSingleAccountForPromos(
+          IdentityManagerFactory::GetForProfile(profile)),
+      access_point);
+  syncer::SyncService* sync_service =
+      SyncServiceFactory::GetForProfile(profile);
+  if (!sync_service) {
+    return;
+  }
+
+  // It is safe to pass a pointer to the sync service here because the callback
+  // is then owned by a tab helper, which is guaranteed to be destroyed before
+  // the sync service.
+  auto enable_history_sync = base::BindOnce(&signin_util::EnableHistorySync,
+                                            base::Unretained(sync_service));
+
+  switch (signin_util::GetSignedInState(
+      IdentityManagerFactory::GetForProfile(profile))) {
+    // If the sign in was already successful, enable history sync directly.
+    case signin_util::SignedInState::kSignedIn:
+      std::move(enable_history_sync).Run();
+      return;
+    // These states require a sign in tab to be displayed. A tab helper attached
+    // to the tab will take care of turning on history sync once signed in.
+    case signin_util::SignedInState::kSignedOut:
+    case signin_util::SignedInState::kSignInPending:
+    case signin_util::SignedInState::kSyncPaused:
+      break;
+    case signin_util::SignedInState::kSyncing:
+    case signin_util::SignedInState::kWebOnlySignedIn:
+      return;
+  }
+
+  content::WebContents* sign_in_tab_contents =
+      signin_ui_util::GetSignInTabWithAccessPoint(browser, access_point);
+
+  // SignInFromSingleAccountPromo may fail to open a tab. Do not wait for a
+  // sign in event in that case.
+  if (!sign_in_tab_contents) {
+    return;
+  }
+
+  SigninPromoTabHelper::GetForWebContents(*sign_in_tab_contents)
+      ->InitializeCallbackAfterSignIn(std::move(enable_history_sync),
+                                      access_point);
+#else
+  // This is not expected to be called on ChromeOS as the screen that uses this
+  // function is never shown for ChromeOS.
+  NOTREACHED();
+#endif
+}
+
 }  // namespace signin_ui_util
