@@ -50,6 +50,13 @@
 #include "services/network/public/mojom/cookie_manager.mojom.h"
 #include "ui/base/l10n/l10n_util.h"
 
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
+#include "chrome/browser/ui/browser_dialogs.h"
+#include "chrome/browser/ui/browser_finder.h"
+#include "components/strings/grit/components_strings.h"
+#include "ui/base/models/dialog_model.h"
+#endif  // BUILDFLAG(IS_LINUX) ||  BUILDFLAG(IS_MAC) ||  BUILDFLAG(IS_WIN)
+
 namespace signin_util {
 
 namespace {
@@ -147,10 +154,11 @@ void CookiesMover::OnCookiesMoved() {
 bool IsForceSigninEnabled() {
   if (g_is_force_signin_enabled_cache == NOT_CACHED) {
     PrefService* prefs = g_browser_process->local_state();
-    if (prefs)
+    if (prefs) {
       SetForceSigninPolicy(prefs->GetBoolean(prefs::kForceBrowserSignin));
-    else
+    } else {
       return false;
+    }
   }
   return (g_is_force_signin_enabled_cache == ENABLE);
 }
@@ -369,44 +377,93 @@ std::string SignedInStateToString(SignedInState state) {
   }
 }
 
-#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
-bool ShouldShowHistorySyncOptinScreen(Profile& profile) {
-  if (GetSignedInState(IdentityManagerFactory::GetForProfile(&profile)) !=
-      signin_util::SignedInState::kSignedIn) {
-    return false;
-  }
-
-  syncer::SyncService* sync_service =
-      SyncServiceFactory::GetForProfile(&profile);
+bool IsSyncingUserSelectableTypesAllowedByPolicy(
+    const syncer::SyncService* sync_service,
+    const syncer::UserSelectableTypeSet& types) {
   if (!sync_service) {
     return false;
   }
+
   if (sync_service->HasDisableReason(
           syncer::SyncService::DISABLE_REASON_ENTERPRISE_POLICY)) {
     return false;
   }
 
-  syncer::UserSelectableTypeSet synced_data_types(
-      {syncer::UserSelectableType::kHistory, syncer::UserSelectableType::kTabs,
-       syncer::UserSelectableType::kSavedTabGroups});
-  for (auto type : synced_data_types) {
+  for (auto type : types) {
     if (sync_service->GetUserSettings()->IsTypeManagedByPolicy(type) ||
         sync_service->GetUserSettings()->IsTypeManagedByCustodian(type)) {
       return false;
     }
   }
 
-  // Note: Post migration these preferences will be set by a single
-  // settings toggle and are expected to have the same value.
-  if (sync_service->GetUserSettings()->GetSelectedTypes().Has(
-          syncer::UserSelectableType::kHistory) &&
-      sync_service->GetUserSettings()->GetSelectedTypes().Has(
-          syncer::UserSelectableType::kTabs) &&
-      sync_service->GetUserSettings()->GetSelectedTypes().Has(
-          syncer::UserSelectableType::kSavedTabGroups)) {
+  return true;
+}
+
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
+bool HasExplicitlyDisabledHistorySync(Profile& profile) {
+  // If the user is signed out, we cannot know if the toggles were interacted
+  // with or not.
+  CHECK(GetSignedInState(IdentityManagerFactory::GetForProfile(&profile)) ==
+        signin_util::SignedInState::kSignedIn);
+
+  syncer::SyncService* sync_service =
+      SyncServiceFactory::GetForProfile(&profile);
+  if (!sync_service) {
     return false;
   }
-  return true;
+
+  for (auto type :
+       {syncer::UserSelectableType::kHistory, syncer::UserSelectableType::kTabs,
+        syncer::UserSelectableType::kSavedTabGroups}) {
+    if (sync_service->GetUserSettings()->GetTypePrefStateForAccount(type) ==
+        syncer::SyncUserSettings::UserSelectableTypePrefState::kDisabled) {
+      return true;
+    }
+  }
+
+  return false;
+}
+
+ShouldShowHistorySyncOptinResult ShouldShowHistorySyncOptinScreen(
+    Profile& profile) {
+  if (GetSignedInState(IdentityManagerFactory::GetForProfile(&profile)) !=
+      signin_util::SignedInState::kSignedIn) {
+    return ShouldShowHistorySyncOptinResult::kSkipUserNotSignedIn;
+  }
+
+  syncer::UserSelectableTypeSet required_types(
+      {syncer::UserSelectableType::kHistory, syncer::UserSelectableType::kTabs,
+       syncer::UserSelectableType::kSavedTabGroups});
+  syncer::SyncService* sync_service =
+      SyncServiceFactory::GetForProfile(&profile);
+  if (!IsSyncingUserSelectableTypesAllowedByPolicy(sync_service,
+                                                   required_types)) {
+    return ShouldShowHistorySyncOptinResult::kSkipSyncForbidden;
+  }
+
+  // Sync service must exist, otherwise the method would have exited already.
+  CHECK(sync_service);
+  // Note: Post migration these preferences will be set by a single
+  // settings toggle and are expected to have the same value.
+  bool all_types_enabled =
+      sync_service->GetUserSettings()->GetSelectedTypes().HasAll(
+          required_types);
+  if (all_types_enabled) {
+    return ShouldShowHistorySyncOptinResult::kSkipUserAlreadyOptedIn;
+  }
+
+  return ShouldShowHistorySyncOptinResult::kShow;
+}
+
+void EnableHistorySync(syncer::SyncService* sync_service) {
+  CHECK(sync_service);
+
+  sync_service->GetUserSettings()->SetSelectedType(
+      syncer::UserSelectableType::kHistory, /*is_type_on=*/true);
+  sync_service->GetUserSettings()->SetSelectedType(
+      syncer::UserSelectableType::kTabs, /*is_type_on=*/true);
+  sync_service->GetUserSettings()->SetSelectedType(
+      syncer::UserSelectableType::kSavedTabGroups, /*is_type_on=*/true);
 }
 
 bool ShouldShowAvatarSyncPromo(Profile* profile) {
@@ -464,6 +521,22 @@ bool ShouldShowAvatarSyncPromo(Profile* profile) {
 
   return true;
 }
+
+void ShowErrorDialogWithMessage(Browser* browser, int error_message_id) {
+  if (!browser) {
+    return;
+  }
+
+  auto dialog_model =
+      ui::DialogModel::Builder()
+          .AddParagraph(ui::DialogModelLabel(error_message_id))
+          .AddOkButton(base::DoNothing(),
+                       ui::DialogModel::Button::Params().SetLabel(
+                           l10n_util::GetStringUTF16(IDS_OK)))
+          .Build();
+
+  chrome::ShowBrowserModal(browser, std::move(dialog_model));
+}
 #endif  // BUILDFLAG(IS_LINUX) ||  BUILDFLAG(IS_MAC) ||  BUILDFLAG(IS_WIN)
 
 }  // namespace signin_util
