@@ -21,7 +21,6 @@
 #include "chrome/browser/ui/autofill/autofill_bubble_base.h"
 #include "chrome/browser/ui/autofill/autofill_bubble_controller_base.h"
 #include "chrome/browser/ui/autofill/autofill_bubble_handler.h"
-#include "chrome/browser/ui/autofill/payments/payments_ui_constants.h"
 #include "chrome/browser/ui/autofill/payments/save_card_ui.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_finder.h"
@@ -53,11 +52,36 @@
 #include "components/strings/grit/components_strings.h"
 #include "components/sync/service/sync_service.h"
 #include "content/public/browser/navigation_handle.h"
+#include "content/public/browser/visibility.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/resource/resource_bundle.h"
 
 namespace autofill {
 
+namespace {
+
+// SaveCardPromptMetricType will be either LegacySaveCardPromptResult or
+// SaveCardPromptResultDesktop.
+template <typename SaveCardPromptMetricType>
+SaveCardPromptMetricType GetMetric(PaymentsUiClosedReason reason) {
+  switch (reason) {
+    case PaymentsUiClosedReason::kAccepted:
+      return SaveCardPromptMetricType::kAccepted;
+    case PaymentsUiClosedReason::kCancelled:
+      return SaveCardPromptMetricType::kCancelled;
+    case PaymentsUiClosedReason::kClosed:
+      return SaveCardPromptMetricType::kClosed;
+    case PaymentsUiClosedReason::kNotInteracted:
+      return SaveCardPromptMetricType::kNotInteracted;
+    case PaymentsUiClosedReason::kLostFocus:
+      return SaveCardPromptMetricType::kLostFocus;
+    case PaymentsUiClosedReason::kUnknown:
+      return SaveCardPromptMetricType::kUnknown;
+  }
+}
+
+}  // namespace
+
 static bool g_ignore_window_activation_for_testing = false;
 
 SaveCardBubbleControllerImpl::SaveCardBubbleControllerImpl(
@@ -90,33 +114,42 @@ void SaveCardBubbleControllerImpl::OfferLocalSave(
         save_card_prompt_callback) {
   // If the confirmation view is still showing, close it before showing the new
   // offer.
-  if (current_bubble_type_ == BubbleType::UPLOAD_COMPLETED) {
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadComplete) {
     HideBubble();
   }
 
   // Don't show the bubble if it's already visible.
-  if (bubble_view()) {
+  if (bubble_view() || !MaySetUpBubble()) {
     return;
   }
 
+  SetupLocalSave(card, options, std::move(save_card_prompt_callback));
+
+  if (options.show_prompt) {
+    CheckPreconditionsBeforeShowing();
+    QueueOrShowBubble();
+  } else {
+    ShowIconOnly();
+  }
+}
+
+void SaveCardBubbleControllerImpl::SetupLocalSave(
+    CreditCard card,
+    payments::PaymentsAutofillClient::SaveCreditCardOptions options,
+    payments::PaymentsAutofillClient::LocalSaveCardPromptCallback
+        save_card_prompt_callback) {
   is_upload_save_ = false;
   is_reshow_ = false;
   is_triggered_by_user_gesture_ = false;
   options_ = options;
-  card_ = card;
+  card_ = std::move(card);
   local_save_card_prompt_callback_ = std::move(save_card_prompt_callback);
   legal_message_lines_.clear();
   current_bubble_type_ =
       options.card_save_type ==
               payments::PaymentsAutofillClient::CardSaveType::kCvcSaveOnly
-          ? BubbleType::LOCAL_CVC_SAVE
-          : BubbleType::LOCAL_SAVE;
-
-  if (options.show_prompt) {
-    SetupAndShowBubble();
-  } else {
-    ShowIconOnly();
-  }
+          ? PaymentsBubbleType::kLocalCvcSave
+          : PaymentsBubbleType::kLocalSave;
 }
 
 void SaveCardBubbleControllerImpl::OfferUploadSave(
@@ -127,41 +160,52 @@ void SaveCardBubbleControllerImpl::OfferUploadSave(
         save_card_prompt_callback) {
   // If the confirmation view is still showing, close it before showing the new
   // offer.
-  if (current_bubble_type_ == BubbleType::UPLOAD_COMPLETED) {
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadComplete) {
     HideBubble();
   }
 
   // Don't show the bubble if it's already visible.
-  if (bubble_view()) {
+  if (bubble_view() || !MaySetUpBubble()) {
     return;
   }
 
+  SetupUploadSave(card, legal_message_lines, options,
+                  std::move(save_card_prompt_callback));
+
+  if (options_.show_prompt) {
+    CheckPreconditionsBeforeShowing();
+    QueueOrShowBubble();
+  } else {
+    ShowIconOnly();
+  }
+}
+
+void SaveCardBubbleControllerImpl::SetupUploadSave(
+    CreditCard card,
+    LegalMessageLines legal_message_lines,
+    payments::PaymentsAutofillClient::SaveCreditCardOptions options,
+    payments::PaymentsAutofillClient::UploadSaveCardPromptCallback
+        save_card_prompt_callback) {
   is_upload_save_ = true;
   is_reshow_ = false;
   is_triggered_by_user_gesture_ = false;
   options_ = options;
-  card_ = card;
+  card_ = std::move(card);
   upload_save_card_prompt_callback_ = std::move(save_card_prompt_callback);
   current_bubble_type_ =
       options.card_save_type ==
               payments::PaymentsAutofillClient::CardSaveType::kCvcSaveOnly
-          ? BubbleType::UPLOAD_CVC_SAVE
-          : BubbleType::UPLOAD_SAVE;
+          ? PaymentsBubbleType::kUploadCvcSave
+          : PaymentsBubbleType::kUploadSave;
 
   // Reset legal_message_lines for CVC only upload as there is no legal message
   // for this case.
   // TODO(crbug.com/40931101): Refactor ShowSaveCreditCardToCloud to change
   // legal_message_lines_ to optional.
-  if (current_bubble_type_ == BubbleType::UPLOAD_CVC_SAVE) {
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadCvcSave) {
     legal_message_lines_.clear();
   } else {
-    legal_message_lines_ = legal_message_lines;
-  }
-
-  if (options_.show_prompt) {
-    SetupAndShowBubble();
-  } else {
-    ShowIconOnly();
+    legal_message_lines_ = std::move(legal_message_lines);
   }
 }
 
@@ -169,8 +213,9 @@ void SaveCardBubbleControllerImpl::OfferUploadSave(
 void SaveCardBubbleControllerImpl::ShowBubbleForManageCardsForTesting(
     const CreditCard& card) {
   card_ = card;
-  current_bubble_type_ = BubbleType::MANAGE_CARDS;
-  SetupAndShowBubble();
+  current_bubble_type_ = PaymentsBubbleType::kManageCards;
+  CheckPreconditionsBeforeShowing();
+  QueueOrShowBubble();
 }
 
 void SaveCardBubbleControllerImpl::ReshowBubble(
@@ -182,7 +227,8 @@ void SaveCardBubbleControllerImpl::ReshowBubble(
 
   is_reshow_ = true;
   is_triggered_by_user_gesture_ = is_triggered_by_user_gesture;
-  SetupAndShowBubble();
+  CheckPreconditionsBeforeShowing();
+  QueueOrShowBubble(/*force_show=*/true);
 }
 
 void SaveCardBubbleControllerImpl::ShowConfirmationBubbleView(
@@ -195,7 +241,7 @@ void SaveCardBubbleControllerImpl::ShowConfirmationBubbleView(
 
   is_reshow_ = false;
   is_triggered_by_user_gesture_ = false;
-  current_bubble_type_ = BubbleType::UPLOAD_COMPLETED;
+  current_bubble_type_ = PaymentsBubbleType::kUploadComplete;
   confirmation_ui_params_ =
       card_saved ? SavePaymentMethodAndVirtualCardEnrollConfirmationUiParams::
                        CreateForSaveCardSuccess()
@@ -204,7 +250,8 @@ void SaveCardBubbleControllerImpl::ShowConfirmationBubbleView(
   on_confirmation_closed_callback_ = std::move(on_confirmation_closed_callback);
 
   // Show upload confirmation bubble.
-  SetupAndShowBubble();
+  CheckPreconditionsBeforeShowing();
+  QueueOrShowBubble();
 
   // Auto close confirmation bubble when card saved is successful.
   if (card_saved) {
@@ -230,33 +277,33 @@ SaveCardBubbleControllerImpl::GetEndSaveCardPromptFlowCallback() {
 
 std::u16string SaveCardBubbleControllerImpl::GetWindowTitle() const {
   switch (current_bubble_type_) {
-    case BubbleType::LOCAL_SAVE:
+    case PaymentsBubbleType::kLocalSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_LOCAL);
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kLocalCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_LOCAL);
-    case BubbleType::UPLOAD_SAVE:
-    case BubbleType::UPLOAD_IN_PROGRESS:
+    case PaymentsBubbleType::kUploadSave:
+    case PaymentsBubbleType::kUploadInProgress:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CARD_PROMPT_TITLE_TO_CLOUD_SECURITY);
-    case BubbleType::UPLOAD_CVC_SAVE:
+    case PaymentsBubbleType::kUploadCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CVC_PROMPT_TITLE_TO_CLOUD);
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kManageCards:
       return l10n_util::GetStringUTF16(
           options_.card_save_type ==
                   payments::PaymentsAutofillClient::CardSaveType::kCvcSaveOnly
               ? IDS_AUTOFILL_CVC_SAVED
               : IDS_AUTOFILL_CARD_SAVED);
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kInactive:
       NOTREACHED();
   }
 }
 
 std::u16string SaveCardBubbleControllerImpl::GetExplanatoryMessage() const {
-  if (current_bubble_type_ == BubbleType::LOCAL_SAVE &&
+  if (current_bubble_type_ == PaymentsBubbleType::kLocalSave &&
       base::FeatureList::IsEnabled(
           features::kAutofillEnableCvcStorageAndFilling)) {
     CHECK_NE(options_.card_save_type,
@@ -268,18 +315,18 @@ std::u16string SaveCardBubbleControllerImpl::GetExplanatoryMessage() const {
             : IDS_AUTOFILL_SAVE_CARD_WITH_CVC_PROMPT_EXPLANATION_LOCAL);
   }
 
-  if (current_bubble_type_ == BubbleType::LOCAL_CVC_SAVE) {
+  if (current_bubble_type_ == PaymentsBubbleType::kLocalCvcSave) {
     return l10n_util::GetStringUTF16(
         IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_LOCAL);
   }
 
-  if (current_bubble_type_ == BubbleType::UPLOAD_CVC_SAVE) {
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadCvcSave) {
     return l10n_util::GetStringUTF16(
         IDS_AUTOFILL_SAVE_CVC_PROMPT_EXPLANATION_UPLOAD);
   }
 
-  if (current_bubble_type_ != BubbleType::UPLOAD_SAVE &&
-      current_bubble_type_ != BubbleType::UPLOAD_IN_PROGRESS) {
+  if (current_bubble_type_ != PaymentsBubbleType::kUploadSave &&
+      current_bubble_type_ != PaymentsBubbleType::kUploadInProgress) {
     return std::u16string();
   }
 
@@ -289,37 +336,37 @@ std::u16string SaveCardBubbleControllerImpl::GetExplanatoryMessage() const {
 
 std::u16string SaveCardBubbleControllerImpl::GetAcceptButtonText() const {
   switch (current_bubble_type_) {
-    case BubbleType::LOCAL_SAVE:
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kLocalSave:
+    case PaymentsBubbleType::kLocalCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CARD_BUBBLE_LOCAL_SAVE_ACCEPT);
-    case BubbleType::UPLOAD_SAVE:
-    case BubbleType::UPLOAD_CVC_SAVE:
+    case PaymentsBubbleType::kUploadSave:
+    case PaymentsBubbleType::kUploadCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_SAVE_CARD_BUBBLE_UPLOAD_SAVE_ACCEPT);
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kManageCards:
       return l10n_util::GetStringUTF16(IDS_AUTOFILL_DONE);
-    case BubbleType::UPLOAD_IN_PROGRESS:
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadInProgress:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kInactive:
       return std::u16string();
   }
 }
 
 std::u16string SaveCardBubbleControllerImpl::GetDeclineButtonText() const {
   switch (current_bubble_type_) {
-    case BubbleType::LOCAL_SAVE:
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kLocalSave:
+    case PaymentsBubbleType::kLocalCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_NO_THANKS_DESKTOP_LOCAL_SAVE);
-    case BubbleType::UPLOAD_SAVE:
-    case BubbleType::UPLOAD_CVC_SAVE:
+    case PaymentsBubbleType::kUploadSave:
+    case PaymentsBubbleType::kUploadCvcSave:
       return l10n_util::GetStringUTF16(
           IDS_AUTOFILL_NO_THANKS_DESKTOP_UPLOAD_SAVE);
-    case BubbleType::UPLOAD_IN_PROGRESS:
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::MANAGE_CARDS:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadInProgress:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kManageCards:
+    case PaymentsBubbleType::kInactive:
       return std::u16string();
   }
 }
@@ -385,7 +432,7 @@ void SaveCardBubbleControllerImpl::OnSaveButton(
     const payments::PaymentsAutofillClient::UserProvidedCardDetails&
         user_provided_card_details) {
   switch (current_bubble_type_) {
-    case BubbleType::UPLOAD_SAVE: {
+    case PaymentsBubbleType::kUploadSave: {
       CHECK(!upload_save_card_prompt_callback_.is_null());
       if (auto* sentiment_service =
               TrustSafetySentimentServiceFactory::GetForProfile(GetProfile())) {
@@ -409,15 +456,21 @@ void SaveCardBubbleControllerImpl::OnSaveButton(
       // because we don't immediately close the bubble (at which time the other
       // metrics are logged) after OnSaveButton() and logging now aligns the
       // timing of the log with the other cases.
+      autofill_metrics::LogSaveCreditCardPromptResultMetricDesktop(
+          autofill_metrics::SaveCardPromptResultDesktop::kAccepted,
+          is_upload_save_, options_,
+          /*has_saved_cards=*/
+          !payments_data_manager_->GetCreditCards().empty());
       autofill_metrics::LogSaveCardPromptResultMetric(
-          autofill_metrics::SaveCardPromptResult::kAccepted, is_upload_save_,
-          is_reshow_, options_,
+          autofill_metrics::LegacySaveCardPromptResult::kAccepted,
+          is_upload_save_, is_reshow_, options_,
           payments_data_manager_->GetPaymentsSigninStateForMetrics(),
           /*has_saved_cards=*/
           !payments_data_manager_->GetCreditCards().empty());
       autofill_metrics::LogCreditCardUploadLoadingViewShownMetric(
           /*is_shown=*/true);
-      current_bubble_type_ = BubbleType::UPLOAD_IN_PROGRESS;
+
+      current_bubble_type_ = PaymentsBubbleType::kUploadInProgress;
 
       std::move(upload_save_card_prompt_callback_)
           .Run(payments::PaymentsAutofillClient::SaveCardOfferUserDecision::
@@ -425,7 +478,7 @@ void SaveCardBubbleControllerImpl::OnSaveButton(
                user_provided_card_details);
       break;
     }
-    case BubbleType::UPLOAD_CVC_SAVE: {
+    case PaymentsBubbleType::kUploadCvcSave: {
       CHECK(!upload_save_card_prompt_callback_.is_null());
       if (auto* sentiment_service =
               TrustSafetySentimentServiceFactory::GetForProfile(GetProfile())) {
@@ -437,8 +490,8 @@ void SaveCardBubbleControllerImpl::OnSaveButton(
                /*user_provided_card_details=*/{});
       break;
     }
-    case BubbleType::LOCAL_SAVE:
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kLocalSave:
+    case PaymentsBubbleType::kLocalCvcSave:
       CHECK(!local_save_card_prompt_callback_.is_null());
       if (auto* sentiment_service =
               TrustSafetySentimentServiceFactory::GetForProfile(GetProfile())) {
@@ -451,13 +504,13 @@ void SaveCardBubbleControllerImpl::OnSaveButton(
           .Run(payments::PaymentsAutofillClient::SaveCardOfferUserDecision::
                    kAccepted);
       break;
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kManageCards:
       CHECK(!is_upload_save_);
       LogManageCardsPromptMetric(ManageCardsPromptMetric::kManageCardsDone);
       return;
-    case BubbleType::UPLOAD_IN_PROGRESS:
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadInProgress:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kInactive:
       NOTREACHED();
   }
 }
@@ -468,7 +521,7 @@ void SaveCardBubbleControllerImpl::OnLegalMessageLinkClicked(const GURL& url) {
 }
 
 void SaveCardBubbleControllerImpl::OnManageCardsClicked() {
-  CHECK(current_bubble_type_ == BubbleType::MANAGE_CARDS);
+  CHECK(current_bubble_type_ == PaymentsBubbleType::kManageCards);
   CHECK(!is_upload_save_);
 
   LogManageCardsPromptMetric(ManageCardsPromptMetric::kManageCardsManageCards);
@@ -483,7 +536,7 @@ void SaveCardBubbleControllerImpl::ShowPaymentsSettingsPage() {
 
 void SaveCardBubbleControllerImpl::OnBubbleClosed(
     PaymentsUiClosedReason closed_reason) {
-  set_bubble_view(nullptr);
+  ResetBubbleViewAndInformBubbleManager();
 
   // If the dialog should be re-shown, do not change the bubble type or log
   // metrics.
@@ -493,56 +546,50 @@ void SaveCardBubbleControllerImpl::OnBubbleClosed(
     return;
   }
 
-  auto get_metric = [](PaymentsUiClosedReason reason) {
-    switch (reason) {
-      case PaymentsUiClosedReason::kAccepted:
-        return autofill_metrics::SaveCardPromptResult::kAccepted;
-      case PaymentsUiClosedReason::kCancelled:
-        return autofill_metrics::SaveCardPromptResult::kCancelled;
-      case PaymentsUiClosedReason::kClosed:
-        return autofill_metrics::SaveCardPromptResult::kClosed;
-      case PaymentsUiClosedReason::kNotInteracted:
-        return autofill_metrics::SaveCardPromptResult::kNotInteracted;
-      case PaymentsUiClosedReason::kLostFocus:
-        return autofill_metrics::SaveCardPromptResult::kLostFocus;
-      case PaymentsUiClosedReason::kUnknown:
-        return autofill_metrics::SaveCardPromptResult::kUnknown;
-    }
-  };
+  autofill_metrics::LegacySaveCardPromptResult legacy_metric =
+      GetMetric<autofill_metrics::LegacySaveCardPromptResult>(closed_reason);
 
   // Log save card prompt result according to the closed reason.
   switch (current_bubble_type_) {
-    case BubbleType::LOCAL_CVC_SAVE:
-    case BubbleType::UPLOAD_CVC_SAVE:
+    case PaymentsBubbleType::kLocalCvcSave:
+    case PaymentsBubbleType::kUploadCvcSave:
       autofill_metrics::LogSaveCvcPromptResultMetric(
-          get_metric(closed_reason), is_upload_save_, is_reshow_);
+          legacy_metric, is_upload_save_, is_reshow_);
       break;
-    case BubbleType::LOCAL_SAVE:
-    case BubbleType::UPLOAD_SAVE:
+    case PaymentsBubbleType::kLocalSave:
+    case PaymentsBubbleType::kUploadSave:
+      if (!is_reshow_) {
+        autofill_metrics::LogSaveCreditCardPromptResultMetricDesktop(
+            GetMetric<autofill_metrics::SaveCardPromptResultDesktop>(
+                closed_reason),
+            is_upload_save_,
+            /*save_credit_card_options=*/options_, /*has_saved_cards=*/
+            !payments_data_manager_->GetCreditCards().empty());
+      }
       autofill_metrics::LogSaveCardPromptResultMetric(
-          get_metric(closed_reason), is_upload_save_, is_reshow_, options_,
+          legacy_metric, is_upload_save_, is_reshow_, options_,
           payments_data_manager_->GetPaymentsSigninStateForMetrics(),
           /*has_saved_cards=*/
           !payments_data_manager_->GetCreditCards().empty());
       break;
-    case BubbleType::UPLOAD_IN_PROGRESS:
+    case PaymentsBubbleType::kUploadInProgress:
       autofill_metrics::LogCreditCardUploadLoadingViewResultMetric(
-          get_metric(closed_reason));
+          legacy_metric);
       break;
-    case BubbleType::UPLOAD_COMPLETED:
+    case PaymentsBubbleType::kUploadComplete:
       autofill_metrics::LogCreditCardUploadConfirmationViewResultMetric(
-          get_metric(closed_reason), confirmation_ui_params_->is_success);
+          legacy_metric, confirmation_ui_params_->is_success);
       break;
-    case BubbleType::INACTIVE:
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kInactive:
+    case PaymentsBubbleType::kManageCards:
       break;
   }
 
   // If the bubble is closed with the current_bubble_type_ as
-  // UPLOAD_COMPLETED, transition the current_bubble_type_ to INACTIVE, reset
+  // kUploadComplete, transition the current_bubble_type_ to kInactive, reset
   // the confirmation_ui_model and run `on_confirmation_closed_callback_`.
-  if (current_bubble_type_ == BubbleType::UPLOAD_COMPLETED) {
-    current_bubble_type_ = BubbleType::INACTIVE;
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadComplete) {
+    current_bubble_type_ = PaymentsBubbleType::kInactive;
     confirmation_ui_params_.reset();
 
     UpdatePageActionIcon();
@@ -563,18 +610,18 @@ void SaveCardBubbleControllerImpl::OnBubbleClosed(
     case PaymentsUiClosedReason::kAccepted:
       user_decision = SaveCardOfferUserDecision::kAccepted;
       switch (current_bubble_type_) {
-        case BubbleType::LOCAL_SAVE:
-        case BubbleType::LOCAL_CVC_SAVE:
-          current_bubble_type_ = BubbleType::MANAGE_CARDS;
+        case PaymentsBubbleType::kLocalSave:
+        case PaymentsBubbleType::kLocalCvcSave:
+          current_bubble_type_ = PaymentsBubbleType::kManageCards;
           break;
-        case BubbleType::UPLOAD_SAVE:
-        case BubbleType::UPLOAD_CVC_SAVE:
-        case BubbleType::MANAGE_CARDS:
-          current_bubble_type_ = BubbleType::INACTIVE;
+        case PaymentsBubbleType::kUploadSave:
+        case PaymentsBubbleType::kUploadCvcSave:
+        case PaymentsBubbleType::kManageCards:
+          current_bubble_type_ = PaymentsBubbleType::kInactive;
           break;
-        case BubbleType::INACTIVE:
-        case BubbleType::UPLOAD_IN_PROGRESS:
-        case BubbleType::UPLOAD_COMPLETED:
+        case PaymentsBubbleType::kInactive:
+        case PaymentsBubbleType::kUploadInProgress:
+        case PaymentsBubbleType::kUploadComplete:
           NOTREACHED();
       }
       break;
@@ -592,19 +639,19 @@ void SaveCardBubbleControllerImpl::OnBubbleClosed(
 
   if (user_decision && *user_decision != SaveCardOfferUserDecision::kAccepted) {
     switch (current_bubble_type_) {
-      case BubbleType::LOCAL_SAVE:
-      case BubbleType::LOCAL_CVC_SAVE:
+      case PaymentsBubbleType::kLocalSave:
+      case PaymentsBubbleType::kLocalCvcSave:
         std::move(local_save_card_prompt_callback_).Run(*user_decision);
         break;
-      case BubbleType::UPLOAD_SAVE:
-      case BubbleType::UPLOAD_CVC_SAVE:
+      case PaymentsBubbleType::kUploadSave:
+      case PaymentsBubbleType::kUploadCvcSave:
         std::move(upload_save_card_prompt_callback_)
             .Run(*user_decision, /*user_provided_card_details=*/{});
         break;
       default:
         break;
     }
-    current_bubble_type_ = BubbleType::INACTIVE;
+    current_bubble_type_ = PaymentsBubbleType::kInactive;
   }
 
   UpdatePageActionIcon();
@@ -619,7 +666,7 @@ bool SaveCardBubbleControllerImpl::IsUploadSave() const {
   return is_upload_save_;
 }
 
-BubbleType SaveCardBubbleControllerImpl::GetBubbleType() const {
+PaymentsBubbleType SaveCardBubbleControllerImpl::GetPaymentsBubbleType() const {
   return current_bubble_type_;
 }
 
@@ -638,22 +685,22 @@ void SaveCardBubbleControllerImpl::HideSaveCardBubble() {
 std::u16string SaveCardBubbleControllerImpl::GetSavePaymentIconTooltipText()
     const {
   switch (current_bubble_type_) {
-    case BubbleType::LOCAL_SAVE:
-    case BubbleType::UPLOAD_SAVE:
+    case PaymentsBubbleType::kLocalSave:
+    case PaymentsBubbleType::kUploadSave:
       return l10n_util::GetStringUTF16(IDS_TOOLTIP_SAVE_CREDIT_CARD);
-    case BubbleType::LOCAL_CVC_SAVE:
-    case BubbleType::UPLOAD_CVC_SAVE:
+    case PaymentsBubbleType::kLocalCvcSave:
+    case PaymentsBubbleType::kUploadCvcSave:
       return l10n_util::GetStringUTF16(IDS_TOOLTIP_SAVE_CVC);
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kManageCards:
       return l10n_util::GetStringUTF16(
           options_.card_save_type ==
                   payments::PaymentsAutofillClient::CardSaveType::kCvcSaveOnly
               ? IDS_TOOLTIP_SAVE_CVC
               : IDS_TOOLTIP_SAVE_CREDIT_CARD);
-    case BubbleType::UPLOAD_IN_PROGRESS:
+    case PaymentsBubbleType::kUploadInProgress:
       return l10n_util::GetStringUTF16(IDS_TOOLTIP_SAVE_CREDIT_CARD_PENDING);
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kInactive:
       return std::u16string();
   }
 }
@@ -675,7 +722,7 @@ void SaveCardBubbleControllerImpl::OnAnimationEnded() {
 }
 
 bool SaveCardBubbleControllerImpl::IsIconVisible() const {
-  if (current_bubble_type_ == BubbleType::INACTIVE) {
+  if (current_bubble_type_ == PaymentsBubbleType::kInactive) {
     CHECK(!bubble_view());
     // If there is no bubble to show, then there should be no icon.
     return false;
@@ -702,16 +749,23 @@ SaveCardBubbleControllerImpl::IgnoreWindowActivationForTesting() {
 
 void SaveCardBubbleControllerImpl::OnVisibilityChanged(
     content::Visibility visibility) {
+  if (base::FeatureList::IsEnabled(
+          features::kAutofillShowBubblesBasedOnPriorities)) {
+    // BubbleManager will handle the effects of tab changes.
+    return;
+  }
+
   if (visibility == content::Visibility::VISIBLE &&
       (was_url_opened_ ||
-       current_bubble_type_ == BubbleType::UPLOAD_COMPLETED)) {
+       current_bubble_type_ == PaymentsBubbleType::kUploadComplete)) {
     ReshowBubble(/*is_user_gesture=*/false);
   } else if (visibility == content::Visibility::HIDDEN) {
     HideBubble();
   }
 }
 
-PageActionIconType SaveCardBubbleControllerImpl::GetPageActionIconType() {
+std::optional<PageActionIconType>
+SaveCardBubbleControllerImpl::GetPageActionIconType() {
   return PageActionIconType::kSaveCard;
 }
 
@@ -721,14 +775,16 @@ void SaveCardBubbleControllerImpl::DoShowBubble() {
   }
 
   Browser* browser = chrome::FindBrowserWithTab(web_contents());
-  if (current_bubble_type_ == BubbleType::UPLOAD_COMPLETED) {
-    set_bubble_view(browser->window()
-                        ->GetAutofillBubbleHandler()
-                        ->ShowSaveCardConfirmationBubble(web_contents(), this));
+  if (current_bubble_type_ == PaymentsBubbleType::kUploadComplete) {
+    SetBubbleView(*browser->window()
+                       ->GetAutofillBubbleHandler()
+                       ->ShowSaveCardConfirmationBubble(web_contents(), this));
   } else {
-    set_bubble_view(
-        browser->window()->GetAutofillBubbleHandler()->ShowSaveCreditCardBubble(
-            web_contents(), this, is_triggered_by_user_gesture_));
+    SetBubbleView(
+        *browser->window()
+             ->GetAutofillBubbleHandler()
+             ->ShowSaveCreditCardBubble(web_contents(), this,
+                                        is_triggered_by_user_gesture_));
   }
   CHECK(bubble_view());
 
@@ -741,8 +797,8 @@ void SaveCardBubbleControllerImpl::DoShowBubble() {
   }
 
   switch (current_bubble_type_) {
-    case BubbleType::UPLOAD_SAVE:
-    case BubbleType::LOCAL_SAVE:
+    case PaymentsBubbleType::kUploadSave:
+    case PaymentsBubbleType::kLocalSave:
       if (!is_reshow_) {
         autofill_metrics::LogSaveCreditCardPromptOfferMetricDesktop(
             autofill_metrics::SaveCardPromptOffer::kShown, is_upload_save_,
@@ -753,55 +809,63 @@ void SaveCardBubbleControllerImpl::DoShowBubble() {
           is_reshow_, options_,
           payments_data_manager_->GetPaymentsSigninStateForMetrics());
       break;
-    case BubbleType::UPLOAD_CVC_SAVE:
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kUploadCvcSave:
+    case PaymentsBubbleType::kLocalCvcSave:
       autofill_metrics::LogSaveCvcPromptOfferMetric(
           autofill_metrics::SaveCardPromptOffer::kShown, is_upload_save_,
           is_reshow_);
       break;
-    case BubbleType::MANAGE_CARDS:
+    case PaymentsBubbleType::kManageCards:
       CHECK(!is_upload_save_);
       LogManageCardsPromptMetric(ManageCardsPromptMetric::kManageCardsShown);
       break;
-    case BubbleType::UPLOAD_COMPLETED:
+    case PaymentsBubbleType::kUploadComplete:
       autofill_metrics::LogCreditCardUploadConfirmationViewShownMetric(
           /*is_shown=*/true, confirmation_ui_params_->is_success);
       break;
-    case BubbleType::UPLOAD_IN_PROGRESS:
+    case PaymentsBubbleType::kUploadInProgress:
       break;
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kInactive:
       NOTREACHED();
   }
 }
 
-void SaveCardBubbleControllerImpl::SetupAndShowBubble() {
-  CHECK(current_bubble_type_ != BubbleType::INACTIVE);
-  // Upload save callback should not be null for UPLOAD_SAVE or
-  // UPLOAD_CVC_SAVE state.
+BubbleType SaveCardBubbleControllerImpl::GetBubbleType() const {
+  return BubbleType::kSaveUpdateCard;
+}
+
+base::WeakPtr<BubbleControllerBase>
+SaveCardBubbleControllerImpl::GetBubbleControllerBaseWeakPtr() {
+  return weak_ptr_factory_.GetWeakPtr();
+}
+
+void SaveCardBubbleControllerImpl::CheckPreconditionsBeforeShowing() {
+  CHECK(current_bubble_type_ != PaymentsBubbleType::kInactive);
+  // Upload save callback should not be null for kUploadSave or
+  // kUploadCvcSave state.
   CHECK(!upload_save_card_prompt_callback_.is_null() ||
-        (current_bubble_type_ != BubbleType::UPLOAD_SAVE &&
-         current_bubble_type_ != BubbleType::UPLOAD_CVC_SAVE));
-  // Local save callback should not be null for LOCAL_SAVE or LOCAL_CVC_SAVE
+        (current_bubble_type_ != PaymentsBubbleType::kUploadSave &&
+         current_bubble_type_ != PaymentsBubbleType::kUploadCvcSave));
+  // Local save callback should not be null for kLocalSave or kLocalCvcSave
   // state.
   CHECK(!local_save_card_prompt_callback_.is_null() ||
-        (current_bubble_type_ != BubbleType::LOCAL_SAVE &&
-         current_bubble_type_ != BubbleType::LOCAL_CVC_SAVE));
+        (current_bubble_type_ != PaymentsBubbleType::kLocalSave &&
+         current_bubble_type_ != PaymentsBubbleType::kLocalCvcSave));
   CHECK(!bubble_view());
-  ShowBubble();
 }
 
 void SaveCardBubbleControllerImpl::ShowIconOnly() {
-  CHECK(current_bubble_type_ != BubbleType::INACTIVE);
-  // Upload save callback should not be null for UPLOAD_SAVE or
-  // UPLOAD_CVC_SAVE state.
+  CHECK(current_bubble_type_ != PaymentsBubbleType::kInactive);
+  // Upload save callback should not be null for kUploadSave or
+  // kUploadCvcSave state.
   CHECK(!upload_save_card_prompt_callback_.is_null() ||
-        (current_bubble_type_ != BubbleType::UPLOAD_SAVE &&
-         current_bubble_type_ != BubbleType::UPLOAD_CVC_SAVE));
-  // Local save callback should not be null for LOCAL_SAVE or LOCAL_CVC_SAVE
+        (current_bubble_type_ != PaymentsBubbleType::kUploadSave &&
+         current_bubble_type_ != PaymentsBubbleType::kUploadCvcSave));
+  // Local save callback should not be null for kLocalSave or kLocalCvcSave
   // state.
   CHECK(!local_save_card_prompt_callback_.is_null() ||
-        current_bubble_type_ != BubbleType::LOCAL_SAVE &&
-            current_bubble_type_ != BubbleType::LOCAL_CVC_SAVE);
+        current_bubble_type_ != PaymentsBubbleType::kLocalSave &&
+            current_bubble_type_ != PaymentsBubbleType::kLocalCvcSave);
   CHECK(!bubble_view());
 
   // Show the icon only. The bubble can still be displayed if the user
@@ -809,8 +873,8 @@ void SaveCardBubbleControllerImpl::ShowIconOnly() {
   UpdatePageActionIcon();
 
   switch (current_bubble_type_) {
-    case BubbleType::UPLOAD_SAVE:
-    case BubbleType::LOCAL_SAVE:
+    case PaymentsBubbleType::kUploadSave:
+    case PaymentsBubbleType::kLocalSave:
       if (!is_reshow_) {
         autofill_metrics::LogSaveCreditCardPromptOfferMetricDesktop(
             autofill_metrics::SaveCardPromptOffer::kNotShownMaxStrikesReached,
@@ -821,16 +885,16 @@ void SaveCardBubbleControllerImpl::ShowIconOnly() {
           is_upload_save_, is_reshow_, options_,
           payments_data_manager_->GetPaymentsSigninStateForMetrics());
       break;
-    case BubbleType::UPLOAD_CVC_SAVE:
-    case BubbleType::LOCAL_CVC_SAVE:
+    case PaymentsBubbleType::kUploadCvcSave:
+    case PaymentsBubbleType::kLocalCvcSave:
       autofill_metrics::LogSaveCvcPromptOfferMetric(
           autofill_metrics::SaveCardPromptOffer::kNotShownMaxStrikesReached,
           is_upload_save_, is_reshow_);
       break;
-    case BubbleType::UPLOAD_IN_PROGRESS:
-    case BubbleType::UPLOAD_COMPLETED:
-    case BubbleType::MANAGE_CARDS:
-    case BubbleType::INACTIVE:
+    case PaymentsBubbleType::kUploadInProgress:
+    case PaymentsBubbleType::kUploadComplete:
+    case PaymentsBubbleType::kManageCards:
+    case PaymentsBubbleType::kInactive:
       NOTREACHED();
   }
 }
@@ -850,15 +914,15 @@ bool SaveCardBubbleControllerImpl::IsWebContentsActive() {
     return true;
   }
 
-  Browser* active_browser = chrome::FindBrowserWithActiveWindow();
-  return active_browser &&
-         active_browser->tab_strip_model()->GetActiveWebContents() ==
-             web_contents();
+  // Return false if the tab is inactive, occluded by another window, or out
+  // of screen bounds.
+  return web_contents() &&
+         web_contents()->GetVisibility() == content::Visibility::VISIBLE;
 }
 
 void SaveCardBubbleControllerImpl::EndSaveCardPromptFlow() {
   HideBubble();
-  current_bubble_type_ = BubbleType::INACTIVE;
+  current_bubble_type_ = PaymentsBubbleType::kInactive;
   confirmation_ui_params_.reset();
   UpdatePageActionIcon();
 }
