@@ -35,6 +35,7 @@
 #include "chrome/browser/ui/color/chrome_color_id.h"
 #include "chrome/browser/ui/layout_constants.h"
 #include "chrome/browser/ui/profiles/profile_colors_util.h"
+#include "chrome/browser/ui/signin/dice_migration_service.h"
 #include "chrome/browser/ui/ui_features.h"
 #include "chrome/browser/ui/view_ids.h"
 #include "chrome/browser/ui/views/chrome_layout_provider.h"
@@ -351,11 +352,7 @@ bool AvatarToolbarButton::ShouldPaintBorder() const {
 }
 
 bool AvatarToolbarButton::ShouldBlendHighlightColor() const {
-  if (base::FeatureList::IsEnabled(
-          features::kEnableAppMenuButtonColorsForDefaultAvatarButtonStates)) {
-    return false;
-  }
-  return GetWidget() && GetWidget()->GetCustomTheme();
+  return false;
 }
 
 base::ScopedClosureRunner AvatarToolbarButton::SetExplicitButtonState(
@@ -451,6 +448,52 @@ void AvatarToolbarButton::MaybeShowSupervisedUserSignInIPH() {
   BrowserUserEducationInterface::From(browser_)->MaybeShowFeaturePromo(
       std::move(params));
 }
+
+void AvatarToolbarButton::MaybeShowSignInBenefitsIPH() {
+  if (!base::FeatureList::IsEnabled(
+          syncer::kReplaceSyncPromosWithSignInPromos) ||
+      !base::FeatureList::IsEnabled(
+          feature_engagement::kIPHSignInBenefitsFeature)) {
+    return;
+  }
+
+  // Prevent showing the IPH bubble right when the browser was created. Wait a
+  // small delay for a smoother animation.
+  base::TimeDelta time_since_creation = base::TimeTicks::Now() - creation_time_;
+  if (time_since_creation < g_iph_min_delay_after_creation) {
+    base::SingleThreadTaskRunner::GetCurrentDefault()->PostDelayedTask(
+        FROM_HERE,
+        base::BindOnce(&AvatarToolbarButton::MaybeShowSignInBenefitsIPH,
+                       weak_ptr_factory_.GetWeakPtr()),
+        g_iph_min_delay_after_creation - time_since_creation);
+    return;
+  }
+
+  Profile* profile = browser_->profile();
+  CHECK(profile);
+
+  // The IPH only concerns signed-in, non-syncing profiles.
+  signin::IdentityManager* const identity_manager =
+      IdentityManagerFactory::GetForProfile(profile);
+  if (!identity_manager ||
+      !identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSignin) ||
+      identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync)) {
+    return;
+  }
+
+  PrefService* prefs = profile->GetPrefs();
+  CHECK(prefs);
+
+  // Users who sign in after the migration and users migrated from DICe will be
+  // notified with other promos communicating sign-in benefits.
+  if (prefs->GetBoolean(prefs::kPrimaryAccountSetAfterSigninMigration) ||
+      prefs->GetBoolean(kDiceMigrationMigrated)) {
+    return;
+  }
+
+  BrowserUserEducationInterface::From(browser_)->MaybeShowStartupFeaturePromo(
+      feature_engagement::kIPHSignInBenefitsFeature);
+}
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
 
 void AvatarToolbarButton::MaybeShowExplicitBrowserSigninPreferenceRememberedIPH(
@@ -615,30 +658,10 @@ void AvatarToolbarButton::AfterPropertyChange(const void* key,
 }
 
 SkColor AvatarToolbarButton::GetForegroundColor(ButtonState state) const {
-  if (base::FeatureList::IsEnabled(
-          features::kEnableAppMenuButtonColorsForDefaultAvatarButtonStates)) {
-    if (IsLabelPresentAndVisible()) {
-      return GetHighlightTextColor().value_or(GetColorProvider()->GetColor(
-          kColorAvatarButtonHighlightDefaultForeground));
-    }
-  } else {
-    const bool has_custom_theme =
-        this->GetWidget() && this->GetWidget()->GetCustomTheme();
-
-    // If there is a custom theme use the `ToolbarButton` version of
-    // `GetForegroundColor()` This is to avoid creating new colorIds for icons
-    // for all the different states. With chrome refresh and without any custom
-    // theme, the color would be same as the label color.
-    if (!has_custom_theme && IsLabelPresentAndVisible()) {
-      const std::optional<SkColor> foreground_color = GetHighlightTextColor();
-      const auto* const color_provider = GetColorProvider();
-      return foreground_color.has_value()
-                 ? foreground_color.value()
-                 : color_provider->GetColor(
-                       kColorAvatarButtonHighlightDefaultForeground);
-    }
+  if (IsLabelPresentAndVisible()) {
+    return GetHighlightTextColor().value_or(GetColorProvider()->GetColor(
+        kColorAvatarButtonHighlightDefaultForeground));
   }
-
   return ToolbarButton::GetForegroundColor(state);
 }
 
@@ -690,6 +713,11 @@ base::AutoReset<std::optional<base::TimeDelta>> AvatarToolbarButton::
   return AvatarToolbarButtonStateManager::
       CreateScopedZeroDelayOverrideSigninPendingTextForTesting();
 }
+
+void AvatarToolbarButton::ForceShowingPromoForTesting() {
+  CHECK(state_manager_);
+  state_manager_->ForceShowingPromoForTesting();
+}
 #endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
 
 BEGIN_METADATA(AvatarToolbarButton)
