@@ -41,13 +41,13 @@
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_commands.h"
 #include "chrome/browser/ui/browser_window.h"
+#include "chrome/browser/ui/exclusive_access/exclusive_access_manager.h"
 #include "chrome/browser/ui/global_error/global_error_service_factory.h"
 #include "chrome/browser/ui/hats/trust_safety_sentiment_service_factory.h"
 #include "chrome/browser/ui/layout_constants.h"
 #include "chrome/browser/ui/profiles/profile_view_utils.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_hats_service.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_hats_service_factory.h"
-#include "chrome/browser/ui/tabs/saved_tab_groups/saved_tab_group_service_factory.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "chrome/browser/ui/toolbar/app_menu_model.h"
 #include "chrome/browser/ui/ui_features.h"
@@ -668,7 +668,8 @@ class AppMenu::ZoomView : public AppMenuView, public views::WidgetObserver {
                 base::BindRepeating(&AppMenu::ZoomView::OnZoomLevelChanged,
                                     base::Unretained(this)));
     // Disable full screen button when window is not resizable
-    views::Widget* widget = menu->browser_->GetBrowserView().GetWidget();
+    views::Widget* widget = views::Widget::GetWidgetForNativeWindow(
+        menu->browser_->window()->GetNativeWindow());
     if (widget) {
       widget_observation_.Observe(widget);
     }
@@ -844,8 +845,11 @@ class AppMenu::ZoomView : public AppMenuView, public views::WidgetObserver {
   }
 
   void UpdateFullScreenButton() {
-    bool can_fullscreen =
-        menu()->browser_->GetBrowserView().CanUserEnterFullscreen();
+    bool can_fullscreen = menu()
+                              ->browser_->browser_window_features()
+                              ->exclusive_access_manager()
+                              ->context()
+                              ->CanUserEnterFullscreen();
     const int accname_string_id = can_fullscreen
                                       ? IDS_ACCNAME_FULLSCREEN
                                       : IDS_ACCNAME_FULLSCREEN_DISABLED;
@@ -1054,6 +1058,19 @@ void AppMenu::RunMenu(views::MenuButtonController* host) {
       "Chrome.AppMenu.MenuHostInitToNextFramePresented");
 }
 
+void AppMenu::RunMenu(views::Widget* parent,
+                      const gfx::Rect& anchor_screen_bounds) {
+  base::RecordAction(UserMetricsAction("ShowAppMenu"));
+  UMA_HISTOGRAM_ENUMERATION("WrenchMenu.MenuAction", MENU_ACTION_MENU_OPENED,
+                            LIMIT_MENU_ACTION);
+
+  menu_runner_->RunMenuAt(
+      parent, nullptr, anchor_screen_bounds,
+      views::MenuAnchorPosition::kTopRight, ui::mojom::MenuSourceType::kNone,
+      /*native_view_for_gestures=*/gfx::NativeView(), /*corners=*/std::nullopt,
+      "Chrome.AppMenu.MenuHostInitToNextFramePresented");
+}
+
 void AppMenu::CloseMenu() {
   if (menu_runner_.get()) {
     menu_runner_->Cancel();
@@ -1195,6 +1212,10 @@ bool AppMenu::IsCommandEnabled(int command_id) const {
     return true;
   }
 
+  if (command_id == IDC_CREATE_NEW_TAB_GROUP_TOP_LEVEL) {
+    return true;
+  }
+
   if (IsTabGroupsCommand(command_id)) {
     return stg_everything_menu_->ShouldEnableCommand(command_id);
   }
@@ -1278,6 +1299,14 @@ bool AppMenu::GetAccelerator(int command_id,
     return false;
   }
 
+  if (command_id == IDC_CREATE_NEW_TAB_GROUP_TOP_LEVEL) {
+    // Same as 'Create new tab group' except the menu item is at the top level
+    // of the app menu instead of in the tab groups submenu.
+      return browser_->browser_window_features()
+          ->accelerator_provider()
+          ->GetAcceleratorForCommandId(IDC_CREATE_NEW_TAB_GROUP, accelerator);
+    }
+
   if (IsTabGroupsCommand(command_id)) {
     return false;
   }
@@ -1314,9 +1343,9 @@ void AppMenu::WillShowMenu(MenuItemView* menu) {
                               LIMIT_MENU_ACTION);
     if (!stg_everything_menu_) {
       // Only recreate the menu if we have to.
-      stg_everything_menu_ =
-          std::make_unique<tab_groups::STGEverythingMenu>(nullptr, browser_);
-      stg_everything_menu_->SetShowSubmenu(true);
+      stg_everything_menu_ = std::make_unique<tab_groups::STGEverythingMenu>(
+          nullptr, browser_,
+          tab_groups::STGEverythingMenu::MenuContext::kAppMenu);
       stg_everything_menu_->PopulateMenu(menu);
     }
   } else if (IsTabGroupsCommand(menu->GetCommand())) {
