@@ -9,6 +9,7 @@
 #include <memory>
 
 #include "base/check_deref.h"
+#include "base/check_is_test.h"
 #include "base/check_op.h"
 #include "base/containers/contains.h"
 #include "base/containers/to_vector.h"
@@ -18,6 +19,7 @@
 #include "base/notreached.h"
 #include "base/strings/utf_string_conversions.h"
 #include "components/autofill/core/browser/country_type.h"
+#include "components/autofill/core/browser/data_manager/addresses/account_name_email_store.h"
 #include "components/autofill/core/browser/data_manager/addresses/address_data_cleaner.h"
 #include "components/autofill/core/browser/data_manager/addresses/home_and_work_metadata_store.h"
 #include "components/autofill/core/browser/data_quality/addresses/profile_requirement_utils.h"
@@ -83,7 +85,7 @@ AddressDataManager::AddressDataManager(
     PrefService* local_state,
     syncer::SyncService* sync_service,
     signin::IdentityManager* identity_manager,
-    StrikeDatabaseBase* strike_database,
+    strike_database::StrikeDatabaseBase* strike_database,
     GeoIpCountryCode variation_country_code,
     std::string app_locale)
     : variation_country_code_(std::move(variation_country_code)),
@@ -119,6 +121,13 @@ AddressDataManager::AddressDataManager(
     address_data_cleaner_ = std::make_unique<AddressDataCleaner>(
         *this, sync_service, *pref_service_,
         alternative_state_name_map_updater_.get());
+
+    if (identity_manager && sync_service &&
+        base::FeatureList::IsEnabled(
+            features::kAutofillEnableSupportForNameAndEmail)) {
+      account_name_email_store_ = std::make_unique<AccountNameEmailStore>(
+          *this, *identity_manager, *sync_service, *pref_service_);
+    }
   }
 }
 
@@ -131,6 +140,7 @@ void AddressDataManager::Shutdown() {
   contact_info_precondition_checker_.reset();
   address_data_cleaner_.reset();
   home_and_work_metadata_.reset();
+  account_name_email_store_.reset();
 }
 
 void AddressDataManager::AddObserver(AddressDataManager::Observer* obs) {
@@ -169,6 +179,27 @@ void AddressDataManager::OnWebDataServiceRequestDone(
 
   if (!has_initial_load_finished_) {
     has_initial_load_finished_ = true;
+    // `AccountNameEmailStore::MaybeUpdateOrCreateAccountNameEmail()` is
+    // responsible for creating or updating the `kAccountNameEmail` profile.
+    // This requires profiles from the database to be loaded, so any old
+    // `kAccountNameEmail` profile can be accessed. Updates to the account info
+    // are generally caught by an identity observer. But if the account info
+    // becomes available before the initial load has finished, the additional
+    // call here is necessary to apply these updates.
+    // TODO(crbug.com/356845298): Clean up after launch.
+    if (base::FeatureList::IsEnabled(
+            features::kAutofillEnableSupportForNameAndEmail)) {
+      account_name_email_store_->MaybeUpdateOrCreateAccountNameEmail();
+    } else {
+      // In case the feature got disabled the profile should be cleaned up.
+      if (!GetProfilesByRecordType(
+               AutofillProfile::RecordType::kAccountNameEmail)
+               .empty()) {
+        RemoveProfile(GetProfilesByRecordType(
+                          AutofillProfile::RecordType::kAccountNameEmail)[0]
+                          ->guid());
+      }
+    }
     LogStoredDataMetrics();
   }
   NotifyObservers();
@@ -203,7 +234,45 @@ std::vector<const AutofillProfile*> AddressDataManager::GetProfilesToSuggest()
   if (!IsAutofillProfileEnabled()) {
     return {};
   }
-  return GetProfiles(ProfileOrder::kHighestFrecencyDesc);
+
+  std::vector<const AutofillProfile*> profiles =
+      GetProfiles(ProfileOrder::kHighestFrecencyDesc);
+
+  // If the `pref_service_` doesn't exits the special logic which depends on
+  // prefs shouldn't run.
+  if (!pref_service_) {
+    CHECK_IS_TEST();
+    return profiles;
+  }
+
+  if (!base::FeatureList::IsEnabled(
+          features::kAutofillEnableSupportForNameAndEmail)) {
+    return profiles;
+  }
+
+  // `prefs::kAutofillNameAndEmailProfileNotSelectedCounter` counts how many
+  // times the suggestion for kAccountNameEmail profile was shown and wasn't
+  // accepted.
+  const bool should_promote_name_email_profile =
+      !pref_service_->GetBoolean(prefs::kAutofillWasNameAndEmailProfileUsed) &&
+      (pref_service_->GetInteger(
+          prefs::kAutofillNameAndEmailProfileNotSelectedCounter) == 0);
+  // Move the kAccountNameEmail profile to the front (or back) depending on
+  // the `should_promote_name_email_profile`.
+  std::ranges::stable_partition(
+      profiles, [should_promote_name_email_profile](
+                    const AutofillProfile* p) {
+        bool is_name_email_profile =
+            p->record_type() == AutofillProfile::RecordType::kAccountNameEmail;
+        // stable_partition() moves all elements where the predicate returns
+        // true to the front. The name/email profile should be in front when
+        // it hasn't been used before and in the back otherwise.
+        return should_promote_name_email_profile
+                   ? is_name_email_profile
+                   : !is_name_email_profile;
+      });
+
+  return profiles;
 }
 
 std::vector<const AutofillProfile*> AddressDataManager::GetProfilesForSettings()
@@ -227,15 +296,15 @@ void AddressDataManager::AddProfile(const AutofillProfile& profile) {
   if (profile.IsEmpty(app_locale_)) {
     // TODO(crbug.com/40100455): This call is only used to notify tests to stop
     // waiting. Since no profile is added, this case shouldn't trigger
-    // `OnPersonalDataChanged()`.
+    // `OnAddressDataChanged()`.
     NotifyObservers();
     return;
   }
-  ongoing_profile_changes_[profile.guid()].emplace_back(
+  ongoing_profile_changes_.emplace_back(
       AutofillProfileChange(AutofillProfileChange::ADD, profile.guid(),
                             profile),
       /*is_ongoing=*/false);
-  HandleNextProfileChange(profile.guid());
+  HandleNextProfileChange();
 }
 
 void AddressDataManager::UpdateProfile(const AutofillProfile& profile) {
@@ -277,9 +346,10 @@ void AddressDataManager::UpdateProfile(const AutofillProfile& profile) {
   UpdateProfileInDB(profile);
 }
 
-void AddressDataManager::RemoveProfile(const std::string& guid,
-                                       bool is_deduplication_initiated) {
-  RemoveProfileImpl(guid, is_deduplication_initiated);
+void AddressDataManager::RemoveProfile(
+    const std::string& guid,
+    bool non_permanent_account_profile_removal) {
+  RemoveProfileImpl(guid, non_permanent_account_profile_removal);
 }
 
 void AddressDataManager::RemoveLocalProfilesModifiedBetween(base::Time begin,
@@ -498,7 +568,7 @@ void AddressDataManager::SetPrefService(PrefService* pref_service) {
 }
 
 void AddressDataManager::SetStrikeDatabase(
-    StrikeDatabaseBase* strike_database) {
+    strike_database::StrikeDatabaseBase* strike_database) {
   if (!strike_database) {
     return;
   }
@@ -584,6 +654,11 @@ bool AddressDataManager::IsAutofillUserSelectableTypeEnabled() const {
 }
 
 bool AddressDataManager::IsAutofillSyncToggleAvailable() const {
+  if (base::FeatureList::IsEnabled(
+          syncer::kReplaceSyncPromosWithSignInPromos)) {
+    return false;
+  }
+
   if (!pref_service_->GetBoolean(::prefs::kExplicitBrowserSignin)) {
     return false;
   }
@@ -646,7 +721,7 @@ void AddressDataManager::OnAutofillProfileChanged(
   const std::string& guid = change.key();
   const AutofillProfile& profile = change.data_model();
   DCHECK(guid == profile.guid());
-  if (!ProfileChangesAreOngoing(guid)) {
+  if (ongoing_profile_changes_.empty()) {
     return;
   }
 
@@ -677,49 +752,39 @@ void AddressDataManager::OnAutofillProfileChanged(
       break;
   }
 
-  OnProfileChangeDone(guid);
+  OnProfileChangeDone();
 }
 
 void AddressDataManager::UpdateProfileInDB(const AutofillProfile& profile) {
-  if (!ProfileChangesAreOngoing(profile.guid())) {
-    const AutofillProfile* existing_profile = GetProfileByGUID(profile.guid());
-    if (!existing_profile ||
-        existing_profile->EqualsForUpdatePurposes(profile)) {
-      NotifyObservers();
-      return;
-    }
-  }
-
-  ongoing_profile_changes_[profile.guid()].emplace_back(
+  ongoing_profile_changes_.emplace_back(
       AutofillProfileChange(AutofillProfileChange::UPDATE, profile.guid(),
                             profile),
       /*is_ongoing=*/false);
-  HandleNextProfileChange(profile.guid());
+  HandleNextProfileChange();
 }
 
-void AddressDataManager::HandleNextProfileChange(const std::string& guid) {
-  if (!ProfileChangesAreOngoing(guid)) {
+void AddressDataManager::HandleNextProfileChange() {
+  if (ongoing_profile_changes_.empty()) {
     return;
   }
 
-  auto& [change, is_ongoing] = ongoing_profile_changes_[guid].front();
+  auto& [change, is_ongoing] = ongoing_profile_changes_.front();
   if (is_ongoing) {
     return;
   }
 
-  const AutofillProfile* existing_profile = GetProfileByGUID(guid);
   const AutofillProfile& profile = change.data_model();
-  DCHECK(guid == profile.guid());
+  const AutofillProfile* existing_profile = GetProfileByGUID(profile.guid());
 
   switch (change.type()) {
     case AutofillProfileChange::HIDE_IN_AUTOFILL:
     case AutofillProfileChange::REMOVE: {
       if (!existing_profile) {
-        OnProfileChangeDone(guid);
+        OnProfileChangeDone();
         return;
       }
       webdata_service_->RemoveAutofillProfile(
-          guid, change.type(),
+          profile.guid(), change.type(),
           base::BindOnce(&AddressDataManager::OnAutofillProfileChanged,
                          weak_ptr_factory_.GetWeakPtr()));
       break;
@@ -730,7 +795,7 @@ void AddressDataManager::HandleNextProfileChange(const std::string& guid) {
                               [&](const AutofillProfile* o) {
                                 return o->Compare(profile) == 0;
                               })) {
-        OnProfileChangeDone(guid);
+        OnProfileChangeDone();
         return;
       }
       webdata_service_->AddAutofillProfile(
@@ -741,7 +806,7 @@ void AddressDataManager::HandleNextProfileChange(const std::string& guid) {
     case AutofillProfileChange::UPDATE: {
       if (!existing_profile ||
           existing_profile->EqualsForUpdatePurposes(profile)) {
-        OnProfileChangeDone(guid);
+        OnProfileChangeDone();
         return;
       }
       // At this point, the `existing_profile` is consistent with
@@ -766,28 +831,16 @@ void AddressDataManager::HandleNextProfileChange(const std::string& guid) {
   if (home_and_work_metadata_) {
     home_and_work_metadata_->ApplyChange(change);
   }
+  if (account_name_email_store_) {
+    account_name_email_store_->ApplyChange(change);
+  }
   is_ongoing = true;
 }
 
-bool AddressDataManager::ProfileChangesAreOngoing(
-    const std::string& guid) const {
-  auto it = ongoing_profile_changes_.find(guid);
-  return it != ongoing_profile_changes_.end() && !it->second.empty();
-}
-
-bool AddressDataManager::ProfileChangesAreOngoing() const {
-  for (const auto& [guid, change] : ongoing_profile_changes_) {
-    if (ProfileChangesAreOngoing(guid)) {
-      return true;
-    }
-  }
-  return false;
-}
-
-void AddressDataManager::OnProfileChangeDone(const std::string& guid) {
-  ongoing_profile_changes_[guid].pop_front();
+void AddressDataManager::OnProfileChangeDone() {
+  ongoing_profile_changes_.pop_front();
   NotifyObservers();
-  HandleNextProfileChange(guid);
+  HandleNextProfileChange();
 }
 
 void AddressDataManager::LogStoredDataMetrics() const {
@@ -804,33 +857,39 @@ void AddressDataManager::LogStoredDataMetrics() const {
   }
 }
 
-void AddressDataManager::RemoveProfileImpl(const std::string& guid,
-                                           bool is_deduplication_initiated) {
+void AddressDataManager::RemoveProfileImpl(
+    const std::string& guid,
+    bool non_permanent_account_profile_removal) {
   if (!webdata_service_) {
     return;
   }
 
-  // Find the profile to remove. Even for removals the profile is a necessary
-  // part of the AutofillProfileChange, so downstream code an distinguish by
-  // RecordType.
-  const AutofillProfile* profile =
-      ProfileChangesAreOngoing(guid)
-          ? &ongoing_profile_changes_[guid].back().first.data_model()
-          : GetProfileByGUID(guid);
+  // Find the profile to remove. Even though a `guid` uniquely identifies a
+  // profile, downstream code (most notably sync) needs to know the `RecordType`
+  // of the removed profile as well (since only account profiles are uploaded).
+  // `ongoing_profile_changes_` are executed in order, so the last ongoing
+  // change for `guid` describe the profile's state by the time this removal
+  // should happen.
+  auto it = std::find_if(ongoing_profile_changes_.rbegin(),
+                         ongoing_profile_changes_.rend(),
+                         [&](const auto& x) { return x.first.key() == guid; });
+  const AutofillProfile* profile = it == ongoing_profile_changes_.rend()
+                                       ? GetProfileByGUID(guid)
+                                       : &it->first.data_model();
   if (!profile) {
     NotifyObservers();
     return;
   }
 
-  ongoing_profile_changes_[guid].emplace_back(
-      AutofillProfileChange(
-          (profile->IsAccountProfile() && is_deduplication_initiated) ||
-                  profile->IsHomeAndWorkProfile()
-              ? AutofillProfileChange::HIDE_IN_AUTOFILL
-              : AutofillProfileChange::REMOVE,
-          guid, *profile),
+  ongoing_profile_changes_.emplace_back(
+      AutofillProfileChange((profile->IsAccountProfile() &&
+                             non_permanent_account_profile_removal) ||
+                                    profile->IsHomeAndWorkProfile()
+                                ? AutofillProfileChange::HIDE_IN_AUTOFILL
+                                : AutofillProfileChange::REMOVE,
+                            guid, *profile),
       /*is_ongoing=*/false);
-  HandleNextProfileChange(guid);
+  HandleNextProfileChange();
 }
 
 }  // namespace autofill
