@@ -16,6 +16,7 @@
 #include "base/task/sequenced_task_runner.h"
 #include "base/task/thread_pool.h"
 #include "components/autofill/core/common/save_password_progress_logger.h"
+#include "components/os_crypt/async/browser/os_crypt_async.h"
 #include "components/password_manager/core/browser/browser_save_password_progress_logger.h"
 #include "components/password_manager/core/browser/password_form.h"
 #include "components/password_manager/core/browser/password_manager_client.h"
@@ -57,7 +58,8 @@ constexpr char kLoginSalt[] = "Login.salt";
 class CheckReuseRequest final : public PasswordReuseDetectorConsumer {
  public:
   // |consumer| must not be null.
-  explicit CheckReuseRequest(PasswordReuseDetectorConsumer* consumer);
+  explicit CheckReuseRequest(
+      base::WeakPtr<PasswordReuseDetectorConsumer> consumer);
   ~CheckReuseRequest() override;
 
   CheckReuseRequest(const CheckReuseRequest&) = delete;
@@ -83,9 +85,10 @@ class CheckReuseRequest final : public PasswordReuseDetectorConsumer {
   base::WeakPtrFactory<CheckReuseRequest> weak_ptr_factory_{this};
 };
 
-CheckReuseRequest::CheckReuseRequest(PasswordReuseDetectorConsumer* consumer)
+CheckReuseRequest::CheckReuseRequest(
+    base::WeakPtr<PasswordReuseDetectorConsumer> consumer)
     : origin_task_runner_(base::SequencedTaskRunner::GetCurrentDefault()),
-      consumer_weak_(consumer->AsWeakPtr()) {}
+      consumer_weak_(std::move(consumer)) {}
 
 CheckReuseRequest::~CheckReuseRequest() = default;
 
@@ -115,10 +118,18 @@ void CheckReuseHelper(std::unique_ptr<CheckReuseRequest> request,
 
 }  // namespace
 
-PasswordReuseManagerImpl::PasswordReuseManagerImpl() = default;
+PasswordReuseManagerImpl::PasswordReuseManagerImpl(
+    os_crypt_async::OSCryptAsync* os_crypt_async) {
+  os_crypt_async->GetInstance(
+      base::BindOnce(&PasswordReuseManagerImpl::OnOsCryptAsyncReady,
+                     weak_ptr_factory_.GetWeakPtr()),
+      os_crypt_async::Encryptor::Option::kEncryptSyncCompat);
+}
+
 PasswordReuseManagerImpl::~PasswordReuseManagerImpl() = default;
 
 void PasswordReuseManagerImpl::Shutdown() {
+  pending_tasks_.clear();
   profile_store_observation_.Reset();
   profile_store_.reset();
   account_store_observation_.Reset();
@@ -143,9 +154,7 @@ void PasswordReuseManagerImpl::Init(
     signin::IdentityManager* identity_manager,
     std::unique_ptr<SharedPreferencesDelegate> shared_pref_delegate) {
   prefs_ = prefs;
-  hash_password_manager_.set_prefs(prefs_);
-  hash_password_manager_.set_local_prefs(local_prefs);
-  hash_password_manager_.MigrateEnterprisePasswordHashes();
+  InitHashPasswordManager(local_prefs);
   identity_manager_ = identity_manager;
 #if BUILDFLAG(IS_ANDROID)
   if (shared_pref_delegate) {
@@ -183,13 +192,16 @@ void PasswordReuseManagerImpl::Init(
 
 void PasswordReuseManagerImpl::ReportMetrics(const std::string& username) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (DelayUntilReady(&PasswordReuseManagerImpl::ReportMetrics, username)) {
+    return;
+  }
   if (username.empty()) {
     return;
   }
 
   auto hash_password_state =
-      hash_password_manager_.HasPasswordHash(username,
-                                             /*is_gaia_password=*/true)
+      hash_password_manager_->HasPasswordHash(username,
+                                              /*is_gaia_password=*/true)
           ? metrics_util::IsSyncPasswordHashSaved::SAVED_VIA_LIST_PREF
           : metrics_util::IsSyncPasswordHashSaved::NOT_SAVED;
   metrics_util::LogIsSyncPasswordHashSaved(hash_password_state);
@@ -200,6 +212,21 @@ void PasswordReuseManagerImpl::CheckReuse(
     const std::string& domain,
     PasswordReuseDetectorConsumer* consumer) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  CheckReuseImpl(input, domain, consumer->AsWeakPtr());
+}
+
+void PasswordReuseManagerImpl::CheckReuseImpl(
+    const std::u16string& input,
+    const std::string& domain,
+    base::WeakPtr<PasswordReuseDetectorConsumer> consumer) {
+  CHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (DelayUntilReady(&PasswordReuseManagerImpl::CheckReuseImpl, input, domain,
+                      consumer)) {
+    return;
+  }
+  if (!consumer) {
+    return;
+  }
   if (!reuse_detector_) {
     consumer->OnReuseCheckDone(false, 0, std::nullopt, {}, 0, std::string(), 0);
     return;
@@ -212,6 +239,10 @@ void PasswordReuseManagerImpl::CheckReuse(
 void PasswordReuseManagerImpl::PreparePasswordHashData(
     std::optional<metrics_util::SignInState> sign_in_state_for_metrics) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (DelayUntilReady(&PasswordReuseManagerImpl::PreparePasswordHashData,
+                      sign_in_state_for_metrics)) {
+    return;
+  }
   SchedulePasswordHashUpdate(sign_in_state_for_metrics);
   ScheduleEnterprisePasswordURLUpdate();
 }
@@ -222,6 +253,10 @@ void PasswordReuseManagerImpl::SaveGaiaPasswordHash(
     bool is_sync_password_for_metrics,
     metrics_util::GaiaPasswordHashChange event) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (DelayUntilReady(&PasswordReuseManagerImpl::SaveGaiaPasswordHash, username,
+                      password, is_sync_password_for_metrics, event)) {
+    return;
+  }
   RecordAction(
       UserMetricsAction("PasswordProtection.Gaia.HashedPasswordSaved"));
   SaveProtectedPasswordHash(username, password, is_sync_password_for_metrics,
@@ -232,6 +267,10 @@ void PasswordReuseManagerImpl::SaveEnterprisePasswordHash(
     const std::string& username,
     const std::u16string& password) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (DelayUntilReady(&PasswordReuseManagerImpl::SaveEnterprisePasswordHash,
+                      username, password)) {
+    return;
+  }
   RecordAction(UserMetricsAction(
       "PasswordProtection.NonGaiaEnterprise.HashedPasswordSaved"));
   SaveProtectedPasswordHash(username, password,
@@ -248,8 +287,9 @@ void PasswordReuseManagerImpl::SaveProtectedPasswordHash(
     bool is_gaia_password,
     metrics_util::GaiaPasswordHashChange event) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  if (hash_password_manager_.SavePasswordHash(username, password,
-                                              is_gaia_password)) {
+  CHECK(hash_password_manager_);
+  if (hash_password_manager_->SavePasswordHash(username, password,
+                                               is_gaia_password)) {
     if (is_gaia_password) {
       metrics_util::LogGaiaPasswordHashChange(event,
                                               is_sync_password_for_metrics);
@@ -263,7 +303,11 @@ void PasswordReuseManagerImpl::SaveSyncPasswordHash(
     const PasswordHashData& sync_password_data,
     metrics_util::GaiaPasswordHashChange event) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  if (hash_password_manager_.SavePasswordHash(sync_password_data)) {
+  if (DelayUntilReady(&PasswordReuseManagerImpl::SaveSyncPasswordHash,
+                      sync_password_data, event)) {
+    return;
+  }
+  if (hash_password_manager_->SavePasswordHash(sync_password_data)) {
     metrics_util::LogGaiaPasswordHashChange(event,
                                             /*is_sync_password=*/true);
     SchedulePasswordHashUpdate(/*sign_in_state_for_metrics=*/std::nullopt);
@@ -273,8 +317,12 @@ void PasswordReuseManagerImpl::SaveSyncPasswordHash(
 void PasswordReuseManagerImpl::ClearGaiaPasswordHash(
     const std::string& username) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  hash_password_manager_.ClearSavedPasswordHash(username,
-                                                /*is_gaia_password=*/true);
+  if (DelayUntilReady(&PasswordReuseManagerImpl::ClearGaiaPasswordHash,
+                      username)) {
+    return;
+  }
+  hash_password_manager_->ClearSavedPasswordHash(username,
+                                                 /*is_gaia_password=*/true);
   if (!reuse_detector_) {
     return;
   }
@@ -285,7 +333,10 @@ void PasswordReuseManagerImpl::ClearGaiaPasswordHash(
 
 void PasswordReuseManagerImpl::ClearAllGaiaPasswordHash() {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  hash_password_manager_.ClearAllPasswordHash(/* is_gaia_password= */ true);
+  if (DelayUntilReady(&PasswordReuseManagerImpl::ClearAllGaiaPasswordHash)) {
+    return;
+  }
+  hash_password_manager_->ClearAllPasswordHash(/* is_gaia_password= */ true);
   if (!reuse_detector_) {
     return;
   }
@@ -295,7 +346,11 @@ void PasswordReuseManagerImpl::ClearAllGaiaPasswordHash() {
 
 void PasswordReuseManagerImpl::ClearAllEnterprisePasswordHash() {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  hash_password_manager_.ClearAllPasswordHash(/* is_gaia_password= */ false);
+  if (DelayUntilReady(
+          &PasswordReuseManagerImpl::ClearAllEnterprisePasswordHash)) {
+    return;
+  }
+  hash_password_manager_->ClearAllPasswordHash(/* is_gaia_password= */ false);
   if (!reuse_detector_) {
     return;
   }
@@ -306,7 +361,11 @@ void PasswordReuseManagerImpl::ClearAllEnterprisePasswordHash() {
 
 void PasswordReuseManagerImpl::ClearAllNonGmailPasswordHash() {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  hash_password_manager_.ClearAllNonGmailPasswordHash();
+  if (DelayUntilReady(
+          &PasswordReuseManagerImpl::ClearAllNonGmailPasswordHash)) {
+    return;
+  }
+  hash_password_manager_->ClearAllNonGmailPasswordHash();
   if (!reuse_detector_) {
     return;
   }
@@ -315,33 +374,59 @@ void PasswordReuseManagerImpl::ClearAllNonGmailPasswordHash() {
                      base::Unretained(reuse_detector_.get())));
 }
 
-base::CallbackListSubscription
-PasswordReuseManagerImpl::RegisterStateCallbackOnHashPasswordManager(
-    const base::RepeatingCallback<void(const std::string& username)>&
-        callback) {
-  DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-  return hash_password_manager_.RegisterStateCallback(callback);
-}
-
 void PasswordReuseManagerImpl::SetPasswordReuseManagerSigninNotifier(
     std::unique_ptr<PasswordReuseManagerSigninNotifier> notifier) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (!hash_password_manager_) {
+    CHECK(DelayUntilReady(
+        &PasswordReuseManagerImpl::SetPasswordReuseManagerSigninNotifier,
+        std::move(notifier)));
+    return;
+  }
   DCHECK(!notifier_);
   DCHECK(notifier);
   notifier_ = std::move(notifier);
   notifier_->SubscribeToSigninEvents(this);
 }
 
+void PasswordReuseManagerImpl::InitHashPasswordManager(
+    PrefService* local_prefs) {
+  if (DelayUntilReady(&PasswordReuseManagerImpl::InitHashPasswordManager,
+                      base::Unretained(local_prefs))) {
+    return;
+  }
+  hash_password_manager_->set_prefs(prefs_);
+  hash_password_manager_->set_local_prefs(local_prefs);
+  hash_password_manager_->MigrateEnterprisePasswordHashes();
+}
+
+void PasswordReuseManagerImpl::OnOsCryptAsyncReady(
+    os_crypt_async::Encryptor encryptor) {
+  hash_password_manager_ =
+      std::make_unique<HashPasswordManager>(std::move(encryptor));
+  state_callback_list_subscription_ =
+      hash_password_manager_->RegisterStateCallback(base::BindRepeating(
+          &PasswordReuseManagerImpl::HashPasswordManagerStateChanged,
+          weak_ptr_factory_.GetWeakPtr()));
+  for (auto& task : pending_tasks_) {
+    std::move(task).Run();
+  }
+  pending_tasks_.clear();
+  observers_.Notify(
+      &PasswordReuseManager::Observer::HashPasswordManagerAvailable,
+      hash_password_manager_.get());
+}
+
 void PasswordReuseManagerImpl::SchedulePasswordHashUpdate(
     std::optional<metrics_util::SignInState> sign_in_state_for_metrics) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-
+  CHECK(hash_password_manager_);
   if (!reuse_detector_) {
     return;
   }
 
   std::vector<PasswordHashData> protected_password_data_list =
-      hash_password_manager_.RetrieveAllPasswordHashes();
+      hash_password_manager_->RetrieveAllPasswordHashes();
 
   std::vector<PasswordHashData> gaia_password_hash_list;
   std::vector<PasswordHashData> enterprise_password_hash_list;
@@ -370,7 +455,10 @@ void PasswordReuseManagerImpl::SchedulePasswordHashUpdate(
 
 void PasswordReuseManagerImpl::ScheduleEnterprisePasswordURLUpdate() {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
-
+  if (DelayUntilReady(
+          &PasswordReuseManagerImpl::ScheduleEnterprisePasswordURLUpdate)) {
+    return;
+  }
   if (!prefs_) {
     return;
   }
@@ -407,6 +495,11 @@ void PasswordReuseManagerImpl::RequestLoginsFromStores() {
 void PasswordReuseManagerImpl::OnGetPasswordStoreResults(
     std::vector<std::unique_ptr<PasswordForm>> results) {
   DCHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  if (!hash_password_manager_) {
+    CHECK(DelayUntilReady(&PasswordReuseManagerImpl::OnGetPasswordStoreResults,
+                          std::move(results)));
+    return;
+  }
   if (!reuse_detector_) {
     return;
   }
@@ -418,6 +511,10 @@ void PasswordReuseManagerImpl::OnGetPasswordStoreResults(
 void PasswordReuseManagerImpl::OnLoginsChanged(
     password_manager::PasswordStoreInterface* store,
     const password_manager::PasswordStoreChangeList& changes) {
+  if (DelayUntilReady(&PasswordReuseManagerImpl::OnLoginsChanged, nullptr,
+                      changes)) {
+    return;
+  }
   ScheduleTask(base::BindOnce(&PasswordReuseDetector::OnLoginsChanged,
                               base::Unretained(reuse_detector_.get()),
                               changes));
@@ -429,6 +526,16 @@ void PasswordReuseManagerImpl::OnLoginsRetained(
   PasswordForm::Store store_type = store == account_store_
                                        ? PasswordForm::Store::kAccountStore
                                        : PasswordForm::Store::kProfileStore;
+  OnLoginsRetainedImpl(store_type, retained_passwords);
+}
+
+void PasswordReuseManagerImpl::OnLoginsRetainedImpl(
+    PasswordForm::Store store_type,
+    const std::vector<PasswordForm>& retained_passwords) {
+  if (DelayUntilReady(&PasswordReuseManagerImpl::OnLoginsRetainedImpl,
+                      store_type, retained_passwords)) {
+    return;
+  }
   ScheduleTask(base::BindOnce(&PasswordReuseDetector::OnLoginsRetained,
                               base::Unretained(reuse_detector_.get()),
                               store_type, retained_passwords));
@@ -447,8 +554,19 @@ void PasswordReuseManagerImpl::AccountStoreStateChanged() {
   account_store_->GetAutofillableLogins(weak_ptr_factory_.GetWeakPtr());
 }
 
+void PasswordReuseManagerImpl::HashPasswordManagerStateChanged(
+    const std::string& username) {
+  observers_.Notify(
+      &PasswordReuseManager::Observer::HashPasswordStateMaybeChanged, username,
+      hash_password_manager_.get());
+}
+
 void PasswordReuseManagerImpl::OnPrimaryAccountChanged(
     const signin::PrimaryAccountChangeEvent& event_details) {
+  if (DelayUntilReady(&PasswordReuseManagerImpl::OnPrimaryAccountChanged,
+                      event_details)) {
+    return;
+  }
   if (!shared_pref_delegate_) {
     return;
   }
@@ -500,7 +618,7 @@ void PasswordReuseManagerImpl::OnPrimaryAccountChanged(
         password_hash_data.hash = static_cast<uint64_t>(
             saved_creds_entry->FindDouble(kLoginHashedPassword).value());
         password_hash_data.force_update = true;
-        hash_password_manager_.SavePasswordHash(password_hash_data);
+        hash_password_manager_->SavePasswordHash(password_hash_data);
         SchedulePasswordHashUpdate(/*sign_in_state_for_metrics=*/std::nullopt);
         metrics_util::LogGaiaPasswordHashChange(
             metrics_util::GaiaPasswordHashChange::SAVED_ON_CHROME_SIGNIN,
@@ -522,6 +640,12 @@ void PasswordReuseManagerImpl::OnPrimaryAccountChanged(
 void PasswordReuseManagerImpl::MaybeSavePasswordHash(
     const PasswordForm* submitted_form,
     PasswordManagerClient* client) {
+  // This method doesn't use DelayUntilReady since it isn't safe to store
+  // `submitted_form` or `client` in a task. That's okay since this method
+  // doesn't (and should never) use any member variables. It does call into
+  // SaveEnterprisePasswordHash or SaveGaiaPasswordHash which are themselves
+  // delayed if necessary.
+
   // When |username_value| is empty, it's not clear whether the submitted
   // credentials are really Gaia or enterprise credentials. Don't save
   // password hash in that case.
@@ -577,4 +701,21 @@ void PasswordReuseManagerImpl::MaybeSavePasswordHash(
                        /*is_sync_password_for_metrics=*/is_sync_account_email,
                        event);
 }
+
+HashPasswordManager* PasswordReuseManagerImpl::GetHashPasswordManager() {
+  return hash_password_manager_.get();
+}
+
+void PasswordReuseManagerImpl::AddObserver(
+    PasswordReuseManager::Observer* observer) {
+  CHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  observers_.AddObserver(observer);
+}
+
+void PasswordReuseManagerImpl::RemoveObserver(
+    PasswordReuseManager::Observer* observer) {
+  CHECK(main_task_runner_->RunsTasksInCurrentSequence());
+  observers_.RemoveObserver(observer);
+}
+
 }  // namespace password_manager
