@@ -71,8 +71,6 @@ constexpr char kAutofillSignInPromoDismissCount[] =
 
 // Registers that the sign in occurred with an explicit user action from the
 // bubble that appears after installing an extension. False by default.
-// Note: this pref is only set to true when
-// `switches::kEnableExtensionsExplicitBrowserSignin` is enabled.
 constexpr char kExtensionsExplicitBrowserSigninEnabled[] =
     "ExtensionsExplicitBrowserSigninEnabled";
 
@@ -82,15 +80,16 @@ constexpr char kExtensionsExplicitBrowserSigninEnabled[] =
 constexpr char kBookmarksExplicitBrowserSigninEnabled[] =
     "BookmarksExplicitBrowserSigninEnabled";
 
+// Sync promo on the avatar button.
+//
 // Number of times the sync promo was shown in the identity pill (avatar toolbar
 // button).
 constexpr std::string_view kSyncPromoIdentityPillShownCount =
-    "ChromeSigninSyncPromoIdentityPillShownCount";
-
+    "SyncPromoIdentityPillShownCount";
 // Number of times the sync promo was used (clicked) in the identity pill
 // (avatar toolbar button).
 constexpr std::string_view kSyncPromoIdentityPillUsedCount =
-    "ChromeSigninSyncPromoIdentityPillUsedCount";
+    "SyncPromoIdentityPillUsedCount";
 
 // Number of times the Bookmark Batch Upload promo was dismissed.
 constexpr std::string_view kBookmarkBatchUploadPromoDismissCount =
@@ -99,6 +98,29 @@ constexpr std::string_view kBookmarkBatchUploadPromoDismissCount =
 constexpr std::string_view kBookmarkBatchUploadPromoLastDismissTime =
     "BookmarkBatchUploadPromoLastDismissTime";
 
+constexpr std::string_view kPolicyDisclaimerLastRegistrationFailureTime =
+    "PolicyDisclaimerLastRegistrationFailureTime";
+
+// Dictionary pref that contains all the values related to the avatar button
+// promo counts.
+constexpr std::string_view kAvatarButtonPromoCountDictionary =
+    "AvatarButtonPromoCountDictionary";
+
+// DEPRECATED(10/25): Check `SigninPrefs::SigninPrefs()`.
+// Testing deprecating pref:
+constexpr std::string_view kDeprecatingTestingPref = "DeprecatingTestingPref";
+//
+// History Sync promo on the avatar button.
+//
+// Number of times the history sync promo was shown in the identity pill (avata
+// toolbar button).
+constexpr std::string_view kHistorySyncPromoIdentityPillShownCount =
+    "ChromeSigninSyncPromoIdentityPillShownCount";
+// Number of times the history sync promo was used (clicked) in the identity
+// pill (avatar toolbar button).
+constexpr std::string_view kHistorySyncPromoIdentityPillUsedCount =
+    "ChromeSigninSyncPromoIdentityPillUsedCount";
+
 }  // namespace
 
 SigninPrefs::SigninPrefs(PrefService& pref_service)
@@ -110,8 +132,17 @@ void SigninPrefs::RegisterProfilePrefs(PrefRegistrySimple* registry) {
   registry->RegisterDictionaryPref(kSigninAccountPrefs);
   registry->RegisterIntegerPref(prefs::kHistorySyncSuccessiveDeclineCount, 0);
   registry->RegisterInt64Pref(prefs::kHistorySyncLastDeclinedTimestamp, 0);
-  registry->RegisterIntegerPref(kSyncPromoIdentityPillShownCount, 0);
-  registry->RegisterIntegerPref(kSyncPromoIdentityPillUsedCount, 0);
+}
+
+void SigninPrefs::MigrateObsoleteSigninPrefs() {
+  ScopedDictPrefUpdate scoped_update(&pref_service_.get(), kSigninAccountPrefs);
+  // Deprecates prefs within the existing internal account dict.
+  for (auto value : scoped_update.Get()) {
+    base::DictValue& account_dict = value.second.GetDict();
+    account_dict.Remove(kDeprecatingTestingPref);
+    account_dict.Remove(kHistorySyncPromoIdentityPillShownCount);
+    account_dict.Remove(kHistorySyncPromoIdentityPillUsedCount);
+  }
 }
 
 bool SigninPrefs::HasAccountPrefs(const GaiaId& gaia_id) const {
@@ -265,9 +296,6 @@ int SigninPrefs::GetAutofillSigninPromoDismissCount(
 
 void SigninPrefs::SetExtensionsExplicitBrowserSignin(const GaiaId& gaia_id,
                                                      bool enabled) {
-  // The pref can only be set to true if the
-  // `switches::kEnableExtensionsExplicitBrowserSignin` flag is enabled.
-  CHECK(!enabled || switches::IsExtensionsExplicitBrowserSigninEnabled());
   SetBooleanPrefForAccount(gaia_id, kExtensionsExplicitBrowserSigninEnabled,
                            enabled);
 }
@@ -294,6 +322,24 @@ bool SigninPrefs::GetBookmarksExplicitBrowserSignin(
                                   kBookmarksExplicitBrowserSigninEnabled);
 }
 
+void SigninPrefs::SetPolicyDisclaimerLastRegistrationFailureTime(
+    const GaiaId& gaia_id,
+    base::Time last_registration_failure_time) {
+  SetTimePref(last_registration_failure_time, gaia_id,
+              kPolicyDisclaimerLastRegistrationFailureTime);
+}
+
+void SigninPrefs::ClearPolicyDisclaimerLastRegistrationFailureTime(
+    const GaiaId& gaia_id) {
+  ClearPref(gaia_id, kPolicyDisclaimerLastRegistrationFailureTime);
+}
+
+std::optional<base::Time>
+SigninPrefs::GetPolicyDisclaimerLastRegistrationFailureTime(
+    const GaiaId& gaia_id) const {
+  return GetTimePref(gaia_id, kPolicyDisclaimerLastRegistrationFailureTime);
+}
+
 void SigninPrefs::IncrementSyncPromoIdentityPillShownCount(
     const GaiaId& gaia_id) {
   IncrementIntPrefForAccount(gaia_id, kSyncPromoIdentityPillShownCount);
@@ -328,6 +374,15 @@ SigninPrefs::GetBookmarkBatchUploadPromoDismissCountWithLastTime(
           GetTimePref(gaia_id, kBookmarkBatchUploadPromoLastDismissTime)};
 }
 
+base::DictValue& SigninPrefs::GetOrCreateAvatarButtonPromoCountDictionary(
+    const GaiaId& gaia_id) {
+  CHECK(!gaia_id.empty());
+  ScopedDictPrefUpdate scoped_update(&pref_service_.get(), kSigninAccountPrefs);
+  // `EnsureDict` gets or create the dictionary.
+  return *scoped_update->EnsureDict(gaia_id.ToString())
+              ->EnsureDict(kAvatarButtonPromoCountDictionary);
+}
+
 int SigninPrefs::IncrementIntPrefForAccount(const GaiaId& gaia_id,
                                             std::string_view pref) {
   CHECK(!gaia_id.empty());
@@ -425,3 +480,28 @@ void SigninPrefs::ClearPref(const GaiaId& gaia_id, std::string_view pref) {
 
   account_dict->Remove(pref);
 }
+
+void SigninPrefs::SetDeprecatedPrefForTesting(const GaiaId& gaia_id) {
+  CHECK(!gaia_id.empty());
+  ScopedDictPrefUpdate scoped_update(&pref_service_.get(), kSigninAccountPrefs);
+  // `EnsureDict` gets or create the dictionary.
+  base::Value::Dict* account_dict =
+      scoped_update->EnsureDict(gaia_id.ToString());
+
+  account_dict->Set(kDeprecatingTestingPref, 123);
+}
+
+std::optional<int> SigninPrefs::GetDeprecatedPrefForTesting(
+    const GaiaId& gaia_id) {
+  CHECK(!gaia_id.empty());
+  const base::Value::Dict* account_dict =
+      pref_service_->GetDict(kSigninAccountPrefs).FindDict(gaia_id.ToString());
+  if (!account_dict) {
+    return std::nullopt;
+  }
+
+  std::optional<int> pref_value =
+      account_dict->FindInt(kDeprecatingTestingPref);
+  return pref_value.has_value() ? pref_value.value()
+                                : std::optional<int>(std::nullopt);
+}
