@@ -268,7 +268,8 @@ bool TranslateManager::IsMimeTypeSupported(const std::string& mime_type) {
   return true;
 }
 
-void TranslateManager::ShowTranslateUI(const std::string& target_lang,
+void TranslateManager::ShowTranslateUI(std::optional<std::string> source_code,
+                                       std::optional<std::string> target_code,
                                        bool auto_translate,
                                        bool triggered_from_menu) {
   // If a translation is in progress, do nothing.
@@ -277,10 +278,21 @@ void TranslateManager::ShowTranslateUI(const std::string& target_lang,
   }
   std::unique_ptr<TranslatePrefs> translate_prefs(
       translate_client_->GetTranslatePrefs());
-  const std::string source_code = TranslateDownloadManager::GetLanguageCode(
-      language_state_.source_language());
-  bool is_translated = language_state_.IsPageTranslated() &&
-                       target_lang == language_state_.current_language();
+
+  // Get language codes.
+  std::string converted_source_code =
+      source_code.has_value() ? source_code.value()
+                              : TranslateDownloadManager::GetLanguageCode(
+                                    language_state_.source_language());
+  language::ToTranslateLanguageSynonym(&converted_source_code);
+  const std::string converted_target_code =
+      target_code.has_value()
+          ? target_code.value()
+          : GetTargetLanguageForDisplay(translate_prefs.get(), language_model_);
+
+  bool is_translated =
+      language_state_.IsPageTranslated() &&
+      converted_target_code == language_state_.current_language();
 
   language_state_.SetTranslateEnabled(true);
   const TranslateStep step = is_translated ? TRANSLATE_STEP_AFTER_TRANSLATE
@@ -289,24 +301,20 @@ void TranslateManager::ShowTranslateUI(const std::string& target_lang,
   // should trigger translation automatically. Otherwise, only show the infobar.
   if (auto_translate && !is_translated) {
     TranslatePage(
-        source_code, target_lang, triggered_from_menu,
+        converted_source_code, converted_target_code, triggered_from_menu,
         GetActiveTranslateMetricsLogger()->GetNextManualTranslationType(
             triggered_from_menu));
     return;
   }
-  translate_client_->ShowTranslateUI(step, source_code, target_lang,
-                                     TranslateErrors::NONE,
-                                     triggered_from_menu);
+  translate_client_->ShowTranslateUI(
+      step, converted_source_code, converted_target_code, TranslateErrors::NONE,
+      triggered_from_menu);
 }
 
 void TranslateManager::ShowTranslateUI(bool auto_translate,
                                        bool triggered_from_menu) {
-  std::unique_ptr<TranslatePrefs> translate_prefs(
-      translate_client_->GetTranslatePrefs());
-  const std::string target_lang =
-      GetTargetLanguageForDisplay(translate_prefs.get(), language_model_);
-
-  ShowTranslateUI(target_lang, auto_translate, triggered_from_menu);
+  ShowTranslateUI(std::nullopt, std::nullopt, auto_translate,
+                  triggered_from_menu);
 }
 
 void TranslateManager::TranslatePage(const std::string& original_source_lang,
