@@ -29,6 +29,7 @@
 #include "components/supervised_user/core/browser/supervised_user_url_filter.h"  // nogncheck
 #include "components/supervised_user/core/browser/supervised_user_utils.h"
 #include "components/supervised_user/core/common/buildflags.h"
+#include "content/public/browser/navigation_controller.h"
 #include "content/public/browser/navigation_entry.h"
 #include "content/public/browser/render_frame_host.h"
 #include "content/public/browser/render_process_host.h"
@@ -330,12 +331,13 @@ bool ShouldUseProcessPerSiteForInstantSiteURL(const GURL& site_url,
          site_url.host_piece() == chrome::kChromeSearchRemoteNtpHost;
 }
 
-GURL GetEffectiveURLForInstant(const GURL& url, Profile* profile) {
+std::optional<GURL> GetEffectiveURLForInstant(const GURL& url,
+                                              Profile* profile) {
   CHECK(ShouldAssignURLToInstantRenderer(url, profile))
       << "Error granting Instant access.";
 
   if (url.SchemeIs(chrome::kChromeSearchScheme)) {
-    return url;
+    return std::nullopt;
   }
 
   // Replace the scheme with "chrome-search:", and clear the port, since
