@@ -19,7 +19,6 @@
 #include "base/memory/weak_ptr.h"
 #include "base/scoped_observation.h"
 #include "base/scoped_observation_traits.h"
-#include "base/supports_user_data.h"
 #include "base/time/time.h"
 #include "base/timer/elapsed_timer.h"
 #include "base/types/expected.h"
@@ -32,6 +31,7 @@
 #include "chrome/browser/ui/browser_navigator_params.h"
 #include "chrome/browser/ui/browser_window/public/browser_window_interface.h"
 #include "chrome/browser/ui/browser_window/public/desktop_browser_window_capabilities_delegate.h"
+#include "chrome/browser/ui/browser_window_deleter.h"
 #include "chrome/browser/ui/chrome_web_modal_dialog_manager_delegate.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "chrome/browser/ui/tabs/tab_strip_model_observer.h"
@@ -53,7 +53,6 @@
 #include "ui/base/unowned_user_data/unowned_user_data_host.h"
 #include "ui/base/window_open_disposition.h"
 #include "ui/gfx/geometry/rect.h"
-#include "ui/shell_dialogs/select_file_dialog.h"
 
 #if BUILDFLAG(IS_ANDROID)
 #error This file should only be included on desktop.
@@ -97,10 +96,6 @@ namespace gfx {
 class Image;
 }
 
-namespace ui {
-struct SelectedFileInfo;
-}
-
 namespace web_app {
 class AppBrowserController;
 }
@@ -122,19 +117,18 @@ enum class BrowserClosingStatus {
   kDeniedUnloadHandlersNeedTime
 };
 
-// An instance of this class represents a single browser window on Desktop. All
-// features that are scoped to a browser window should have lifetime semantics
-// scoped to an instance of this class, usually via direct or indirect ownership
-// of a std::unique_ptr. See BrowserWindowFeatures and TabFeatures.
+// An instance of this class represents a single browser window on Desktop.
+// Owned by BrowserManagerService.
+// All features that are scoped to a browser window should have lifetime scoped
+// to an instance of this class, usually via direct or indirect ownership of a
+// std::unique_ptr. See BrowserWindowFeatures and TabFeatures.
 class Browser : public TabStripModelObserver,
                 public WebContentsCollection::Observer,
                 public content::WebContentsDelegate,
                 public ChromeWebModalDialogManagerDelegate,
-                public base::SupportsUserData,
                 public BookmarkTabHelperObserver,
                 public zoom::ZoomObserver,
                 public ThemeServiceObserver,
-                public ui::SelectFileDialog::Listener,
                 public BrowserWindowInterface,
                 public DesktopBrowserWindowCapabilitiesDelegate {
  public:
@@ -265,9 +259,6 @@ class Browser : public TabStripModelObserver,
     // platform supports it.
     bool initial_visible_on_all_workspaces_state = false;
 
-    // Whether to enable the tab group feature in the tab strip.
-    bool are_tab_groups_enabled = true;
-
     ui::mojom::WindowShowState initial_show_state =
         ui::mojom::WindowShowState::kDefault;
 
@@ -308,7 +299,11 @@ class Browser : public TabStripModelObserver,
     bool in_tab_dragging = false;
 
     // Supply a custom BrowserWindow implementation, to be used instead of the
-    // default. Intended for testing.
+    // default. Intended for testing. The resulting Browser takes ownership
+    // of `window`.
+    // TODO(crbug.com/413168662): CreateParams should be updated to be move-only
+    // and this should become a unique_ptr (or removed completely once
+    // deprecated Browser unit tests are eliminated).
     raw_ptr<BrowserWindow, DanglingUntriaged> window = nullptr;
 
     // User-set title of this browser window, if there is one.
@@ -377,7 +372,10 @@ class Browser : public TabStripModelObserver,
   static std::unique_ptr<Browser> DeprecatedCreateOwnedForTesting(
       const CreateParams& params);
 
-  // Returns whether a browser window can be created for the specified profile.
+  // Returns whether a browser window can currently be created for the specified
+  // profile. This condition may change during runtime for a given `profile`
+  // (e.g. a profile may support Browser windows but creating a Browser is
+  // disallowed during shutdown).
   static CreationStatus GetCreationStatusForProfile(Profile* profile);
 
   Browser(const Browser&) = delete;
@@ -438,7 +436,7 @@ class Browser : public TabStripModelObserver,
 
   // |window()| will return NULL if called before |CreateBrowserWindow()|
   // is done.
-  BrowserWindow* window() const { return window_; }
+  BrowserWindow* window() const { return window_.get(); }
 
   // In production code, each instance of Browser will always instantiate an
   // instance of BrowserView in the constructor. Some tests instantiate a
@@ -477,10 +475,10 @@ class Browser : public TabStripModelObserver,
     return should_trigger_session_restore_;
   }
   const web_app::AppBrowserController* app_controller() const {
-    return app_controller_.get();
+    return GetAppBrowserController();
   }
   web_app::AppBrowserController* app_controller() {
-    return app_controller_.get();
+    return GetAppBrowserController();
   }
   BrowserWindowFeatures* browser_window_features() const {
     return features_.get();
@@ -538,24 +536,25 @@ class Browser : public TabStripModelObserver,
   WarnBeforeClosingResult MaybeWarnBeforeClosing(
       WarnBeforeClosingCallback warn_callback);
 
-  // Gives beforeunload handlers the chance to cancel the close. Returns the
-  // closing status. Closing can be denied due to different reasons.
-  // This function checks if unload handlers are still executing. It further
-  // may ask the user for permission to close the browser (e.g. if downloads
-  // are ongoing).
+  // Gives beforeunload handlers the chance to cancel the close. Returns true if
+  // the close operation was permitted. Closing can be denied due to different
+  // reasons. This function checks if unload handlers are still executing. It
+  // further may ask the user for permission to close the browser (e.g. if
+  // downloads are ongoing).
   // If this function is called
-  // * but the user denied closure after being prompted, it returns
-  // `BrowserClosingStatus::kDeniedByUser`.
-  // * but the closure is not permitted by policy, it returns
-  // `BrowserClosingStatus::kDeniedByPolicy`.
-  // * while the process begun by TryToCloseWindow is in progress, it returns
-  // `BrowserClosingStatus::kDeniedUnloadHandlersNeedTime`.
+  // * but the user denied closure after being prompted, it returns false and
+  //   emits `BrowserWindowInterface::ClosingStatus::kDeniedByUser`.
+  // * but the closure is not permitted by policy, it returns false and emits
+  //   `BrowserWindowInterface::ClosingStatus::kDeniedByPolicy`.
+  // * while the process begun by `TryToCloseWindow()` is in progress, it
+  //   returns false and emits
+  //   `BrowserWindowInterface::ClosingStatus::kDeniedUnloadHandlersNeedTime`.
   //
   // If you don't care about beforeunload handlers and just want to prompt the
   // user that they might lose an in-progress operation, call
-  // MaybeWarnBeforeClosing() instead (HandleBeforeClose() also calls this
+  // `MaybeWarnBeforeClosing()` instead (`HandleBeforeClose()` also calls this
   // method).
-  BrowserClosingStatus HandleBeforeClose();
+  bool HandleBeforeClose();
 
   // Begins the process of confirming whether the associated browser can be
   // closed. If there are no tabs with beforeunload handlers it will immediately
@@ -695,6 +694,7 @@ class Browser : public TabStripModelObserver,
 
   // Overridden from content::WebContentsDelegate:
   void ActivateContents(content::WebContents* contents) override;
+  bool IsContentsActive(content::WebContents* contents) override;
   void SetTopControlsShownRatio(content::WebContents* web_contents,
                                 float ratio) override;
   int GetTopControlsHeight() override;
@@ -705,8 +705,6 @@ class Browser : public TabStripModelObserver,
   bool CanOverscrollContent() override;
   bool ShouldPreserveAbortedURLs(content::WebContents* source) override;
   void SetFocusToLocationBar() override;
-  bool PreHandleMouseEvent(content::WebContents* source,
-                           const blink::WebMouseEvent& event) override;
   void PreHandleDragUpdate(const content::DropData& drop_data,
                            const gfx::PointF& client_pt) override;
   void PreHandleDragExit() override;
@@ -742,8 +740,6 @@ class Browser : public TabStripModelObserver,
       content::WebContents& web_contents,
       content::PreloadingTriggerType trigger_type) override;
   bool ShouldShowStaleContentOnEviction(content::WebContents* source) override;
-  void MediaWatchTimeChanged(
-      const content::MediaPlayerWatchTime& watch_time) override;
   std::unique_ptr<content::EyeDropper> OpenEyeDropper(
       content::RenderFrameHost* frame,
       content::EyeDropperListener* listener) override;
@@ -755,6 +751,8 @@ class Browser : public TabStripModelObserver,
       content::WebContents* contents) override;
   std::vector<blink::mojom::RelatedApplicationPtr> GetSavedRelatedApplications(
       content::WebContents* web_contents) override;
+  content::WebContents* GetResponsibleWebContents(
+      content::WebContents* web_contents) override;
 
   bool is_type_normal() const { return type_ == TYPE_NORMAL; }
   bool is_type_popup() const { return type_ == TYPE_POPUP; }
@@ -794,6 +792,7 @@ class Browser : public TabStripModelObserver,
   // BrowserWindowInterface overrides:
   views::WebView* GetWebView() override;
   Profile* GetProfile() override;
+  const Profile* GetProfile() const override;
   void OpenGURL(const GURL& gurl, WindowOpenDisposition disposition) override;
   content::WebContents* OpenURL(
       const content::OpenURLParams& params,
@@ -801,10 +800,13 @@ class Browser : public TabStripModelObserver,
           navigation_handle_callback) override;
   const SessionID& GetSessionID() const override;
   TabStripModel* GetTabStripModel() override;
+  const TabStripModel* GetTabStripModel() const override;
   bool IsTabStripVisible() override;
   bool ShouldHideUIForFullscreen() const override;
   base::CallbackListSubscription RegisterBrowserDidClose(
       BrowserDidCloseCallback callback) override;
+  base::CallbackListSubscription RegisterBrowserCloseCancelled(
+      BrowserCloseCancelledCallback callback) override;
   views::View* TopContainer() override;
   base::WeakPtr<BrowserWindowInterface> GetWeakPtr() override;
   views::View* LensOverlayView() override;
@@ -817,6 +819,8 @@ class Browser : public TabStripModelObserver,
   const ui::UnownedUserDataHost& GetUnownedUserDataHost() const override;
   web_modal::WebContentsModalDialogHost*
   GetWebContentsModalDialogHostForWindow() override;
+  web_modal::WebContentsModalDialogHost* GetWebContentsModalDialogHostForTab(
+      tabs::TabInterface* tab_interface) override;
   bool IsActive() const override;
   base::CallbackListSubscription RegisterDidBecomeActive(
       DidBecomeActiveCallback callback) override;
@@ -834,6 +838,7 @@ class Browser : public TabStripModelObserver,
   bool CanShowCallToAction() const override;
   std::unique_ptr<ScopedWindowCallToAction> ShowCallToAction() override;
   ui::BaseWindow* GetWindow() override;
+  const ui::BaseWindow* GetWindow() const override;
   DesktopBrowserWindowCapabilities* capabilities() override;
   const DesktopBrowserWindowCapabilities* capabilities() const override;
 
@@ -933,6 +938,11 @@ class Browser : public TabStripModelObserver,
                           const ui::Event& event) override;
   void ContentsZoomChange(bool zoom_in) override;
   bool TakeFocus(content::WebContents* source, bool reverse) override;
+  bool DidAddMessageToConsole(content::WebContents* source,
+                              blink::mojom::ConsoleMessageLevel log_level,
+                              const std::u16string& message,
+                              int32_t line_no,
+                              const std::u16string& source_id) override;
   void BeforeUnloadFired(content::WebContents* source,
                          bool proceed,
                          bool* proceed_to_fire_unload) override;
@@ -1056,8 +1066,10 @@ class Browser : public TabStripModelObserver,
   // Overridden from WebContentsModalDialogManagerDelegate:
   void SetWebContentsBlocked(content::WebContents* web_contents,
                              bool blocked) override;
-  web_modal::WebContentsModalDialogHost* GetWebContentsModalDialogHost()
-      override;
+  web_modal::WebContentsModalDialogHost* GetWebContentsModalDialogHost(
+      content::WebContents* web_contents) override;
+  void OnWebContentsModalDialogFirstShown(
+      content::WebContents* web_contents) override;
 
   // Overridden from BookmarkTabHelperObserver:
   void URLStarredChanged(content::WebContents* web_contents,
@@ -1069,10 +1081,6 @@ class Browser : public TabStripModelObserver,
   void OnZoomChanged(
       const zoom::ZoomController::ZoomChangedEventData& data) override;
 
-  // Overridden from SelectFileDialog::Listener:
-  void FileSelected(const ui::SelectedFileInfo& file_info, int index) override;
-  void FileSelectionCanceled() override;
-
   // Overridden from ThemeServiceObserver:
   void OnThemeChanged() override;
 
@@ -1123,6 +1131,8 @@ class Browser : public TabStripModelObserver,
   // Removes all entries from scheduled_updates_ whose source is contents.
   void RemoveScheduledUpdatesFor(content::WebContents* contents);
 
+  void OnFileSelectedFromDialog(const GURL& url);
+
   // Getters for UI ///////////////////////////////////////////////////////////
 
   // Returns the list of StatusBubbles from the current toolbar. It is possible
@@ -1277,7 +1287,7 @@ class Browser : public TabStripModelObserver,
   std::unique_ptr<ScopedProfileKeepAlive> profile_keep_alive_;
 
   // This Browser's window.
-  raw_ptr<BrowserWindow, DanglingUntriaged> window_;
+  std::unique_ptr<BrowserWindow, BrowserWindowDeleter> window_;
 
   // The active state of this browser.
   bool is_active_ = false;
@@ -1350,14 +1360,6 @@ class Browser : public TabStripModelObserver,
 
   UnloadController unload_controller_;
 
-  // Dialog box used for opening and saving files.
-  scoped_refptr<ui::SelectFileDialog> select_file_dialog_;
-
-  // Helper which handles bookmark app specific browser configuration.
-  // This must be initialized before |command_controller_| to ensure the correct
-  // set of commands are enabled.
-  const std::unique_ptr<web_app::AppBrowserController> app_controller_;
-
   // True if the browser window has been shown at least once.
   bool window_has_shown_;
 
@@ -1404,6 +1406,11 @@ class Browser : public TabStripModelObserver,
       base::RepeatingCallbackList<void(BrowserWindowInterface*)>;
   BrowserDidCloseCallbackList browser_did_close_callback_list_;
 
+  using BrowserCloseCancelledCallbackList =
+      base::RepeatingCallbackList<void(BrowserWindowInterface*,
+                                       BrowserWindowInterface::ClosingStatus)>;
+  BrowserCloseCancelledCallbackList browser_close_cancelled_callback_list_;
+
   using DidActiveTabChangeCallbackList =
       base::RepeatingCallbackList<void(BrowserWindowInterface*)>;
   DidActiveTabChangeCallbackList did_active_tab_change_callback_list_;
