@@ -220,6 +220,7 @@ void SearchProvider::Start(const AutocompleteInput& input,
   model->Load();
 
   matches_.clear();
+  smart_compose_inline_hint_.clear();
 
   // At this point, we could exit early if the input is on-focus or empty,
   // because offering suggestions in those scenarios is handled by
@@ -301,11 +302,13 @@ void SearchProvider::Start(const AutocompleteInput& input,
 
   input_ = input;
 
-  // Don't search the history database for on-focus inputs or Lens searchboxes.
-  // On-focus inputs should only be used to warm up the suggest server; and Lens
-  // searchboxes do not show suggestions from the history database.
+  // Don't search the history database for on-focus inputs, Lens, or compose
+  // searchboxes. On-focus inputs should only be used to warm up the suggest
+  // server; and Lens searchboxes do not show suggestions from the history
+  // database.
   if (!input.IsZeroSuggest() &&
-      !omnibox::IsLensSearchbox(input_.current_page_classification())) {
+      !omnibox::IsLensSearchbox(input_.current_page_classification()) &&
+      !omnibox::IsComposebox(input_.current_page_classification())) {
     DoHistoryQuery(minimal_changes);
     // Answers needs scored history results before any suggest query has been
     // started, since the query for answer-bearing results needs additional
@@ -437,6 +440,7 @@ void SearchProvider::OnURLLoadComplete(
           client()->GetOmniboxTriggeredFeatureService()->FeatureTriggered(
               metrics::OmniboxEventProto_Feature_REMOTE_SEARCH_FEATURE);
         }
+        smart_compose_inline_hint_ = results->smart_compose_inline_hint;
         SortResults(is_keyword, results);
         PrefetchImages(results);
       }
@@ -464,6 +468,7 @@ void SearchProvider::StopSuggest() {
 void SearchProvider::ClearAllResults() {
   keyword_results_.Clear();
   default_results_.Clear();
+  smart_compose_inline_hint_.clear();
 }
 
 void SearchProvider::UpdateMatchContentsClass(
@@ -700,12 +705,12 @@ base::TimeDelta SearchProvider::GetSuggestQueryDelay() const {
 }
 
 void SearchProvider::StartOrStopSuggestQuery(bool minimal_changes) {
-  // Since there is currently no contextual search suggest, lens contextual
-  // searchboxes, shouldn't query suggest and only the verbatim matches should
-  // be shown.
-  if (omnibox::IsLensContextualSearchbox(
-          input_.current_page_classification()) &&
-      !lens::features::ShowContextualSearchboxSearchSuggest()) {
+  // Since there is currently no contextual search suggest or typed AI mode
+  // suggest, lens contextual searchboxes and the composebox, shouldn't query
+  // suggest and only the verbatim matches should be shown.
+  if ((omnibox::IsLensContextualSearchbox(
+           input_.current_page_classification()) &&
+       !lens::features::ShowContextualSearchboxSearchSuggest())) {
     return;
   }
   // Make sure the current query can be sent to at least one suggest service.
@@ -1040,9 +1045,6 @@ void SearchProvider::ConvertResultsToAutocompleteMatches() {
                                   &matches);
   }
 
-  if (OmniboxFieldTrial::kAnswerActionsShowAboveKeyboard.Get()) {
-    DuplicateCardAnswer(&matches);
-  }
   // Now add the most relevant matches to |matches_|.  We take up to
   // provider_max_matches_ suggest/navsuggest matches, regardless of origin.  We
   // always include in that set a legal default match if possible. If we have
