@@ -18,6 +18,7 @@
 #include "build/branding_buildflags.h"
 #include "build/build_config.h"
 #include "build/chromeos_buildflags.h"
+#include "extensions/buildflags/buildflags.h"
 
 namespace features {
 
@@ -33,8 +34,9 @@ BASE_DECLARE_FEATURE(kAllowUnmutedAutoplayForTWA);
 #endif  // BUILDFLAG(IS_ANDROID)
 BASE_DECLARE_FEATURE(kAutocompleteActionPredictorConfidenceCutoff);
 BASE_DECLARE_FEATURE(kBookmarksTreeView);
-BASE_DECLARE_FEATURE(kBookmarkTriggerForPrerender2);
+BASE_DECLARE_FEATURE(kBookmarkTriggerForPrerender2KillSwitch);
 BASE_DECLARE_FEATURE(kBookmarkTriggerForPreconnect);
+BASE_DECLARE_FEATURE(kBookmarkTriggerForPrefetch);
 BASE_DECLARE_FEATURE(kCertificateTransparencyAskBeforeEnabling);
 BASE_DECLARE_FEATURE(kCertVerificationNetworkTime);
 BASE_DECLARE_FEATURE(kClearUserDataUponProfileDestruction);
@@ -46,24 +48,31 @@ BASE_DECLARE_FEATURE(kUseFreedesktopSecretKeyProvider);
 
 BASE_DECLARE_FEATURE(kDestroyProfileOnBrowserClose);
 BASE_DECLARE_FEATURE(kDestroySystemProfiles);
-
-#if BUILDFLAG(IS_CHROMEOS)
-BASE_DECLARE_FEATURE(kDoubleTapToZoomInTabletMode);
-#endif
+BASE_DECLARE_FEATURE(kDelayOnProfileCreatedForFullBrowserTransition);
 
 BASE_DECLARE_FEATURE(kFlexOrgManagementDisclosure);
 BASE_DECLARE_FEATURE(kIncomingCallNotifications);
 
+#if BUILDFLAG(ENABLE_EXTENSIONS)
+// Controls whether to load the initial sideloaded external extensions or not.
+BASE_DECLARE_FEATURE(kInitialExternalExtensions);
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
+
 #if !BUILDFLAG(IS_ANDROID)
 BASE_DECLARE_FEATURE(kMuteNotificationSnoozeAction);
 #endif
 
 BASE_DECLARE_FEATURE(kNetworkAnnotationMonitoring);
 BASE_DECLARE_FEATURE(kNewTabPageTriggerForPrerender2);
+BASE_DECLARE_FEATURE(kNewTabPageTriggerForPrefetch);
 const base::FeatureParam<int>
-    kNewTabPagePreconnectStartDelayOnMouseHoverByMiliSeconds{
+    kNewTabPagePreconnectStartDelayOnMouseHoverByMilliSeconds{
         &features::kNewTabPageTriggerForPrerender2,
         "preconnect_start_delay_on_mouse_hover_ms", 100};
+const base::FeatureParam<int>
+    kNewTabPagePrefetchStartDelayOnMouseHoverByMilliSeconds{
+        &features::kNewTabPageTriggerForPrefetch,
+        "prefetch_start_delay_on_mouse_hover_ms", 300};
 
 #if BUILDFLAG(IS_ANDROID)
 BASE_DECLARE_FEATURE(kNotificationOneTapUnsubscribe);
@@ -74,10 +83,6 @@ extern base::FeatureParam<bool>
 BASE_DECLARE_FEATURE(kPromoBrowserCommands);
 extern const char kBrowserCommandIdParam[];
 
-#if !BUILDFLAG(IS_ANDROID)
-BASE_DECLARE_FEATURE(kReadAnythingPermanentAccessibility);
-#endif
-
 #if BUILDFLAG(IS_WIN) && BUILDFLAG(GOOGLE_CHROME_BRANDING)
 BASE_DECLARE_FEATURE(kRegisterOsUpdateHandlerWin);
 BASE_DECLARE_FEATURE(kInstallPlatformExperienceHelperWin);
