@@ -44,6 +44,7 @@
 #include "net/nqe/effective_connection_type.h"
 #include "net/nqe/network_quality_estimator_params.h"
 #include "services/network/public/cpp/client_hints.h"
+#include "services/network/public/cpp/features.h"
 #include "services/network/public/cpp/is_potentially_trustworthy.h"
 #include "services/network/public/cpp/network_quality_tracker.h"
 #include "services/network/public/cpp/permissions_policy/client_hints_permissions_policy_mapping.h"
@@ -141,9 +142,9 @@ double RoundKbpsToMbps(const std::string& host,
 
 double GetDeviceScaleFactor() {
   double device_scale_factor = 1.0;
-  if (display::Screen::GetScreen()) {
+  if (display::Screen::Get()) {
     device_scale_factor =
-        display::Screen::GetScreen()->GetPrimaryDisplay().device_scale_factor();
+        display::Screen::Get()->GetPrimaryDisplay().device_scale_factor();
   }
   DCHECK_LT(0.0, device_scale_factor);
   return device_scale_factor;
@@ -522,8 +523,7 @@ const std::string SerializeHeaderString(const T& value) {
 struct ClientHintsExtendedData {
   ClientHintsExtendedData(const url::Origin& origin,
                           FrameTreeNode* frame_tree_node,
-                          ClientHintsControllerDelegate* delegate,
-                          const std::optional<GURL>& maybe_request_url)
+                          ClientHintsControllerDelegate* delegate)
       : resource_origin(origin) {
     // If the current frame is the outermost main frame, the URL wasn't
     // committed yet, so in order to get the main frame URL, we should use the
@@ -674,31 +674,34 @@ enum class ClientUaHeaderCallType {
 // Implementation of UpdateNavigationRequestClientUaHeaders().
 void UpdateNavigationRequestClientUaHeadersImpl(
     ClientHintsControllerDelegate* delegate,
-    bool override_ua,
-    FrameTreeNode* frame_tree_node,
+    bool is_ua_override_on,
+    FrameTreeNode* ftn_for_web_contents_override,
     ClientUaHeaderCallType call_type,
     net::HttpRequestHeaders* headers,
     const network::ParsedPermissionsPolicy& container_policy,
-    const std::optional<GURL>& request_url,
-    const ClientHintsExtendedData& data) {
+    const ClientHintsExtendedData& data,
+    FrameTreeNode* ftn_for_devtools_override) {
   std::optional<blink::UserAgentMetadata> ua_metadata;
   bool disable_due_to_custom_ua = false;
-  if (override_ua) {
+  if (is_ua_override_on) {
     NavigatorDelegate* nav_delegate =
-        frame_tree_node ? frame_tree_node->navigator().GetDelegate() : nullptr;
-    ua_metadata =
-        nav_delegate
-            ? nav_delegate->GetUserAgentOverride(frame_tree_node->frame_tree())
-                  .ua_metadata_override
-            : std::nullopt;
+        ftn_for_web_contents_override
+            ? ftn_for_web_contents_override->navigator().GetDelegate()
+            : nullptr;
+    ua_metadata = nav_delegate
+                      ? nav_delegate
+                            ->GetUserAgentOverride(
+                                ftn_for_web_contents_override->frame_tree())
+                            .ua_metadata_override
+                      : std::nullopt;
     // If a custom UA override is set, but no value is provided for UA client
     // hints, disable them.
     disable_due_to_custom_ua = !ua_metadata.has_value();
   }
 
-  if (frame_tree_node &&
-      devtools_instrumentation::ApplyUserAgentMetadataOverrides(frame_tree_node,
-                                                                &ua_metadata)) {
+  if (ftn_for_devtools_override &&
+      devtools_instrumentation::ApplyUserAgentMetadataOverrides(
+          ftn_for_devtools_override, &ua_metadata)) {
     // Likewise, if devtools says to override client hints but provides no
     // value, disable them. This overwrites previous decision from UI.
     disable_due_to_custom_ua = !ua_metadata.has_value();
@@ -825,14 +828,24 @@ void UpdateNavigationRequestClientUaHeaders(
     return;
   }
 
-  ClientHintsExtendedData data(origin, frame_tree_node, delegate, request_url);
+  // In usual navigation, use the common FrameTreeNode to look up DevTools for
+  // the DevTools UA override logic.
+  ClientHintsExtendedData data(origin, frame_tree_node, delegate);
   UpdateNavigationRequestClientUaHeadersImpl(
       delegate, override_ua, frame_tree_node,
-      ClientUaHeaderCallType::kAfterCreated, headers, {}, request_url, data);
+      ClientUaHeaderCallType::kAfterCreated, headers, {}, data,
+      /*ftn_for_devtools_override=*/frame_tree_node);
 }
-
 namespace {
 
+// The main logic of adding Client Hints headers to `headers`. `frame_tree_node`
+// is used for checking the client hints policies, looking up UA overrides in
+// the corresponding WebContents, and calculating client hints values like
+// ViewportWidth, whereas `ftn_for_devtools_override` only serves as source of
+// UA override by DevTools. The two FrameTreeNode parameters can differ in
+// prefetch navigation cases because the FrameTreeNode of the navigation target
+// is sometimes unavailable during prefetch, and we must find an alternative
+// FrameTreeNode for the DevTools UA override source in such cases.
 void AddRequestClientHintsHeaders(
     const url::Origin& origin,
     net::HttpRequestHeaders* headers,
@@ -841,8 +854,8 @@ void AddRequestClientHintsHeaders(
     bool is_ua_override_on,
     FrameTreeNode* frame_tree_node,
     const network::ParsedPermissionsPolicy& container_policy,
-    const std::optional<GURL>& request_url) {
-  ClientHintsExtendedData data(origin, frame_tree_node, delegate, request_url);
+    FrameTreeNode* ftn_for_devtools_override) {
+  ClientHintsExtendedData data(origin, frame_tree_node, delegate);
   UpdateIFramePermissionsPolicyWithDelegationSupportForClientHints(
       data, container_policy);
 
@@ -887,8 +900,8 @@ void AddRequestClientHintsHeaders(
 
   UpdateNavigationRequestClientUaHeadersImpl(
       delegate, is_ua_override_on, frame_tree_node,
-      ClientUaHeaderCallType::kDuringCreation, headers, container_policy,
-      request_url, data);
+      ClientUaHeaderCallType::kDuringCreation, headers, container_policy, data,
+      ftn_for_devtools_override);
 
   if (ShouldAddClientHint(data, WebClientHintsType::kPrefersColorScheme)) {
     AddPrefersColorSchemeHeader(headers, frame_tree_node);
@@ -928,7 +941,8 @@ void AddPrefetchNavigationRequestClientHintsHeaders(
     net::HttpRequestHeaders* headers,
     BrowserContext* context,
     ClientHintsControllerDelegate* delegate,
-    bool is_ua_override_on) {
+    bool is_ua_override_on,
+    FrameTreeNode* ftn_for_devtools_override) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   DCHECK(context);
 
@@ -936,8 +950,12 @@ void AddPrefetchNavigationRequestClientHintsHeaders(
     return;
   }
 
+  // FrameTreeNode is nullptr because it is possible that no navigation has been
+  // committed yet. Nevertheless, `ftn_for_devtools_override` serves as a
+  // workaround for DevTools-initiated UA overrides.
   AddRequestClientHintsHeaders(origin, headers, context, delegate,
-                               is_ua_override_on, nullptr, {}, std::nullopt);
+                               is_ua_override_on, nullptr, {},
+                               ftn_for_devtools_override);
 }
 
 void AddNavigationRequestClientHintsHeaders(
@@ -956,9 +974,11 @@ void AddNavigationRequestClientHintsHeaders(
     return;
   }
 
-  AddRequestClientHintsHeaders(origin, headers, context, delegate,
-                               is_ua_override_on, frame_tree_node,
-                               container_policy, request_url);
+  // In usual navigation, use the common FrameTreeNode to look up DevTools for
+  // the DevTools UA override logic.
+  AddRequestClientHintsHeaders(
+      origin, headers, context, delegate, is_ua_override_on, frame_tree_node,
+      container_policy, /*ftn_for_devtools_override=*/frame_tree_node);
 }
 
 std::optional<std::vector<WebClientHintsType>>
@@ -1037,48 +1057,66 @@ std::vector<WebClientHintsType> LookupAcceptCHForCommit(
     return result;
   }
 
-  const ClientHintsExtendedData data(origin, frame_tree_node, delegate,
-                                     request_url);
+  const ClientHintsExtendedData data(origin, frame_tree_node, delegate);
   return data.hints.GetEnabledHints();
 }
 
-bool AreCriticalHintsMissing(
+CriticalHintsMissingStatus GetCriticalHintsMissingStatus(
     const url::Origin& origin,
     FrameTreeNode* frame_tree_node,
     ClientHintsControllerDelegate* delegate,
     const std::vector<WebClientHintsType>& critical_hints) {
-  ClientHintsExtendedData data(origin, frame_tree_node, delegate, std::nullopt);
+  ClientHintsExtendedData data(origin, frame_tree_node, delegate);
 
+  bool contains_not_allowed = false;
   // Note: these only check for per-hint origin/permissions policy settings, not
-  // origin-level or "browser-level" policies like disabiling JS or other
+  // origin-level or "browser-level" policies like disabling JS or other
   // features.
   for (auto hint : critical_hints) {
-    if (IsClientHintAllowed(data, hint) && !IsClientHintEnabled(data, hint)) {
-      return true;
+    if (!IsClientHintAllowed(data, hint)) {
+      contains_not_allowed = true;
+      continue;
+    }
+    if (!IsClientHintEnabled(data, hint)) {
+      return CriticalHintsMissingStatus::kMissing;
     }
   }
 
-  return false;
+  return contains_not_allowed
+             ? CriticalHintsMissingStatus::kPresentButContainsNotAllowed
+             : CriticalHintsMissingStatus::kPresent;
 }
 
-std::vector<network::mojom::WebClientHintsType> GetAddedClientHints(
-    const url::Origin& origin,
-    FrameTreeNode* frame_tree_node,
-    ClientHintsControllerDelegate* delegate) {
-  std::vector<network::mojom::WebClientHintsType> hints;
-  ClientHintsExtendedData data(origin, frame_tree_node, delegate, std::nullopt);
+network::ResourceRequest::TrustedParams::EnabledClientHints
+GetEnabledClientHints(const url::Origin& origin,
+                      FrameTreeNode* frame_tree_node,
+                      ClientHintsControllerDelegate* delegate) {
+  ClientHintsExtendedData data(origin, frame_tree_node, delegate);
 
+  network::ResourceRequest::TrustedParams::EnabledClientHints
+      enabled_client_hints;
+  enabled_client_hints.is_outermost_main_frame = data.is_outermost_main_frame;
   const auto& client_hints_map = network::GetClientHintToNameMap();
   // Note: these only check for per-hint origin/permissions policy settings, not
-  // origin-level or "browser-level" policies like disabiling JS or other
+  // origin-level or "browser-level" policies like disabling JS or other
   // features.
   for (const auto& [hint, _] : client_hints_map) {
+    // `enabled_client_hints.hints` are client hints that are enabled for the
+    // origin and allowed to be attached to the request.
     if (ShouldAddClientHint(data, hint)) {
-      hints.push_back(hint);
+      enabled_client_hints.hints.push_back(hint);
+    }
+    // `enabled_client_hints.not_allowed_hints` are client hints that are
+    // currently not allowed to be attached to the request.
+    if (base::FeatureList::IsEnabled(
+            network::features::kOffloadAcceptCHFrameCheck) &&
+        network::features::kAcceptCHFrameOffloadNotAllowedHints.Get() &&
+        !IsClientHintAllowed(data, hint)) {
+      enabled_client_hints.not_allowed_hints.push_back(hint);
     }
   }
-
-  return hints;
+  enabled_client_hints.origin = data.main_frame_origin;
+  return enabled_client_hints;
 }
 
 }  // namespace content
